@charset "UTF-8";
/*
Theme Name: Twenty Nineteen
Theme URI: https://wordpress.org/themes/twentynineteen/
Author: the WordPress team
Author URI: https://wordpress.org/
Description: Our 2019 default theme is designed to show off the power of the block editor. It features custom styles for all the default blocks, and is built so that what you see in the editor looks like what you'll see on your website. Twenty Nineteen is designed to be adaptable to a wide range of websites, whether you’re running a photo blog, launching a new business, or supporting a non-profit. Featuring ample whitespace and modern sans-serif headlines paired with classic serif body text, it's built to be beautiful on all screen sizes.
Requires at least: 4.9.6
Requires PHP: 5.2.4
Version: 2.0
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: twentynineteen
Tags: one-column, flexible-header, accessibility-ready, custom-colors, custom-menu, custom-logo, editor-style, featured-images, footer-widgets, rtl-language-support, sticky-post, threaded-comments, translation-ready, block-patterns

This theme, like WordPress, is licensed under the GPL.
Use it to make something cool, have fun, and share what you've learned with others.

Twenty Nineteen is based on Underscores https://underscores.me/, (C) 2012-2020 Automattic, Inc.
Underscores is distributed under the terms of the GNU GPL v2 or later.

Normalizing styles have been helped along thanks to the fine work of
Nicolas Gallagher and Jonathan Neal https://necolas.github.io/normalize.css/

Bundled block pattern images:
Abstract Background by HD Wallpapers, CC0. https://stocksnap.io/photo/abstract-background-0SRRVNMKBX
Abstract Waves by HD Wallpapers, CC0. https://stocksnap.io/photo/abstract-waves-0KREGLTZQ3
Abstract Bokeh by HD Wallpapers, CC0. https://stocksnap.io/photo/abstract-bokeh-P4KVZBMQ6L
Colorful Bokeh by HD Wallpapers, CC0. https://stocksnap.io/photo/colorful-bokeh-VN4G84GL8H
*/
/*--------------------------------------------------------------
>>> TABLE OF CONTENTS:
----------------------------------------------------------------
# Variables
# Normalize
# Typography
	## Headings
	## Copy
# Elements
	## Lists
	## Tables
# Forms
	## Buttons
	## Fields
# Navigation
	## Links
	## Menus
	## Next & Previous
# Accessibility
# Alignments
# Clearings
# Layout
# Widgets
# Content
	## Archives
	## Posts and pages
	## Comments
# Blocks
# Media
	## Captions
	## Galleries
--------------------------------------------------------------*/
/*
 * Chrome renders extra-wide &nbsp; characters for the Hoefler Text font.
 * This results in a jumping cursor when typing in both the Classic and block
 * editors. The following font-face override fixes the issue by manually inserting
 * a custom font that includes just a Hoefler Text space replacement for that
 * character instead.
 */
@font-face {
  font-family: 'NonBreakingSpaceOverride';
  src: url(data:application/font-woff2;charset=utf-8;base64,d09GMgABAAAAAAMoAA0AAAAACDQAAALTAAEAAAAAAAAAAAAAAAAAAAAAAAAAAAAAP0ZGVE0cGh4GYACCahEICjx3CywAATYCJANUBCAFhiEHgWwbXQfILgpsY+rQRRARwyAs6uL7pxzYhxEE+32b3aeHmifR6tklkS9hiZA0ewkqGRJE+H7/+6378ASViK/PGeavqJyOzsceKi1s3BCiQsiOdn1r/RBgIJYEgCUhbm/8/8/h4saPssnTNkkiWUBrTRtjmQSajw3Ui3pZ3LYDPD+XG2C3JA/yKAS8/rU5eNfuGqRf4eNNgV4YAlIIgxglEkWe6FYpq10+wi3g+/nUgvgPFczNrz/RsTgVm/zfbPuHZlsuQECxuyqBcQwKFBjFgKO8AqP4bAN9tFJtnM9xPcbNjeXS/x1wY/xU52f5W/X1+9cnH4YwKIaoRRAkUkj/YlAAeF/624foiIDBgBmgQBeGAyhBljUPZUm/l2dTvmpqcBDUOHdbPZWd8JsBAsGr4w8/EDn82/bUPx4eh0YNrQTBuHO2FjQEAGBwK0DeI37DpQVqdERS4gZBhpeUhWCfLFz7J99aEBgsJCHvUGAdAPp4IADDCAPCEFMGpMZ9AQpTfQtQGhLbGVBZFV8BaqNyP68oTZgHNj3M8kBPfXTTC9t90UuzYhy9ciH0grVlOcqyCytisvbsERsEYztiznR0WCrmTksJwbSNK6fd1Rvr25I9oLvctUoEbNOmXJbqgYgPXEHJ82IUsrCnpkxh23F1rfZ2zcRnJYoXtauB3VTFkFXQg3uoZYD5qE0kdjDtoDoF1h2bulGmev5HbYhbrjtohQSRI4aNOkffIcT+d3v6atpaYh3JvPoQsztCcqvaBkppDSPcQ3bw3KaCBo1f5CJWTZEgW3LjLofYg51MaVezrx8xZitYbQ9KYeoRaqQdVLwSEfrKXLK1otCWOKNdR/YwYAfon5Yk8O2MJfSD10dPGA5PIJJQMkah0ugMJiv6x4Dm7LEa8xnrRGGGLAg4sAlbsA07sAt76DOsXKO3hIjtIlpnnFrt1qW4kh6NhS83P/6HB/fl1SMAAA==) format("woff2"), url(data:application/font-woff;charset=utf-8;base64,d09GRgABAAAAAAUQAA0AAAAACDQAAQAAAAAAAAAAAAAAAAAAAAAAAAAAAABGRlRNAAAE9AAAABwAAAAchf5yU0dERUYAAATYAAAAHAAAAB4AJwAbT1MvMgAAAaAAAABJAAAAYJAcgU5jbWFwAAACIAAAAF4AAAFqUUxBZ2dhc3AAAATQAAAACAAAAAgAAAAQZ2x5ZgAAApAAAAAyAAAAPL0n8y9oZWFkAAABMAAAADAAAAA2Fi93Z2hoZWEAAAFgAAAAHQAAACQOSgWaaG10eAAAAewAAAAzAAAAVC7TAQBsb2NhAAACgAAAABAAAAAsAOQBAm1heHAAAAGAAAAAHQAAACAAWQALbmFtZQAAAsQAAAF6AAADIYvD/Adwb3N0AAAEQAAAAI4AAADsapk2o3jaY2BkYGAA4ov5mwzj+W2+MnCzXwCKMNzgCBSB0LfbQDQ7AxuI4mBgAlEAFKQIRHjaY2BkYGD3+NvCwMDBAALsDAyMDKhAFAA3+wH3AAAAeNpjYGRgYBBl4GBgYgABEMnIABJzAPMZAAVmAGUAAAB42mNgZlJhnMDAysDCKsKygYGBYRqEZtrDYMT4D8gHSmEHjgUFOQwODAqqf9g9/rYwMLB7MNUAhRlBcsxBrMlASoGBEQAj8QtyAAAAeNrjYGBkAAGmWQwMjO8gmBnIZ2NA0ExAzNjAAFYJVn0ASBsD6VAIDZb7AtELAgANIgb9AHjaY2BgYGaAYBkGRgYQSAHyGMF8FgYPIM3HwMHAxMDGoMCwQIFLQV8hXvXP//9AcRCfAcb///h/ygPW+w/vb7olBjUHCTCyMcAFGZmABBO6AogThgZgIUsXAEDcEzcAAHjaY2BgECMCyoEgACZaAed42mNgYmRgYGBnYGNgYAZSDJqMgorCgoqCjECRXwwNrCAKSP5mAAFGBiRgyAAAi/YFBQAAeNqtkc1OwkAUhU/5M25cEhcsZick0AwlBJq6MWwgJkAgYV/KAA2lJeUn+hY+gktXvpKv4dLTMqKycGHsTZNv7px7z50ZAFd4hYHjdw1Ls4EiHjVncIFnzVnc4F1zDkWjrzmPW+NNcwGlzIRKI3fJlUyrEjZQxb3mDH2fNGfRx4vmHKqG0JzHg6E0F9DOlFBGBxUI1GEzLNT4S0aLuTtsGAEUuYcQHkyg3KmIum1bNUvKlrjbbAIleqHHnS4iSudpQcySMYtdFiXlAxzSbAwfMxK6kZoHKhbjjespMTioOPZnzI+4ucCeTVyKMVKLfeAS6vSWaTinuZwzyy/Dc7vaed+6KaV0kukdPUk6yOcctZPvvxxqksq2lEW8RvHjMEO2FCl/zy6p3NEm0R9OFSafJdldc4QVeyaaObMBO0/5cCaa6d9Ggyubxire+lEojscdjoWUR1xGOy8KD8mG2ZLO2l2paDc3A39qmU2z2W5YNv5+u79e6QfGJY/hAAB42m3NywrCMBQE0DupWp/1AYI7/6DEaLQu66Mrd35BKUWKJSlFv1+rue4cGM7shgR981qSon+ZNwUJ8iDgoYU2OvDRRQ99DDDECAHGmGCKmf80hZSx/Kik/LliFbtmN6xmt+yOjdg9GztV4tROnRwX/Bsaaw51nt4Lc7tWaZYHp/MlzKx51LZs5htNri+2AAAAAQAB//8AD3jaY2BkYGDgAWIxIGZiYARCESBmAfMYAAR6AEMAAAABAAAAANXtRbgAAAAA2AhRFAAAAADYCNuG) format("woff");
}

/* If we add the border using a regular CSS border, it won't look good on non-retina devices,
 * since its edges can look jagged due to lack of antialiasing. In this case, we are several
 * layers of box-shadow to add the border visually, which will render the border smoother. */
/* Calculates maximum width for post content */
/* Nested sub-menu padding: 10 levels deep */
/* Ensure all font family declarations come with non-latin fallbacks */
/* Build our non-latin font styles */
body:lang(ar), button:lang(ar),
input:lang(ar),
select:lang(ar),
optgroup:lang(ar),
textarea:lang(ar), .author-description .author-link:lang(ar),
.comment-metadata:lang(ar),
.comment-reply-link:lang(ar),
.comments-title:lang(ar),
.comment-author .fn:lang(ar),
.discussion-meta-info:lang(ar),
.entry-meta:lang(ar),
.entry-footer:lang(ar),
.main-navigation:lang(ar),
.no-comments:lang(ar),
.not-found .page-title:lang(ar),
.error-404 .page-title:lang(ar),
.post-navigation .post-title:lang(ar),
.page-links:lang(ar),
.page-description:lang(ar),
.pagination .nav-links:lang(ar),
.sticky-post:lang(ar),
.site-title:lang(ar),
.site-info:lang(ar),
#cancel-comment-reply-link:lang(ar),
h1:lang(ar),
h2:lang(ar),
h3:lang(ar),
h4:lang(ar),
h5:lang(ar),
h6:lang(ar), .page-title:lang(ar), blockquote cite:lang(ar), table:lang(ar), .button:lang(ar),
input:lang(ar)[type="button"],
input:lang(ar)[type="reset"],
input:lang(ar)[type="submit"], .comment-navigation .nav-previous:lang(ar),
.comment-navigation .nav-next:lang(ar), .comment-list .pingback .comment-body:lang(ar),
.comment-list .trackback .comment-body:lang(ar), .comment-list .pingback .comment-body .comment-edit-link:lang(ar),
.comment-list .trackback .comment-body .comment-edit-link:lang(ar), .comment-form .comment-notes:lang(ar),
.comment-form label:lang(ar), .widget_archive ul li:lang(ar),
.widget_categories ul li:lang(ar),
.widget_meta ul li:lang(ar),
.widget_nav_menu ul li:lang(ar),
.widget_pages ul li:lang(ar),
.widget_recent_comments ul li:lang(ar),
.widget_recent_entries ul li:lang(ar),
.widget_rss ul li:lang(ar), .widget_tag_cloud .tagcloud:lang(ar), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ar), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ar), .entry .entry-content .wp-block-archives li > a:lang(ar),
.entry .entry-content .wp-block-categories li > a:lang(ar),
.entry .entry-content .wp-block-latest-posts li > a:lang(ar), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ar), .entry .entry-content .wp-block-verse:lang(ar), .entry .entry-content .has-drop-cap:lang(ar):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ar), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ar),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ar),
.entry .entry-content .wp-block-cover-image h2:lang(ar),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ar),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ar),
.entry .entry-content .wp-block-cover h2:lang(ar), .entry .entry-content .wp-block-audio figcaption:lang(ar),
.entry .entry-content .wp-block-video figcaption:lang(ar),
.entry .entry-content .wp-block-image figcaption:lang(ar),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ar),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ar), .entry .entry-content .wp-block-file:lang(ar), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ar), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ar), .wp-caption-text:lang(ar), .gallery-caption:lang(ar) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(ary), button:lang(ary),
input:lang(ary),
select:lang(ary),
optgroup:lang(ary),
textarea:lang(ary), .author-description .author-link:lang(ary),
.comment-metadata:lang(ary),
.comment-reply-link:lang(ary),
.comments-title:lang(ary),
.comment-author .fn:lang(ary),
.discussion-meta-info:lang(ary),
.entry-meta:lang(ary),
.entry-footer:lang(ary),
.main-navigation:lang(ary),
.no-comments:lang(ary),
.not-found .page-title:lang(ary),
.error-404 .page-title:lang(ary),
.post-navigation .post-title:lang(ary),
.page-links:lang(ary),
.page-description:lang(ary),
.pagination .nav-links:lang(ary),
.sticky-post:lang(ary),
.site-title:lang(ary),
.site-info:lang(ary),
#cancel-comment-reply-link:lang(ary),
h1:lang(ary),
h2:lang(ary),
h3:lang(ary),
h4:lang(ary),
h5:lang(ary),
h6:lang(ary), .page-title:lang(ary), blockquote cite:lang(ary), table:lang(ary), .button:lang(ary),
input:lang(ary)[type="button"],
input:lang(ary)[type="reset"],
input:lang(ary)[type="submit"], .comment-navigation .nav-previous:lang(ary),
.comment-navigation .nav-next:lang(ary), .comment-list .pingback .comment-body:lang(ary),
.comment-list .trackback .comment-body:lang(ary), .comment-list .pingback .comment-body .comment-edit-link:lang(ary),
.comment-list .trackback .comment-body .comment-edit-link:lang(ary), .comment-form .comment-notes:lang(ary),
.comment-form label:lang(ary), .widget_archive ul li:lang(ary),
.widget_categories ul li:lang(ary),
.widget_meta ul li:lang(ary),
.widget_nav_menu ul li:lang(ary),
.widget_pages ul li:lang(ary),
.widget_recent_comments ul li:lang(ary),
.widget_recent_entries ul li:lang(ary),
.widget_rss ul li:lang(ary), .widget_tag_cloud .tagcloud:lang(ary), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ary), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ary), .entry .entry-content .wp-block-archives li > a:lang(ary),
.entry .entry-content .wp-block-categories li > a:lang(ary),
.entry .entry-content .wp-block-latest-posts li > a:lang(ary), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ary), .entry .entry-content .wp-block-verse:lang(ary), .entry .entry-content .has-drop-cap:lang(ary):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ary), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ary),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ary),
.entry .entry-content .wp-block-cover-image h2:lang(ary),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ary),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ary),
.entry .entry-content .wp-block-cover h2:lang(ary), .entry .entry-content .wp-block-audio figcaption:lang(ary),
.entry .entry-content .wp-block-video figcaption:lang(ary),
.entry .entry-content .wp-block-image figcaption:lang(ary),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ary),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ary), .entry .entry-content .wp-block-file:lang(ary), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ary), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ary), .wp-caption-text:lang(ary), .gallery-caption:lang(ary) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(azb), button:lang(azb),
input:lang(azb),
select:lang(azb),
optgroup:lang(azb),
textarea:lang(azb), .author-description .author-link:lang(azb),
.comment-metadata:lang(azb),
.comment-reply-link:lang(azb),
.comments-title:lang(azb),
.comment-author .fn:lang(azb),
.discussion-meta-info:lang(azb),
.entry-meta:lang(azb),
.entry-footer:lang(azb),
.main-navigation:lang(azb),
.no-comments:lang(azb),
.not-found .page-title:lang(azb),
.error-404 .page-title:lang(azb),
.post-navigation .post-title:lang(azb),
.page-links:lang(azb),
.page-description:lang(azb),
.pagination .nav-links:lang(azb),
.sticky-post:lang(azb),
.site-title:lang(azb),
.site-info:lang(azb),
#cancel-comment-reply-link:lang(azb),
h1:lang(azb),
h2:lang(azb),
h3:lang(azb),
h4:lang(azb),
h5:lang(azb),
h6:lang(azb), .page-title:lang(azb), blockquote cite:lang(azb), table:lang(azb), .button:lang(azb),
input:lang(azb)[type="button"],
input:lang(azb)[type="reset"],
input:lang(azb)[type="submit"], .comment-navigation .nav-previous:lang(azb),
.comment-navigation .nav-next:lang(azb), .comment-list .pingback .comment-body:lang(azb),
.comment-list .trackback .comment-body:lang(azb), .comment-list .pingback .comment-body .comment-edit-link:lang(azb),
.comment-list .trackback .comment-body .comment-edit-link:lang(azb), .comment-form .comment-notes:lang(azb),
.comment-form label:lang(azb), .widget_archive ul li:lang(azb),
.widget_categories ul li:lang(azb),
.widget_meta ul li:lang(azb),
.widget_nav_menu ul li:lang(azb),
.widget_pages ul li:lang(azb),
.widget_recent_comments ul li:lang(azb),
.widget_recent_entries ul li:lang(azb),
.widget_rss ul li:lang(azb), .widget_tag_cloud .tagcloud:lang(azb), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(azb), .entry .entry-content .wp-block-button .wp-block-button__link:lang(azb), .entry .entry-content .wp-block-archives li > a:lang(azb),
.entry .entry-content .wp-block-categories li > a:lang(azb),
.entry .entry-content .wp-block-latest-posts li > a:lang(azb), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(azb), .entry .entry-content .wp-block-verse:lang(azb), .entry .entry-content .has-drop-cap:lang(azb):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(azb), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(azb),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(azb),
.entry .entry-content .wp-block-cover-image h2:lang(azb),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(azb),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(azb),
.entry .entry-content .wp-block-cover h2:lang(azb), .entry .entry-content .wp-block-audio figcaption:lang(azb),
.entry .entry-content .wp-block-video figcaption:lang(azb),
.entry .entry-content .wp-block-image figcaption:lang(azb),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(azb),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(azb), .entry .entry-content .wp-block-file:lang(azb), .entry .entry-content .wp-block-file .wp-block-file__button:lang(azb), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(azb), .wp-caption-text:lang(azb), .gallery-caption:lang(azb) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(ckb), button:lang(ckb),
input:lang(ckb),
select:lang(ckb),
optgroup:lang(ckb),
textarea:lang(ckb), .author-description .author-link:lang(ckb),
.comment-metadata:lang(ckb),
.comment-reply-link:lang(ckb),
.comments-title:lang(ckb),
.comment-author .fn:lang(ckb),
.discussion-meta-info:lang(ckb),
.entry-meta:lang(ckb),
.entry-footer:lang(ckb),
.main-navigation:lang(ckb),
.no-comments:lang(ckb),
.not-found .page-title:lang(ckb),
.error-404 .page-title:lang(ckb),
.post-navigation .post-title:lang(ckb),
.page-links:lang(ckb),
.page-description:lang(ckb),
.pagination .nav-links:lang(ckb),
.sticky-post:lang(ckb),
.site-title:lang(ckb),
.site-info:lang(ckb),
#cancel-comment-reply-link:lang(ckb),
h1:lang(ckb),
h2:lang(ckb),
h3:lang(ckb),
h4:lang(ckb),
h5:lang(ckb),
h6:lang(ckb), .page-title:lang(ckb), blockquote cite:lang(ckb), table:lang(ckb), .button:lang(ckb),
input:lang(ckb)[type="button"],
input:lang(ckb)[type="reset"],
input:lang(ckb)[type="submit"], .comment-navigation .nav-previous:lang(ckb),
.comment-navigation .nav-next:lang(ckb), .comment-list .pingback .comment-body:lang(ckb),
.comment-list .trackback .comment-body:lang(ckb), .comment-list .pingback .comment-body .comment-edit-link:lang(ckb),
.comment-list .trackback .comment-body .comment-edit-link:lang(ckb), .comment-form .comment-notes:lang(ckb),
.comment-form label:lang(ckb), .widget_archive ul li:lang(ckb),
.widget_categories ul li:lang(ckb),
.widget_meta ul li:lang(ckb),
.widget_nav_menu ul li:lang(ckb),
.widget_pages ul li:lang(ckb),
.widget_recent_comments ul li:lang(ckb),
.widget_recent_entries ul li:lang(ckb),
.widget_rss ul li:lang(ckb), .widget_tag_cloud .tagcloud:lang(ckb), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ckb), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ckb), .entry .entry-content .wp-block-archives li > a:lang(ckb),
.entry .entry-content .wp-block-categories li > a:lang(ckb),
.entry .entry-content .wp-block-latest-posts li > a:lang(ckb), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ckb), .entry .entry-content .wp-block-verse:lang(ckb), .entry .entry-content .has-drop-cap:lang(ckb):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ckb), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ckb),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ckb),
.entry .entry-content .wp-block-cover-image h2:lang(ckb),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ckb),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ckb),
.entry .entry-content .wp-block-cover h2:lang(ckb), .entry .entry-content .wp-block-audio figcaption:lang(ckb),
.entry .entry-content .wp-block-video figcaption:lang(ckb),
.entry .entry-content .wp-block-image figcaption:lang(ckb),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ckb),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ckb), .entry .entry-content .wp-block-file:lang(ckb), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ckb), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ckb), .wp-caption-text:lang(ckb), .gallery-caption:lang(ckb) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(fa-IR), button:lang(fa-IR),
input:lang(fa-IR),
select:lang(fa-IR),
optgroup:lang(fa-IR),
textarea:lang(fa-IR), .author-description .author-link:lang(fa-IR),
.comment-metadata:lang(fa-IR),
.comment-reply-link:lang(fa-IR),
.comments-title:lang(fa-IR),
.comment-author .fn:lang(fa-IR),
.discussion-meta-info:lang(fa-IR),
.entry-meta:lang(fa-IR),
.entry-footer:lang(fa-IR),
.main-navigation:lang(fa-IR),
.no-comments:lang(fa-IR),
.not-found .page-title:lang(fa-IR),
.error-404 .page-title:lang(fa-IR),
.post-navigation .post-title:lang(fa-IR),
.page-links:lang(fa-IR),
.page-description:lang(fa-IR),
.pagination .nav-links:lang(fa-IR),
.sticky-post:lang(fa-IR),
.site-title:lang(fa-IR),
.site-info:lang(fa-IR),
#cancel-comment-reply-link:lang(fa-IR),
h1:lang(fa-IR),
h2:lang(fa-IR),
h3:lang(fa-IR),
h4:lang(fa-IR),
h5:lang(fa-IR),
h6:lang(fa-IR), .page-title:lang(fa-IR), blockquote cite:lang(fa-IR), table:lang(fa-IR), .button:lang(fa-IR),
input:lang(fa-IR)[type="button"],
input:lang(fa-IR)[type="reset"],
input:lang(fa-IR)[type="submit"], .comment-navigation .nav-previous:lang(fa-IR),
.comment-navigation .nav-next:lang(fa-IR), .comment-list .pingback .comment-body:lang(fa-IR),
.comment-list .trackback .comment-body:lang(fa-IR), .comment-list .pingback .comment-body .comment-edit-link:lang(fa-IR),
.comment-list .trackback .comment-body .comment-edit-link:lang(fa-IR), .comment-form .comment-notes:lang(fa-IR),
.comment-form label:lang(fa-IR), .widget_archive ul li:lang(fa-IR),
.widget_categories ul li:lang(fa-IR),
.widget_meta ul li:lang(fa-IR),
.widget_nav_menu ul li:lang(fa-IR),
.widget_pages ul li:lang(fa-IR),
.widget_recent_comments ul li:lang(fa-IR),
.widget_recent_entries ul li:lang(fa-IR),
.widget_rss ul li:lang(fa-IR), .widget_tag_cloud .tagcloud:lang(fa-IR), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(fa-IR), .entry .entry-content .wp-block-button .wp-block-button__link:lang(fa-IR), .entry .entry-content .wp-block-archives li > a:lang(fa-IR),
.entry .entry-content .wp-block-categories li > a:lang(fa-IR),
.entry .entry-content .wp-block-latest-posts li > a:lang(fa-IR), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(fa-IR), .entry .entry-content .wp-block-verse:lang(fa-IR), .entry .entry-content .has-drop-cap:lang(fa-IR):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(fa-IR), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(fa-IR),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(fa-IR),
.entry .entry-content .wp-block-cover-image h2:lang(fa-IR),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(fa-IR),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(fa-IR),
.entry .entry-content .wp-block-cover h2:lang(fa-IR), .entry .entry-content .wp-block-audio figcaption:lang(fa-IR),
.entry .entry-content .wp-block-video figcaption:lang(fa-IR),
.entry .entry-content .wp-block-image figcaption:lang(fa-IR),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(fa-IR),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(fa-IR), .entry .entry-content .wp-block-file:lang(fa-IR), .entry .entry-content .wp-block-file .wp-block-file__button:lang(fa-IR), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(fa-IR), .wp-caption-text:lang(fa-IR), .gallery-caption:lang(fa-IR) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(haz), button:lang(haz),
input:lang(haz),
select:lang(haz),
optgroup:lang(haz),
textarea:lang(haz), .author-description .author-link:lang(haz),
.comment-metadata:lang(haz),
.comment-reply-link:lang(haz),
.comments-title:lang(haz),
.comment-author .fn:lang(haz),
.discussion-meta-info:lang(haz),
.entry-meta:lang(haz),
.entry-footer:lang(haz),
.main-navigation:lang(haz),
.no-comments:lang(haz),
.not-found .page-title:lang(haz),
.error-404 .page-title:lang(haz),
.post-navigation .post-title:lang(haz),
.page-links:lang(haz),
.page-description:lang(haz),
.pagination .nav-links:lang(haz),
.sticky-post:lang(haz),
.site-title:lang(haz),
.site-info:lang(haz),
#cancel-comment-reply-link:lang(haz),
h1:lang(haz),
h2:lang(haz),
h3:lang(haz),
h4:lang(haz),
h5:lang(haz),
h6:lang(haz), .page-title:lang(haz), blockquote cite:lang(haz), table:lang(haz), .button:lang(haz),
input:lang(haz)[type="button"],
input:lang(haz)[type="reset"],
input:lang(haz)[type="submit"], .comment-navigation .nav-previous:lang(haz),
.comment-navigation .nav-next:lang(haz), .comment-list .pingback .comment-body:lang(haz),
.comment-list .trackback .comment-body:lang(haz), .comment-list .pingback .comment-body .comment-edit-link:lang(haz),
.comment-list .trackback .comment-body .comment-edit-link:lang(haz), .comment-form .comment-notes:lang(haz),
.comment-form label:lang(haz), .widget_archive ul li:lang(haz),
.widget_categories ul li:lang(haz),
.widget_meta ul li:lang(haz),
.widget_nav_menu ul li:lang(haz),
.widget_pages ul li:lang(haz),
.widget_recent_comments ul li:lang(haz),
.widget_recent_entries ul li:lang(haz),
.widget_rss ul li:lang(haz), .widget_tag_cloud .tagcloud:lang(haz), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(haz), .entry .entry-content .wp-block-button .wp-block-button__link:lang(haz), .entry .entry-content .wp-block-archives li > a:lang(haz),
.entry .entry-content .wp-block-categories li > a:lang(haz),
.entry .entry-content .wp-block-latest-posts li > a:lang(haz), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(haz), .entry .entry-content .wp-block-verse:lang(haz), .entry .entry-content .has-drop-cap:lang(haz):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(haz), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(haz),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(haz),
.entry .entry-content .wp-block-cover-image h2:lang(haz),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(haz),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(haz),
.entry .entry-content .wp-block-cover h2:lang(haz), .entry .entry-content .wp-block-audio figcaption:lang(haz),
.entry .entry-content .wp-block-video figcaption:lang(haz),
.entry .entry-content .wp-block-image figcaption:lang(haz),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(haz),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(haz), .entry .entry-content .wp-block-file:lang(haz), .entry .entry-content .wp-block-file .wp-block-file__button:lang(haz), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(haz), .wp-caption-text:lang(haz), .gallery-caption:lang(haz) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(ps), button:lang(ps),
input:lang(ps),
select:lang(ps),
optgroup:lang(ps),
textarea:lang(ps), .author-description .author-link:lang(ps),
.comment-metadata:lang(ps),
.comment-reply-link:lang(ps),
.comments-title:lang(ps),
.comment-author .fn:lang(ps),
.discussion-meta-info:lang(ps),
.entry-meta:lang(ps),
.entry-footer:lang(ps),
.main-navigation:lang(ps),
.no-comments:lang(ps),
.not-found .page-title:lang(ps),
.error-404 .page-title:lang(ps),
.post-navigation .post-title:lang(ps),
.page-links:lang(ps),
.page-description:lang(ps),
.pagination .nav-links:lang(ps),
.sticky-post:lang(ps),
.site-title:lang(ps),
.site-info:lang(ps),
#cancel-comment-reply-link:lang(ps),
h1:lang(ps),
h2:lang(ps),
h3:lang(ps),
h4:lang(ps),
h5:lang(ps),
h6:lang(ps), .page-title:lang(ps), blockquote cite:lang(ps), table:lang(ps), .button:lang(ps),
input:lang(ps)[type="button"],
input:lang(ps)[type="reset"],
input:lang(ps)[type="submit"], .comment-navigation .nav-previous:lang(ps),
.comment-navigation .nav-next:lang(ps), .comment-list .pingback .comment-body:lang(ps),
.comment-list .trackback .comment-body:lang(ps), .comment-list .pingback .comment-body .comment-edit-link:lang(ps),
.comment-list .trackback .comment-body .comment-edit-link:lang(ps), .comment-form .comment-notes:lang(ps),
.comment-form label:lang(ps), .widget_archive ul li:lang(ps),
.widget_categories ul li:lang(ps),
.widget_meta ul li:lang(ps),
.widget_nav_menu ul li:lang(ps),
.widget_pages ul li:lang(ps),
.widget_recent_comments ul li:lang(ps),
.widget_recent_entries ul li:lang(ps),
.widget_rss ul li:lang(ps), .widget_tag_cloud .tagcloud:lang(ps), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ps), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ps), .entry .entry-content .wp-block-archives li > a:lang(ps),
.entry .entry-content .wp-block-categories li > a:lang(ps),
.entry .entry-content .wp-block-latest-posts li > a:lang(ps), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ps), .entry .entry-content .wp-block-verse:lang(ps), .entry .entry-content .has-drop-cap:lang(ps):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ps), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ps),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ps),
.entry .entry-content .wp-block-cover-image h2:lang(ps),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ps),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ps),
.entry .entry-content .wp-block-cover h2:lang(ps), .entry .entry-content .wp-block-audio figcaption:lang(ps),
.entry .entry-content .wp-block-video figcaption:lang(ps),
.entry .entry-content .wp-block-image figcaption:lang(ps),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ps),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ps), .entry .entry-content .wp-block-file:lang(ps), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ps), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ps), .wp-caption-text:lang(ps), .gallery-caption:lang(ps) {
  font-family: Tahoma, Arial, sans-serif;
}

body:lang(be), button:lang(be),
input:lang(be),
select:lang(be),
optgroup:lang(be),
textarea:lang(be), .author-description .author-link:lang(be),
.comment-metadata:lang(be),
.comment-reply-link:lang(be),
.comments-title:lang(be),
.comment-author .fn:lang(be),
.discussion-meta-info:lang(be),
.entry-meta:lang(be),
.entry-footer:lang(be),
.main-navigation:lang(be),
.no-comments:lang(be),
.not-found .page-title:lang(be),
.error-404 .page-title:lang(be),
.post-navigation .post-title:lang(be),
.page-links:lang(be),
.page-description:lang(be),
.pagination .nav-links:lang(be),
.sticky-post:lang(be),
.site-title:lang(be),
.site-info:lang(be),
#cancel-comment-reply-link:lang(be),
h1:lang(be),
h2:lang(be),
h3:lang(be),
h4:lang(be),
h5:lang(be),
h6:lang(be), .page-title:lang(be), blockquote cite:lang(be), table:lang(be), .button:lang(be),
input:lang(be)[type="button"],
input:lang(be)[type="reset"],
input:lang(be)[type="submit"], .comment-navigation .nav-previous:lang(be),
.comment-navigation .nav-next:lang(be), .comment-list .pingback .comment-body:lang(be),
.comment-list .trackback .comment-body:lang(be), .comment-list .pingback .comment-body .comment-edit-link:lang(be),
.comment-list .trackback .comment-body .comment-edit-link:lang(be), .comment-form .comment-notes:lang(be),
.comment-form label:lang(be), .widget_archive ul li:lang(be),
.widget_categories ul li:lang(be),
.widget_meta ul li:lang(be),
.widget_nav_menu ul li:lang(be),
.widget_pages ul li:lang(be),
.widget_recent_comments ul li:lang(be),
.widget_recent_entries ul li:lang(be),
.widget_rss ul li:lang(be), .widget_tag_cloud .tagcloud:lang(be), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(be), .entry .entry-content .wp-block-button .wp-block-button__link:lang(be), .entry .entry-content .wp-block-archives li > a:lang(be),
.entry .entry-content .wp-block-categories li > a:lang(be),
.entry .entry-content .wp-block-latest-posts li > a:lang(be), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(be), .entry .entry-content .wp-block-verse:lang(be), .entry .entry-content .has-drop-cap:lang(be):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(be), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(be),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(be),
.entry .entry-content .wp-block-cover-image h2:lang(be),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(be),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(be),
.entry .entry-content .wp-block-cover h2:lang(be), .entry .entry-content .wp-block-audio figcaption:lang(be),
.entry .entry-content .wp-block-video figcaption:lang(be),
.entry .entry-content .wp-block-image figcaption:lang(be),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(be),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(be), .entry .entry-content .wp-block-file:lang(be), .entry .entry-content .wp-block-file .wp-block-file__button:lang(be), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(be), .wp-caption-text:lang(be), .gallery-caption:lang(be) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(bg-BG), button:lang(bg-BG),
input:lang(bg-BG),
select:lang(bg-BG),
optgroup:lang(bg-BG),
textarea:lang(bg-BG), .author-description .author-link:lang(bg-BG),
.comment-metadata:lang(bg-BG),
.comment-reply-link:lang(bg-BG),
.comments-title:lang(bg-BG),
.comment-author .fn:lang(bg-BG),
.discussion-meta-info:lang(bg-BG),
.entry-meta:lang(bg-BG),
.entry-footer:lang(bg-BG),
.main-navigation:lang(bg-BG),
.no-comments:lang(bg-BG),
.not-found .page-title:lang(bg-BG),
.error-404 .page-title:lang(bg-BG),
.post-navigation .post-title:lang(bg-BG),
.page-links:lang(bg-BG),
.page-description:lang(bg-BG),
.pagination .nav-links:lang(bg-BG),
.sticky-post:lang(bg-BG),
.site-title:lang(bg-BG),
.site-info:lang(bg-BG),
#cancel-comment-reply-link:lang(bg-BG),
h1:lang(bg-BG),
h2:lang(bg-BG),
h3:lang(bg-BG),
h4:lang(bg-BG),
h5:lang(bg-BG),
h6:lang(bg-BG), .page-title:lang(bg-BG), blockquote cite:lang(bg-BG), table:lang(bg-BG), .button:lang(bg-BG),
input:lang(bg-BG)[type="button"],
input:lang(bg-BG)[type="reset"],
input:lang(bg-BG)[type="submit"], .comment-navigation .nav-previous:lang(bg-BG),
.comment-navigation .nav-next:lang(bg-BG), .comment-list .pingback .comment-body:lang(bg-BG),
.comment-list .trackback .comment-body:lang(bg-BG), .comment-list .pingback .comment-body .comment-edit-link:lang(bg-BG),
.comment-list .trackback .comment-body .comment-edit-link:lang(bg-BG), .comment-form .comment-notes:lang(bg-BG),
.comment-form label:lang(bg-BG), .widget_archive ul li:lang(bg-BG),
.widget_categories ul li:lang(bg-BG),
.widget_meta ul li:lang(bg-BG),
.widget_nav_menu ul li:lang(bg-BG),
.widget_pages ul li:lang(bg-BG),
.widget_recent_comments ul li:lang(bg-BG),
.widget_recent_entries ul li:lang(bg-BG),
.widget_rss ul li:lang(bg-BG), .widget_tag_cloud .tagcloud:lang(bg-BG), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(bg-BG), .entry .entry-content .wp-block-button .wp-block-button__link:lang(bg-BG), .entry .entry-content .wp-block-archives li > a:lang(bg-BG),
.entry .entry-content .wp-block-categories li > a:lang(bg-BG),
.entry .entry-content .wp-block-latest-posts li > a:lang(bg-BG), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(bg-BG), .entry .entry-content .wp-block-verse:lang(bg-BG), .entry .entry-content .has-drop-cap:lang(bg-BG):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(bg-BG), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(bg-BG),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(bg-BG),
.entry .entry-content .wp-block-cover-image h2:lang(bg-BG),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(bg-BG),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(bg-BG),
.entry .entry-content .wp-block-cover h2:lang(bg-BG), .entry .entry-content .wp-block-audio figcaption:lang(bg-BG),
.entry .entry-content .wp-block-video figcaption:lang(bg-BG),
.entry .entry-content .wp-block-image figcaption:lang(bg-BG),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(bg-BG),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(bg-BG), .entry .entry-content .wp-block-file:lang(bg-BG), .entry .entry-content .wp-block-file .wp-block-file__button:lang(bg-BG), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(bg-BG), .wp-caption-text:lang(bg-BG), .gallery-caption:lang(bg-BG) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(kk), button:lang(kk),
input:lang(kk),
select:lang(kk),
optgroup:lang(kk),
textarea:lang(kk), .author-description .author-link:lang(kk),
.comment-metadata:lang(kk),
.comment-reply-link:lang(kk),
.comments-title:lang(kk),
.comment-author .fn:lang(kk),
.discussion-meta-info:lang(kk),
.entry-meta:lang(kk),
.entry-footer:lang(kk),
.main-navigation:lang(kk),
.no-comments:lang(kk),
.not-found .page-title:lang(kk),
.error-404 .page-title:lang(kk),
.post-navigation .post-title:lang(kk),
.page-links:lang(kk),
.page-description:lang(kk),
.pagination .nav-links:lang(kk),
.sticky-post:lang(kk),
.site-title:lang(kk),
.site-info:lang(kk),
#cancel-comment-reply-link:lang(kk),
h1:lang(kk),
h2:lang(kk),
h3:lang(kk),
h4:lang(kk),
h5:lang(kk),
h6:lang(kk), .page-title:lang(kk), blockquote cite:lang(kk), table:lang(kk), .button:lang(kk),
input:lang(kk)[type="button"],
input:lang(kk)[type="reset"],
input:lang(kk)[type="submit"], .comment-navigation .nav-previous:lang(kk),
.comment-navigation .nav-next:lang(kk), .comment-list .pingback .comment-body:lang(kk),
.comment-list .trackback .comment-body:lang(kk), .comment-list .pingback .comment-body .comment-edit-link:lang(kk),
.comment-list .trackback .comment-body .comment-edit-link:lang(kk), .comment-form .comment-notes:lang(kk),
.comment-form label:lang(kk), .widget_archive ul li:lang(kk),
.widget_categories ul li:lang(kk),
.widget_meta ul li:lang(kk),
.widget_nav_menu ul li:lang(kk),
.widget_pages ul li:lang(kk),
.widget_recent_comments ul li:lang(kk),
.widget_recent_entries ul li:lang(kk),
.widget_rss ul li:lang(kk), .widget_tag_cloud .tagcloud:lang(kk), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(kk), .entry .entry-content .wp-block-button .wp-block-button__link:lang(kk), .entry .entry-content .wp-block-archives li > a:lang(kk),
.entry .entry-content .wp-block-categories li > a:lang(kk),
.entry .entry-content .wp-block-latest-posts li > a:lang(kk), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(kk), .entry .entry-content .wp-block-verse:lang(kk), .entry .entry-content .has-drop-cap:lang(kk):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(kk), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(kk),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(kk),
.entry .entry-content .wp-block-cover-image h2:lang(kk),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(kk),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(kk),
.entry .entry-content .wp-block-cover h2:lang(kk), .entry .entry-content .wp-block-audio figcaption:lang(kk),
.entry .entry-content .wp-block-video figcaption:lang(kk),
.entry .entry-content .wp-block-image figcaption:lang(kk),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(kk),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(kk), .entry .entry-content .wp-block-file:lang(kk), .entry .entry-content .wp-block-file .wp-block-file__button:lang(kk), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(kk), .wp-caption-text:lang(kk), .gallery-caption:lang(kk) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(mk-MK), button:lang(mk-MK),
input:lang(mk-MK),
select:lang(mk-MK),
optgroup:lang(mk-MK),
textarea:lang(mk-MK), .author-description .author-link:lang(mk-MK),
.comment-metadata:lang(mk-MK),
.comment-reply-link:lang(mk-MK),
.comments-title:lang(mk-MK),
.comment-author .fn:lang(mk-MK),
.discussion-meta-info:lang(mk-MK),
.entry-meta:lang(mk-MK),
.entry-footer:lang(mk-MK),
.main-navigation:lang(mk-MK),
.no-comments:lang(mk-MK),
.not-found .page-title:lang(mk-MK),
.error-404 .page-title:lang(mk-MK),
.post-navigation .post-title:lang(mk-MK),
.page-links:lang(mk-MK),
.page-description:lang(mk-MK),
.pagination .nav-links:lang(mk-MK),
.sticky-post:lang(mk-MK),
.site-title:lang(mk-MK),
.site-info:lang(mk-MK),
#cancel-comment-reply-link:lang(mk-MK),
h1:lang(mk-MK),
h2:lang(mk-MK),
h3:lang(mk-MK),
h4:lang(mk-MK),
h5:lang(mk-MK),
h6:lang(mk-MK), .page-title:lang(mk-MK), blockquote cite:lang(mk-MK), table:lang(mk-MK), .button:lang(mk-MK),
input:lang(mk-MK)[type="button"],
input:lang(mk-MK)[type="reset"],
input:lang(mk-MK)[type="submit"], .comment-navigation .nav-previous:lang(mk-MK),
.comment-navigation .nav-next:lang(mk-MK), .comment-list .pingback .comment-body:lang(mk-MK),
.comment-list .trackback .comment-body:lang(mk-MK), .comment-list .pingback .comment-body .comment-edit-link:lang(mk-MK),
.comment-list .trackback .comment-body .comment-edit-link:lang(mk-MK), .comment-form .comment-notes:lang(mk-MK),
.comment-form label:lang(mk-MK), .widget_archive ul li:lang(mk-MK),
.widget_categories ul li:lang(mk-MK),
.widget_meta ul li:lang(mk-MK),
.widget_nav_menu ul li:lang(mk-MK),
.widget_pages ul li:lang(mk-MK),
.widget_recent_comments ul li:lang(mk-MK),
.widget_recent_entries ul li:lang(mk-MK),
.widget_rss ul li:lang(mk-MK), .widget_tag_cloud .tagcloud:lang(mk-MK), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(mk-MK), .entry .entry-content .wp-block-button .wp-block-button__link:lang(mk-MK), .entry .entry-content .wp-block-archives li > a:lang(mk-MK),
.entry .entry-content .wp-block-categories li > a:lang(mk-MK),
.entry .entry-content .wp-block-latest-posts li > a:lang(mk-MK), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(mk-MK), .entry .entry-content .wp-block-verse:lang(mk-MK), .entry .entry-content .has-drop-cap:lang(mk-MK):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(mk-MK), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(mk-MK),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(mk-MK),
.entry .entry-content .wp-block-cover-image h2:lang(mk-MK),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(mk-MK),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(mk-MK),
.entry .entry-content .wp-block-cover h2:lang(mk-MK), .entry .entry-content .wp-block-audio figcaption:lang(mk-MK),
.entry .entry-content .wp-block-video figcaption:lang(mk-MK),
.entry .entry-content .wp-block-image figcaption:lang(mk-MK),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(mk-MK),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(mk-MK), .entry .entry-content .wp-block-file:lang(mk-MK), .entry .entry-content .wp-block-file .wp-block-file__button:lang(mk-MK), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(mk-MK), .wp-caption-text:lang(mk-MK), .gallery-caption:lang(mk-MK) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(mn), button:lang(mn),
input:lang(mn),
select:lang(mn),
optgroup:lang(mn),
textarea:lang(mn), .author-description .author-link:lang(mn),
.comment-metadata:lang(mn),
.comment-reply-link:lang(mn),
.comments-title:lang(mn),
.comment-author .fn:lang(mn),
.discussion-meta-info:lang(mn),
.entry-meta:lang(mn),
.entry-footer:lang(mn),
.main-navigation:lang(mn),
.no-comments:lang(mn),
.not-found .page-title:lang(mn),
.error-404 .page-title:lang(mn),
.post-navigation .post-title:lang(mn),
.page-links:lang(mn),
.page-description:lang(mn),
.pagination .nav-links:lang(mn),
.sticky-post:lang(mn),
.site-title:lang(mn),
.site-info:lang(mn),
#cancel-comment-reply-link:lang(mn),
h1:lang(mn),
h2:lang(mn),
h3:lang(mn),
h4:lang(mn),
h5:lang(mn),
h6:lang(mn), .page-title:lang(mn), blockquote cite:lang(mn), table:lang(mn), .button:lang(mn),
input:lang(mn)[type="button"],
input:lang(mn)[type="reset"],
input:lang(mn)[type="submit"], .comment-navigation .nav-previous:lang(mn),
.comment-navigation .nav-next:lang(mn), .comment-list .pingback .comment-body:lang(mn),
.comment-list .trackback .comment-body:lang(mn), .comment-list .pingback .comment-body .comment-edit-link:lang(mn),
.comment-list .trackback .comment-body .comment-edit-link:lang(mn), .comment-form .comment-notes:lang(mn),
.comment-form label:lang(mn), .widget_archive ul li:lang(mn),
.widget_categories ul li:lang(mn),
.widget_meta ul li:lang(mn),
.widget_nav_menu ul li:lang(mn),
.widget_pages ul li:lang(mn),
.widget_recent_comments ul li:lang(mn),
.widget_recent_entries ul li:lang(mn),
.widget_rss ul li:lang(mn), .widget_tag_cloud .tagcloud:lang(mn), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(mn), .entry .entry-content .wp-block-button .wp-block-button__link:lang(mn), .entry .entry-content .wp-block-archives li > a:lang(mn),
.entry .entry-content .wp-block-categories li > a:lang(mn),
.entry .entry-content .wp-block-latest-posts li > a:lang(mn), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(mn), .entry .entry-content .wp-block-verse:lang(mn), .entry .entry-content .has-drop-cap:lang(mn):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(mn), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(mn),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(mn),
.entry .entry-content .wp-block-cover-image h2:lang(mn),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(mn),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(mn),
.entry .entry-content .wp-block-cover h2:lang(mn), .entry .entry-content .wp-block-audio figcaption:lang(mn),
.entry .entry-content .wp-block-video figcaption:lang(mn),
.entry .entry-content .wp-block-image figcaption:lang(mn),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(mn),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(mn), .entry .entry-content .wp-block-file:lang(mn), .entry .entry-content .wp-block-file .wp-block-file__button:lang(mn), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(mn), .wp-caption-text:lang(mn), .gallery-caption:lang(mn) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(ru-RU), button:lang(ru-RU),
input:lang(ru-RU),
select:lang(ru-RU),
optgroup:lang(ru-RU),
textarea:lang(ru-RU), .author-description .author-link:lang(ru-RU),
.comment-metadata:lang(ru-RU),
.comment-reply-link:lang(ru-RU),
.comments-title:lang(ru-RU),
.comment-author .fn:lang(ru-RU),
.discussion-meta-info:lang(ru-RU),
.entry-meta:lang(ru-RU),
.entry-footer:lang(ru-RU),
.main-navigation:lang(ru-RU),
.no-comments:lang(ru-RU),
.not-found .page-title:lang(ru-RU),
.error-404 .page-title:lang(ru-RU),
.post-navigation .post-title:lang(ru-RU),
.page-links:lang(ru-RU),
.page-description:lang(ru-RU),
.pagination .nav-links:lang(ru-RU),
.sticky-post:lang(ru-RU),
.site-title:lang(ru-RU),
.site-info:lang(ru-RU),
#cancel-comment-reply-link:lang(ru-RU),
h1:lang(ru-RU),
h2:lang(ru-RU),
h3:lang(ru-RU),
h4:lang(ru-RU),
h5:lang(ru-RU),
h6:lang(ru-RU), .page-title:lang(ru-RU), blockquote cite:lang(ru-RU), table:lang(ru-RU), .button:lang(ru-RU),
input:lang(ru-RU)[type="button"],
input:lang(ru-RU)[type="reset"],
input:lang(ru-RU)[type="submit"], .comment-navigation .nav-previous:lang(ru-RU),
.comment-navigation .nav-next:lang(ru-RU), .comment-list .pingback .comment-body:lang(ru-RU),
.comment-list .trackback .comment-body:lang(ru-RU), .comment-list .pingback .comment-body .comment-edit-link:lang(ru-RU),
.comment-list .trackback .comment-body .comment-edit-link:lang(ru-RU), .comment-form .comment-notes:lang(ru-RU),
.comment-form label:lang(ru-RU), .widget_archive ul li:lang(ru-RU),
.widget_categories ul li:lang(ru-RU),
.widget_meta ul li:lang(ru-RU),
.widget_nav_menu ul li:lang(ru-RU),
.widget_pages ul li:lang(ru-RU),
.widget_recent_comments ul li:lang(ru-RU),
.widget_recent_entries ul li:lang(ru-RU),
.widget_rss ul li:lang(ru-RU), .widget_tag_cloud .tagcloud:lang(ru-RU), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ru-RU), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ru-RU), .entry .entry-content .wp-block-archives li > a:lang(ru-RU),
.entry .entry-content .wp-block-categories li > a:lang(ru-RU),
.entry .entry-content .wp-block-latest-posts li > a:lang(ru-RU), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ru-RU), .entry .entry-content .wp-block-verse:lang(ru-RU), .entry .entry-content .has-drop-cap:lang(ru-RU):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ru-RU), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ru-RU),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ru-RU),
.entry .entry-content .wp-block-cover-image h2:lang(ru-RU),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ru-RU),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ru-RU),
.entry .entry-content .wp-block-cover h2:lang(ru-RU), .entry .entry-content .wp-block-audio figcaption:lang(ru-RU),
.entry .entry-content .wp-block-video figcaption:lang(ru-RU),
.entry .entry-content .wp-block-image figcaption:lang(ru-RU),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ru-RU),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ru-RU), .entry .entry-content .wp-block-file:lang(ru-RU), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ru-RU), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ru-RU), .wp-caption-text:lang(ru-RU), .gallery-caption:lang(ru-RU) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(sah), button:lang(sah),
input:lang(sah),
select:lang(sah),
optgroup:lang(sah),
textarea:lang(sah), .author-description .author-link:lang(sah),
.comment-metadata:lang(sah),
.comment-reply-link:lang(sah),
.comments-title:lang(sah),
.comment-author .fn:lang(sah),
.discussion-meta-info:lang(sah),
.entry-meta:lang(sah),
.entry-footer:lang(sah),
.main-navigation:lang(sah),
.no-comments:lang(sah),
.not-found .page-title:lang(sah),
.error-404 .page-title:lang(sah),
.post-navigation .post-title:lang(sah),
.page-links:lang(sah),
.page-description:lang(sah),
.pagination .nav-links:lang(sah),
.sticky-post:lang(sah),
.site-title:lang(sah),
.site-info:lang(sah),
#cancel-comment-reply-link:lang(sah),
h1:lang(sah),
h2:lang(sah),
h3:lang(sah),
h4:lang(sah),
h5:lang(sah),
h6:lang(sah), .page-title:lang(sah), blockquote cite:lang(sah), table:lang(sah), .button:lang(sah),
input:lang(sah)[type="button"],
input:lang(sah)[type="reset"],
input:lang(sah)[type="submit"], .comment-navigation .nav-previous:lang(sah),
.comment-navigation .nav-next:lang(sah), .comment-list .pingback .comment-body:lang(sah),
.comment-list .trackback .comment-body:lang(sah), .comment-list .pingback .comment-body .comment-edit-link:lang(sah),
.comment-list .trackback .comment-body .comment-edit-link:lang(sah), .comment-form .comment-notes:lang(sah),
.comment-form label:lang(sah), .widget_archive ul li:lang(sah),
.widget_categories ul li:lang(sah),
.widget_meta ul li:lang(sah),
.widget_nav_menu ul li:lang(sah),
.widget_pages ul li:lang(sah),
.widget_recent_comments ul li:lang(sah),
.widget_recent_entries ul li:lang(sah),
.widget_rss ul li:lang(sah), .widget_tag_cloud .tagcloud:lang(sah), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(sah), .entry .entry-content .wp-block-button .wp-block-button__link:lang(sah), .entry .entry-content .wp-block-archives li > a:lang(sah),
.entry .entry-content .wp-block-categories li > a:lang(sah),
.entry .entry-content .wp-block-latest-posts li > a:lang(sah), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(sah), .entry .entry-content .wp-block-verse:lang(sah), .entry .entry-content .has-drop-cap:lang(sah):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(sah), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(sah),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(sah),
.entry .entry-content .wp-block-cover-image h2:lang(sah),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(sah),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(sah),
.entry .entry-content .wp-block-cover h2:lang(sah), .entry .entry-content .wp-block-audio figcaption:lang(sah),
.entry .entry-content .wp-block-video figcaption:lang(sah),
.entry .entry-content .wp-block-image figcaption:lang(sah),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(sah),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(sah), .entry .entry-content .wp-block-file:lang(sah), .entry .entry-content .wp-block-file .wp-block-file__button:lang(sah), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(sah), .wp-caption-text:lang(sah), .gallery-caption:lang(sah) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(sr-RS), button:lang(sr-RS),
input:lang(sr-RS),
select:lang(sr-RS),
optgroup:lang(sr-RS),
textarea:lang(sr-RS), .author-description .author-link:lang(sr-RS),
.comment-metadata:lang(sr-RS),
.comment-reply-link:lang(sr-RS),
.comments-title:lang(sr-RS),
.comment-author .fn:lang(sr-RS),
.discussion-meta-info:lang(sr-RS),
.entry-meta:lang(sr-RS),
.entry-footer:lang(sr-RS),
.main-navigation:lang(sr-RS),
.no-comments:lang(sr-RS),
.not-found .page-title:lang(sr-RS),
.error-404 .page-title:lang(sr-RS),
.post-navigation .post-title:lang(sr-RS),
.page-links:lang(sr-RS),
.page-description:lang(sr-RS),
.pagination .nav-links:lang(sr-RS),
.sticky-post:lang(sr-RS),
.site-title:lang(sr-RS),
.site-info:lang(sr-RS),
#cancel-comment-reply-link:lang(sr-RS),
h1:lang(sr-RS),
h2:lang(sr-RS),
h3:lang(sr-RS),
h4:lang(sr-RS),
h5:lang(sr-RS),
h6:lang(sr-RS), .page-title:lang(sr-RS), blockquote cite:lang(sr-RS), table:lang(sr-RS), .button:lang(sr-RS),
input:lang(sr-RS)[type="button"],
input:lang(sr-RS)[type="reset"],
input:lang(sr-RS)[type="submit"], .comment-navigation .nav-previous:lang(sr-RS),
.comment-navigation .nav-next:lang(sr-RS), .comment-list .pingback .comment-body:lang(sr-RS),
.comment-list .trackback .comment-body:lang(sr-RS), .comment-list .pingback .comment-body .comment-edit-link:lang(sr-RS),
.comment-list .trackback .comment-body .comment-edit-link:lang(sr-RS), .comment-form .comment-notes:lang(sr-RS),
.comment-form label:lang(sr-RS), .widget_archive ul li:lang(sr-RS),
.widget_categories ul li:lang(sr-RS),
.widget_meta ul li:lang(sr-RS),
.widget_nav_menu ul li:lang(sr-RS),
.widget_pages ul li:lang(sr-RS),
.widget_recent_comments ul li:lang(sr-RS),
.widget_recent_entries ul li:lang(sr-RS),
.widget_rss ul li:lang(sr-RS), .widget_tag_cloud .tagcloud:lang(sr-RS), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(sr-RS), .entry .entry-content .wp-block-button .wp-block-button__link:lang(sr-RS), .entry .entry-content .wp-block-archives li > a:lang(sr-RS),
.entry .entry-content .wp-block-categories li > a:lang(sr-RS),
.entry .entry-content .wp-block-latest-posts li > a:lang(sr-RS), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(sr-RS), .entry .entry-content .wp-block-verse:lang(sr-RS), .entry .entry-content .has-drop-cap:lang(sr-RS):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(sr-RS), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(sr-RS),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(sr-RS),
.entry .entry-content .wp-block-cover-image h2:lang(sr-RS),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(sr-RS),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(sr-RS),
.entry .entry-content .wp-block-cover h2:lang(sr-RS), .entry .entry-content .wp-block-audio figcaption:lang(sr-RS),
.entry .entry-content .wp-block-video figcaption:lang(sr-RS),
.entry .entry-content .wp-block-image figcaption:lang(sr-RS),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(sr-RS),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(sr-RS), .entry .entry-content .wp-block-file:lang(sr-RS), .entry .entry-content .wp-block-file .wp-block-file__button:lang(sr-RS), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(sr-RS), .wp-caption-text:lang(sr-RS), .gallery-caption:lang(sr-RS) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(tt-RU), button:lang(tt-RU),
input:lang(tt-RU),
select:lang(tt-RU),
optgroup:lang(tt-RU),
textarea:lang(tt-RU), .author-description .author-link:lang(tt-RU),
.comment-metadata:lang(tt-RU),
.comment-reply-link:lang(tt-RU),
.comments-title:lang(tt-RU),
.comment-author .fn:lang(tt-RU),
.discussion-meta-info:lang(tt-RU),
.entry-meta:lang(tt-RU),
.entry-footer:lang(tt-RU),
.main-navigation:lang(tt-RU),
.no-comments:lang(tt-RU),
.not-found .page-title:lang(tt-RU),
.error-404 .page-title:lang(tt-RU),
.post-navigation .post-title:lang(tt-RU),
.page-links:lang(tt-RU),
.page-description:lang(tt-RU),
.pagination .nav-links:lang(tt-RU),
.sticky-post:lang(tt-RU),
.site-title:lang(tt-RU),
.site-info:lang(tt-RU),
#cancel-comment-reply-link:lang(tt-RU),
h1:lang(tt-RU),
h2:lang(tt-RU),
h3:lang(tt-RU),
h4:lang(tt-RU),
h5:lang(tt-RU),
h6:lang(tt-RU), .page-title:lang(tt-RU), blockquote cite:lang(tt-RU), table:lang(tt-RU), .button:lang(tt-RU),
input:lang(tt-RU)[type="button"],
input:lang(tt-RU)[type="reset"],
input:lang(tt-RU)[type="submit"], .comment-navigation .nav-previous:lang(tt-RU),
.comment-navigation .nav-next:lang(tt-RU), .comment-list .pingback .comment-body:lang(tt-RU),
.comment-list .trackback .comment-body:lang(tt-RU), .comment-list .pingback .comment-body .comment-edit-link:lang(tt-RU),
.comment-list .trackback .comment-body .comment-edit-link:lang(tt-RU), .comment-form .comment-notes:lang(tt-RU),
.comment-form label:lang(tt-RU), .widget_archive ul li:lang(tt-RU),
.widget_categories ul li:lang(tt-RU),
.widget_meta ul li:lang(tt-RU),
.widget_nav_menu ul li:lang(tt-RU),
.widget_pages ul li:lang(tt-RU),
.widget_recent_comments ul li:lang(tt-RU),
.widget_recent_entries ul li:lang(tt-RU),
.widget_rss ul li:lang(tt-RU), .widget_tag_cloud .tagcloud:lang(tt-RU), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(tt-RU), .entry .entry-content .wp-block-button .wp-block-button__link:lang(tt-RU), .entry .entry-content .wp-block-archives li > a:lang(tt-RU),
.entry .entry-content .wp-block-categories li > a:lang(tt-RU),
.entry .entry-content .wp-block-latest-posts li > a:lang(tt-RU), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(tt-RU), .entry .entry-content .wp-block-verse:lang(tt-RU), .entry .entry-content .has-drop-cap:lang(tt-RU):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(tt-RU), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(tt-RU),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(tt-RU),
.entry .entry-content .wp-block-cover-image h2:lang(tt-RU),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(tt-RU),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(tt-RU),
.entry .entry-content .wp-block-cover h2:lang(tt-RU), .entry .entry-content .wp-block-audio figcaption:lang(tt-RU),
.entry .entry-content .wp-block-video figcaption:lang(tt-RU),
.entry .entry-content .wp-block-image figcaption:lang(tt-RU),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(tt-RU),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(tt-RU), .entry .entry-content .wp-block-file:lang(tt-RU), .entry .entry-content .wp-block-file .wp-block-file__button:lang(tt-RU), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(tt-RU), .wp-caption-text:lang(tt-RU), .gallery-caption:lang(tt-RU) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(uk), button:lang(uk),
input:lang(uk),
select:lang(uk),
optgroup:lang(uk),
textarea:lang(uk), .author-description .author-link:lang(uk),
.comment-metadata:lang(uk),
.comment-reply-link:lang(uk),
.comments-title:lang(uk),
.comment-author .fn:lang(uk),
.discussion-meta-info:lang(uk),
.entry-meta:lang(uk),
.entry-footer:lang(uk),
.main-navigation:lang(uk),
.no-comments:lang(uk),
.not-found .page-title:lang(uk),
.error-404 .page-title:lang(uk),
.post-navigation .post-title:lang(uk),
.page-links:lang(uk),
.page-description:lang(uk),
.pagination .nav-links:lang(uk),
.sticky-post:lang(uk),
.site-title:lang(uk),
.site-info:lang(uk),
#cancel-comment-reply-link:lang(uk),
h1:lang(uk),
h2:lang(uk),
h3:lang(uk),
h4:lang(uk),
h5:lang(uk),
h6:lang(uk), .page-title:lang(uk), blockquote cite:lang(uk), table:lang(uk), .button:lang(uk),
input:lang(uk)[type="button"],
input:lang(uk)[type="reset"],
input:lang(uk)[type="submit"], .comment-navigation .nav-previous:lang(uk),
.comment-navigation .nav-next:lang(uk), .comment-list .pingback .comment-body:lang(uk),
.comment-list .trackback .comment-body:lang(uk), .comment-list .pingback .comment-body .comment-edit-link:lang(uk),
.comment-list .trackback .comment-body .comment-edit-link:lang(uk), .comment-form .comment-notes:lang(uk),
.comment-form label:lang(uk), .widget_archive ul li:lang(uk),
.widget_categories ul li:lang(uk),
.widget_meta ul li:lang(uk),
.widget_nav_menu ul li:lang(uk),
.widget_pages ul li:lang(uk),
.widget_recent_comments ul li:lang(uk),
.widget_recent_entries ul li:lang(uk),
.widget_rss ul li:lang(uk), .widget_tag_cloud .tagcloud:lang(uk), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(uk), .entry .entry-content .wp-block-button .wp-block-button__link:lang(uk), .entry .entry-content .wp-block-archives li > a:lang(uk),
.entry .entry-content .wp-block-categories li > a:lang(uk),
.entry .entry-content .wp-block-latest-posts li > a:lang(uk), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(uk), .entry .entry-content .wp-block-verse:lang(uk), .entry .entry-content .has-drop-cap:lang(uk):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(uk), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(uk),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(uk),
.entry .entry-content .wp-block-cover-image h2:lang(uk),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(uk),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(uk),
.entry .entry-content .wp-block-cover h2:lang(uk), .entry .entry-content .wp-block-audio figcaption:lang(uk),
.entry .entry-content .wp-block-video figcaption:lang(uk),
.entry .entry-content .wp-block-image figcaption:lang(uk),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(uk),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(uk), .entry .entry-content .wp-block-file:lang(uk), .entry .entry-content .wp-block-file .wp-block-file__button:lang(uk), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(uk), .wp-caption-text:lang(uk), .gallery-caption:lang(uk) {
  font-family: "Helvetica Neue", Helvetica, "Segoe UI", Arial, sans-serif;
}

body:lang(zh-HK), button:lang(zh-HK),
input:lang(zh-HK),
select:lang(zh-HK),
optgroup:lang(zh-HK),
textarea:lang(zh-HK), .author-description .author-link:lang(zh-HK),
.comment-metadata:lang(zh-HK),
.comment-reply-link:lang(zh-HK),
.comments-title:lang(zh-HK),
.comment-author .fn:lang(zh-HK),
.discussion-meta-info:lang(zh-HK),
.entry-meta:lang(zh-HK),
.entry-footer:lang(zh-HK),
.main-navigation:lang(zh-HK),
.no-comments:lang(zh-HK),
.not-found .page-title:lang(zh-HK),
.error-404 .page-title:lang(zh-HK),
.post-navigation .post-title:lang(zh-HK),
.page-links:lang(zh-HK),
.page-description:lang(zh-HK),
.pagination .nav-links:lang(zh-HK),
.sticky-post:lang(zh-HK),
.site-title:lang(zh-HK),
.site-info:lang(zh-HK),
#cancel-comment-reply-link:lang(zh-HK),
h1:lang(zh-HK),
h2:lang(zh-HK),
h3:lang(zh-HK),
h4:lang(zh-HK),
h5:lang(zh-HK),
h6:lang(zh-HK), .page-title:lang(zh-HK), blockquote cite:lang(zh-HK), table:lang(zh-HK), .button:lang(zh-HK),
input:lang(zh-HK)[type="button"],
input:lang(zh-HK)[type="reset"],
input:lang(zh-HK)[type="submit"], .comment-navigation .nav-previous:lang(zh-HK),
.comment-navigation .nav-next:lang(zh-HK), .comment-list .pingback .comment-body:lang(zh-HK),
.comment-list .trackback .comment-body:lang(zh-HK), .comment-list .pingback .comment-body .comment-edit-link:lang(zh-HK),
.comment-list .trackback .comment-body .comment-edit-link:lang(zh-HK), .comment-form .comment-notes:lang(zh-HK),
.comment-form label:lang(zh-HK), .widget_archive ul li:lang(zh-HK),
.widget_categories ul li:lang(zh-HK),
.widget_meta ul li:lang(zh-HK),
.widget_nav_menu ul li:lang(zh-HK),
.widget_pages ul li:lang(zh-HK),
.widget_recent_comments ul li:lang(zh-HK),
.widget_recent_entries ul li:lang(zh-HK),
.widget_rss ul li:lang(zh-HK), .widget_tag_cloud .tagcloud:lang(zh-HK), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(zh-HK), .entry .entry-content .wp-block-button .wp-block-button__link:lang(zh-HK), .entry .entry-content .wp-block-archives li > a:lang(zh-HK),
.entry .entry-content .wp-block-categories li > a:lang(zh-HK),
.entry .entry-content .wp-block-latest-posts li > a:lang(zh-HK), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(zh-HK), .entry .entry-content .wp-block-verse:lang(zh-HK), .entry .entry-content .has-drop-cap:lang(zh-HK):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(zh-HK), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(zh-HK),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(zh-HK),
.entry .entry-content .wp-block-cover-image h2:lang(zh-HK),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(zh-HK),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(zh-HK),
.entry .entry-content .wp-block-cover h2:lang(zh-HK), .entry .entry-content .wp-block-audio figcaption:lang(zh-HK),
.entry .entry-content .wp-block-video figcaption:lang(zh-HK),
.entry .entry-content .wp-block-image figcaption:lang(zh-HK),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(zh-HK),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(zh-HK), .entry .entry-content .wp-block-file:lang(zh-HK), .entry .entry-content .wp-block-file .wp-block-file__button:lang(zh-HK), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(zh-HK), .wp-caption-text:lang(zh-HK), .gallery-caption:lang(zh-HK) {
  font-family: -apple-system, BlinkMacSystemFont, "PingFang HK", "Helvetica Neue", "Microsoft YaHei New", STHeiti Light, sans-serif;
}

body:lang(zh-TW), button:lang(zh-TW),
input:lang(zh-TW),
select:lang(zh-TW),
optgroup:lang(zh-TW),
textarea:lang(zh-TW), .author-description .author-link:lang(zh-TW),
.comment-metadata:lang(zh-TW),
.comment-reply-link:lang(zh-TW),
.comments-title:lang(zh-TW),
.comment-author .fn:lang(zh-TW),
.discussion-meta-info:lang(zh-TW),
.entry-meta:lang(zh-TW),
.entry-footer:lang(zh-TW),
.main-navigation:lang(zh-TW),
.no-comments:lang(zh-TW),
.not-found .page-title:lang(zh-TW),
.error-404 .page-title:lang(zh-TW),
.post-navigation .post-title:lang(zh-TW),
.page-links:lang(zh-TW),
.page-description:lang(zh-TW),
.pagination .nav-links:lang(zh-TW),
.sticky-post:lang(zh-TW),
.site-title:lang(zh-TW),
.site-info:lang(zh-TW),
#cancel-comment-reply-link:lang(zh-TW),
h1:lang(zh-TW),
h2:lang(zh-TW),
h3:lang(zh-TW),
h4:lang(zh-TW),
h5:lang(zh-TW),
h6:lang(zh-TW), .page-title:lang(zh-TW), blockquote cite:lang(zh-TW), table:lang(zh-TW), .button:lang(zh-TW),
input:lang(zh-TW)[type="button"],
input:lang(zh-TW)[type="reset"],
input:lang(zh-TW)[type="submit"], .comment-navigation .nav-previous:lang(zh-TW),
.comment-navigation .nav-next:lang(zh-TW), .comment-list .pingback .comment-body:lang(zh-TW),
.comment-list .trackback .comment-body:lang(zh-TW), .comment-list .pingback .comment-body .comment-edit-link:lang(zh-TW),
.comment-list .trackback .comment-body .comment-edit-link:lang(zh-TW), .comment-form .comment-notes:lang(zh-TW),
.comment-form label:lang(zh-TW), .widget_archive ul li:lang(zh-TW),
.widget_categories ul li:lang(zh-TW),
.widget_meta ul li:lang(zh-TW),
.widget_nav_menu ul li:lang(zh-TW),
.widget_pages ul li:lang(zh-TW),
.widget_recent_comments ul li:lang(zh-TW),
.widget_recent_entries ul li:lang(zh-TW),
.widget_rss ul li:lang(zh-TW), .widget_tag_cloud .tagcloud:lang(zh-TW), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(zh-TW), .entry .entry-content .wp-block-button .wp-block-button__link:lang(zh-TW), .entry .entry-content .wp-block-archives li > a:lang(zh-TW),
.entry .entry-content .wp-block-categories li > a:lang(zh-TW),
.entry .entry-content .wp-block-latest-posts li > a:lang(zh-TW), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(zh-TW), .entry .entry-content .wp-block-verse:lang(zh-TW), .entry .entry-content .has-drop-cap:lang(zh-TW):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(zh-TW), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(zh-TW),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(zh-TW),
.entry .entry-content .wp-block-cover-image h2:lang(zh-TW),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(zh-TW),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(zh-TW),
.entry .entry-content .wp-block-cover h2:lang(zh-TW), .entry .entry-content .wp-block-audio figcaption:lang(zh-TW),
.entry .entry-content .wp-block-video figcaption:lang(zh-TW),
.entry .entry-content .wp-block-image figcaption:lang(zh-TW),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(zh-TW),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(zh-TW), .entry .entry-content .wp-block-file:lang(zh-TW), .entry .entry-content .wp-block-file .wp-block-file__button:lang(zh-TW), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(zh-TW), .wp-caption-text:lang(zh-TW), .gallery-caption:lang(zh-TW) {
  font-family: -apple-system, BlinkMacSystemFont, "PingFang TC", "Helvetica Neue", "Microsoft YaHei New", STHeiti Light, sans-serif;
}

body:lang(zh-CN), button:lang(zh-CN),
input:lang(zh-CN),
select:lang(zh-CN),
optgroup:lang(zh-CN),
textarea:lang(zh-CN), .author-description .author-link:lang(zh-CN),
.comment-metadata:lang(zh-CN),
.comment-reply-link:lang(zh-CN),
.comments-title:lang(zh-CN),
.comment-author .fn:lang(zh-CN),
.discussion-meta-info:lang(zh-CN),
.entry-meta:lang(zh-CN),
.entry-footer:lang(zh-CN),
.main-navigation:lang(zh-CN),
.no-comments:lang(zh-CN),
.not-found .page-title:lang(zh-CN),
.error-404 .page-title:lang(zh-CN),
.post-navigation .post-title:lang(zh-CN),
.page-links:lang(zh-CN),
.page-description:lang(zh-CN),
.pagination .nav-links:lang(zh-CN),
.sticky-post:lang(zh-CN),
.site-title:lang(zh-CN),
.site-info:lang(zh-CN),
#cancel-comment-reply-link:lang(zh-CN),
h1:lang(zh-CN),
h2:lang(zh-CN),
h3:lang(zh-CN),
h4:lang(zh-CN),
h5:lang(zh-CN),
h6:lang(zh-CN), .page-title:lang(zh-CN), blockquote cite:lang(zh-CN), table:lang(zh-CN), .button:lang(zh-CN),
input:lang(zh-CN)[type="button"],
input:lang(zh-CN)[type="reset"],
input:lang(zh-CN)[type="submit"], .comment-navigation .nav-previous:lang(zh-CN),
.comment-navigation .nav-next:lang(zh-CN), .comment-list .pingback .comment-body:lang(zh-CN),
.comment-list .trackback .comment-body:lang(zh-CN), .comment-list .pingback .comment-body .comment-edit-link:lang(zh-CN),
.comment-list .trackback .comment-body .comment-edit-link:lang(zh-CN), .comment-form .comment-notes:lang(zh-CN),
.comment-form label:lang(zh-CN), .widget_archive ul li:lang(zh-CN),
.widget_categories ul li:lang(zh-CN),
.widget_meta ul li:lang(zh-CN),
.widget_nav_menu ul li:lang(zh-CN),
.widget_pages ul li:lang(zh-CN),
.widget_recent_comments ul li:lang(zh-CN),
.widget_recent_entries ul li:lang(zh-CN),
.widget_rss ul li:lang(zh-CN), .widget_tag_cloud .tagcloud:lang(zh-CN), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(zh-CN), .entry .entry-content .wp-block-button .wp-block-button__link:lang(zh-CN), .entry .entry-content .wp-block-archives li > a:lang(zh-CN),
.entry .entry-content .wp-block-categories li > a:lang(zh-CN),
.entry .entry-content .wp-block-latest-posts li > a:lang(zh-CN), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(zh-CN), .entry .entry-content .wp-block-verse:lang(zh-CN), .entry .entry-content .has-drop-cap:lang(zh-CN):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(zh-CN), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(zh-CN),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(zh-CN),
.entry .entry-content .wp-block-cover-image h2:lang(zh-CN),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(zh-CN),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(zh-CN),
.entry .entry-content .wp-block-cover h2:lang(zh-CN), .entry .entry-content .wp-block-audio figcaption:lang(zh-CN),
.entry .entry-content .wp-block-video figcaption:lang(zh-CN),
.entry .entry-content .wp-block-image figcaption:lang(zh-CN),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(zh-CN),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(zh-CN), .entry .entry-content .wp-block-file:lang(zh-CN), .entry .entry-content .wp-block-file .wp-block-file__button:lang(zh-CN), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(zh-CN), .wp-caption-text:lang(zh-CN), .gallery-caption:lang(zh-CN) {
  font-family: -apple-system, BlinkMacSystemFont, "PingFang SC", "Helvetica Neue", "Microsoft YaHei New", STHeiti Light, sans-serif;
}

body:lang(bn-BD), button:lang(bn-BD),
input:lang(bn-BD),
select:lang(bn-BD),
optgroup:lang(bn-BD),
textarea:lang(bn-BD), .author-description .author-link:lang(bn-BD),
.comment-metadata:lang(bn-BD),
.comment-reply-link:lang(bn-BD),
.comments-title:lang(bn-BD),
.comment-author .fn:lang(bn-BD),
.discussion-meta-info:lang(bn-BD),
.entry-meta:lang(bn-BD),
.entry-footer:lang(bn-BD),
.main-navigation:lang(bn-BD),
.no-comments:lang(bn-BD),
.not-found .page-title:lang(bn-BD),
.error-404 .page-title:lang(bn-BD),
.post-navigation .post-title:lang(bn-BD),
.page-links:lang(bn-BD),
.page-description:lang(bn-BD),
.pagination .nav-links:lang(bn-BD),
.sticky-post:lang(bn-BD),
.site-title:lang(bn-BD),
.site-info:lang(bn-BD),
#cancel-comment-reply-link:lang(bn-BD),
h1:lang(bn-BD),
h2:lang(bn-BD),
h3:lang(bn-BD),
h4:lang(bn-BD),
h5:lang(bn-BD),
h6:lang(bn-BD), .page-title:lang(bn-BD), blockquote cite:lang(bn-BD), table:lang(bn-BD), .button:lang(bn-BD),
input:lang(bn-BD)[type="button"],
input:lang(bn-BD)[type="reset"],
input:lang(bn-BD)[type="submit"], .comment-navigation .nav-previous:lang(bn-BD),
.comment-navigation .nav-next:lang(bn-BD), .comment-list .pingback .comment-body:lang(bn-BD),
.comment-list .trackback .comment-body:lang(bn-BD), .comment-list .pingback .comment-body .comment-edit-link:lang(bn-BD),
.comment-list .trackback .comment-body .comment-edit-link:lang(bn-BD), .comment-form .comment-notes:lang(bn-BD),
.comment-form label:lang(bn-BD), .widget_archive ul li:lang(bn-BD),
.widget_categories ul li:lang(bn-BD),
.widget_meta ul li:lang(bn-BD),
.widget_nav_menu ul li:lang(bn-BD),
.widget_pages ul li:lang(bn-BD),
.widget_recent_comments ul li:lang(bn-BD),
.widget_recent_entries ul li:lang(bn-BD),
.widget_rss ul li:lang(bn-BD), .widget_tag_cloud .tagcloud:lang(bn-BD), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(bn-BD), .entry .entry-content .wp-block-button .wp-block-button__link:lang(bn-BD), .entry .entry-content .wp-block-archives li > a:lang(bn-BD),
.entry .entry-content .wp-block-categories li > a:lang(bn-BD),
.entry .entry-content .wp-block-latest-posts li > a:lang(bn-BD), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(bn-BD), .entry .entry-content .wp-block-verse:lang(bn-BD), .entry .entry-content .has-drop-cap:lang(bn-BD):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(bn-BD), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(bn-BD),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(bn-BD),
.entry .entry-content .wp-block-cover-image h2:lang(bn-BD),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(bn-BD),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(bn-BD),
.entry .entry-content .wp-block-cover h2:lang(bn-BD), .entry .entry-content .wp-block-audio figcaption:lang(bn-BD),
.entry .entry-content .wp-block-video figcaption:lang(bn-BD),
.entry .entry-content .wp-block-image figcaption:lang(bn-BD),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(bn-BD),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(bn-BD), .entry .entry-content .wp-block-file:lang(bn-BD), .entry .entry-content .wp-block-file .wp-block-file__button:lang(bn-BD), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(bn-BD), .wp-caption-text:lang(bn-BD), .gallery-caption:lang(bn-BD) {
  font-family: Arial, sans-serif;
}

body:lang(hi-IN), button:lang(hi-IN),
input:lang(hi-IN),
select:lang(hi-IN),
optgroup:lang(hi-IN),
textarea:lang(hi-IN), .author-description .author-link:lang(hi-IN),
.comment-metadata:lang(hi-IN),
.comment-reply-link:lang(hi-IN),
.comments-title:lang(hi-IN),
.comment-author .fn:lang(hi-IN),
.discussion-meta-info:lang(hi-IN),
.entry-meta:lang(hi-IN),
.entry-footer:lang(hi-IN),
.main-navigation:lang(hi-IN),
.no-comments:lang(hi-IN),
.not-found .page-title:lang(hi-IN),
.error-404 .page-title:lang(hi-IN),
.post-navigation .post-title:lang(hi-IN),
.page-links:lang(hi-IN),
.page-description:lang(hi-IN),
.pagination .nav-links:lang(hi-IN),
.sticky-post:lang(hi-IN),
.site-title:lang(hi-IN),
.site-info:lang(hi-IN),
#cancel-comment-reply-link:lang(hi-IN),
h1:lang(hi-IN),
h2:lang(hi-IN),
h3:lang(hi-IN),
h4:lang(hi-IN),
h5:lang(hi-IN),
h6:lang(hi-IN), .page-title:lang(hi-IN), blockquote cite:lang(hi-IN), table:lang(hi-IN), .button:lang(hi-IN),
input:lang(hi-IN)[type="button"],
input:lang(hi-IN)[type="reset"],
input:lang(hi-IN)[type="submit"], .comment-navigation .nav-previous:lang(hi-IN),
.comment-navigation .nav-next:lang(hi-IN), .comment-list .pingback .comment-body:lang(hi-IN),
.comment-list .trackback .comment-body:lang(hi-IN), .comment-list .pingback .comment-body .comment-edit-link:lang(hi-IN),
.comment-list .trackback .comment-body .comment-edit-link:lang(hi-IN), .comment-form .comment-notes:lang(hi-IN),
.comment-form label:lang(hi-IN), .widget_archive ul li:lang(hi-IN),
.widget_categories ul li:lang(hi-IN),
.widget_meta ul li:lang(hi-IN),
.widget_nav_menu ul li:lang(hi-IN),
.widget_pages ul li:lang(hi-IN),
.widget_recent_comments ul li:lang(hi-IN),
.widget_recent_entries ul li:lang(hi-IN),
.widget_rss ul li:lang(hi-IN), .widget_tag_cloud .tagcloud:lang(hi-IN), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(hi-IN), .entry .entry-content .wp-block-button .wp-block-button__link:lang(hi-IN), .entry .entry-content .wp-block-archives li > a:lang(hi-IN),
.entry .entry-content .wp-block-categories li > a:lang(hi-IN),
.entry .entry-content .wp-block-latest-posts li > a:lang(hi-IN), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(hi-IN), .entry .entry-content .wp-block-verse:lang(hi-IN), .entry .entry-content .has-drop-cap:lang(hi-IN):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(hi-IN), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(hi-IN),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(hi-IN),
.entry .entry-content .wp-block-cover-image h2:lang(hi-IN),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(hi-IN),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(hi-IN),
.entry .entry-content .wp-block-cover h2:lang(hi-IN), .entry .entry-content .wp-block-audio figcaption:lang(hi-IN),
.entry .entry-content .wp-block-video figcaption:lang(hi-IN),
.entry .entry-content .wp-block-image figcaption:lang(hi-IN),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(hi-IN),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(hi-IN), .entry .entry-content .wp-block-file:lang(hi-IN), .entry .entry-content .wp-block-file .wp-block-file__button:lang(hi-IN), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(hi-IN), .wp-caption-text:lang(hi-IN), .gallery-caption:lang(hi-IN) {
  font-family: Arial, sans-serif;
}

body:lang(mr), button:lang(mr),
input:lang(mr),
select:lang(mr),
optgroup:lang(mr),
textarea:lang(mr), .author-description .author-link:lang(mr),
.comment-metadata:lang(mr),
.comment-reply-link:lang(mr),
.comments-title:lang(mr),
.comment-author .fn:lang(mr),
.discussion-meta-info:lang(mr),
.entry-meta:lang(mr),
.entry-footer:lang(mr),
.main-navigation:lang(mr),
.no-comments:lang(mr),
.not-found .page-title:lang(mr),
.error-404 .page-title:lang(mr),
.post-navigation .post-title:lang(mr),
.page-links:lang(mr),
.page-description:lang(mr),
.pagination .nav-links:lang(mr),
.sticky-post:lang(mr),
.site-title:lang(mr),
.site-info:lang(mr),
#cancel-comment-reply-link:lang(mr),
h1:lang(mr),
h2:lang(mr),
h3:lang(mr),
h4:lang(mr),
h5:lang(mr),
h6:lang(mr), .page-title:lang(mr), blockquote cite:lang(mr), table:lang(mr), .button:lang(mr),
input:lang(mr)[type="button"],
input:lang(mr)[type="reset"],
input:lang(mr)[type="submit"], .comment-navigation .nav-previous:lang(mr),
.comment-navigation .nav-next:lang(mr), .comment-list .pingback .comment-body:lang(mr),
.comment-list .trackback .comment-body:lang(mr), .comment-list .pingback .comment-body .comment-edit-link:lang(mr),
.comment-list .trackback .comment-body .comment-edit-link:lang(mr), .comment-form .comment-notes:lang(mr),
.comment-form label:lang(mr), .widget_archive ul li:lang(mr),
.widget_categories ul li:lang(mr),
.widget_meta ul li:lang(mr),
.widget_nav_menu ul li:lang(mr),
.widget_pages ul li:lang(mr),
.widget_recent_comments ul li:lang(mr),
.widget_recent_entries ul li:lang(mr),
.widget_rss ul li:lang(mr), .widget_tag_cloud .tagcloud:lang(mr), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(mr), .entry .entry-content .wp-block-button .wp-block-button__link:lang(mr), .entry .entry-content .wp-block-archives li > a:lang(mr),
.entry .entry-content .wp-block-categories li > a:lang(mr),
.entry .entry-content .wp-block-latest-posts li > a:lang(mr), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(mr), .entry .entry-content .wp-block-verse:lang(mr), .entry .entry-content .has-drop-cap:lang(mr):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(mr), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(mr),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(mr),
.entry .entry-content .wp-block-cover-image h2:lang(mr),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(mr),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(mr),
.entry .entry-content .wp-block-cover h2:lang(mr), .entry .entry-content .wp-block-audio figcaption:lang(mr),
.entry .entry-content .wp-block-video figcaption:lang(mr),
.entry .entry-content .wp-block-image figcaption:lang(mr),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(mr),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(mr), .entry .entry-content .wp-block-file:lang(mr), .entry .entry-content .wp-block-file .wp-block-file__button:lang(mr), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(mr), .wp-caption-text:lang(mr), .gallery-caption:lang(mr) {
  font-family: Arial, sans-serif;
}

body:lang(ne-NP), button:lang(ne-NP),
input:lang(ne-NP),
select:lang(ne-NP),
optgroup:lang(ne-NP),
textarea:lang(ne-NP), .author-description .author-link:lang(ne-NP),
.comment-metadata:lang(ne-NP),
.comment-reply-link:lang(ne-NP),
.comments-title:lang(ne-NP),
.comment-author .fn:lang(ne-NP),
.discussion-meta-info:lang(ne-NP),
.entry-meta:lang(ne-NP),
.entry-footer:lang(ne-NP),
.main-navigation:lang(ne-NP),
.no-comments:lang(ne-NP),
.not-found .page-title:lang(ne-NP),
.error-404 .page-title:lang(ne-NP),
.post-navigation .post-title:lang(ne-NP),
.page-links:lang(ne-NP),
.page-description:lang(ne-NP),
.pagination .nav-links:lang(ne-NP),
.sticky-post:lang(ne-NP),
.site-title:lang(ne-NP),
.site-info:lang(ne-NP),
#cancel-comment-reply-link:lang(ne-NP),
h1:lang(ne-NP),
h2:lang(ne-NP),
h3:lang(ne-NP),
h4:lang(ne-NP),
h5:lang(ne-NP),
h6:lang(ne-NP), .page-title:lang(ne-NP), blockquote cite:lang(ne-NP), table:lang(ne-NP), .button:lang(ne-NP),
input:lang(ne-NP)[type="button"],
input:lang(ne-NP)[type="reset"],
input:lang(ne-NP)[type="submit"], .comment-navigation .nav-previous:lang(ne-NP),
.comment-navigation .nav-next:lang(ne-NP), .comment-list .pingback .comment-body:lang(ne-NP),
.comment-list .trackback .comment-body:lang(ne-NP), .comment-list .pingback .comment-body .comment-edit-link:lang(ne-NP),
.comment-list .trackback .comment-body .comment-edit-link:lang(ne-NP), .comment-form .comment-notes:lang(ne-NP),
.comment-form label:lang(ne-NP), .widget_archive ul li:lang(ne-NP),
.widget_categories ul li:lang(ne-NP),
.widget_meta ul li:lang(ne-NP),
.widget_nav_menu ul li:lang(ne-NP),
.widget_pages ul li:lang(ne-NP),
.widget_recent_comments ul li:lang(ne-NP),
.widget_recent_entries ul li:lang(ne-NP),
.widget_rss ul li:lang(ne-NP), .widget_tag_cloud .tagcloud:lang(ne-NP), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ne-NP), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ne-NP), .entry .entry-content .wp-block-archives li > a:lang(ne-NP),
.entry .entry-content .wp-block-categories li > a:lang(ne-NP),
.entry .entry-content .wp-block-latest-posts li > a:lang(ne-NP), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ne-NP), .entry .entry-content .wp-block-verse:lang(ne-NP), .entry .entry-content .has-drop-cap:lang(ne-NP):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ne-NP), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ne-NP),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ne-NP),
.entry .entry-content .wp-block-cover-image h2:lang(ne-NP),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ne-NP),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ne-NP),
.entry .entry-content .wp-block-cover h2:lang(ne-NP), .entry .entry-content .wp-block-audio figcaption:lang(ne-NP),
.entry .entry-content .wp-block-video figcaption:lang(ne-NP),
.entry .entry-content .wp-block-image figcaption:lang(ne-NP),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ne-NP),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ne-NP), .entry .entry-content .wp-block-file:lang(ne-NP), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ne-NP), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ne-NP), .wp-caption-text:lang(ne-NP), .gallery-caption:lang(ne-NP) {
  font-family: Arial, sans-serif;
}

body:lang(el), button:lang(el),
input:lang(el),
select:lang(el),
optgroup:lang(el),
textarea:lang(el), .author-description .author-link:lang(el),
.comment-metadata:lang(el),
.comment-reply-link:lang(el),
.comments-title:lang(el),
.comment-author .fn:lang(el),
.discussion-meta-info:lang(el),
.entry-meta:lang(el),
.entry-footer:lang(el),
.main-navigation:lang(el),
.no-comments:lang(el),
.not-found .page-title:lang(el),
.error-404 .page-title:lang(el),
.post-navigation .post-title:lang(el),
.page-links:lang(el),
.page-description:lang(el),
.pagination .nav-links:lang(el),
.sticky-post:lang(el),
.site-title:lang(el),
.site-info:lang(el),
#cancel-comment-reply-link:lang(el),
h1:lang(el),
h2:lang(el),
h3:lang(el),
h4:lang(el),
h5:lang(el),
h6:lang(el), .page-title:lang(el), blockquote cite:lang(el), table:lang(el), .button:lang(el),
input:lang(el)[type="button"],
input:lang(el)[type="reset"],
input:lang(el)[type="submit"], .comment-navigation .nav-previous:lang(el),
.comment-navigation .nav-next:lang(el), .comment-list .pingback .comment-body:lang(el),
.comment-list .trackback .comment-body:lang(el), .comment-list .pingback .comment-body .comment-edit-link:lang(el),
.comment-list .trackback .comment-body .comment-edit-link:lang(el), .comment-form .comment-notes:lang(el),
.comment-form label:lang(el), .widget_archive ul li:lang(el),
.widget_categories ul li:lang(el),
.widget_meta ul li:lang(el),
.widget_nav_menu ul li:lang(el),
.widget_pages ul li:lang(el),
.widget_recent_comments ul li:lang(el),
.widget_recent_entries ul li:lang(el),
.widget_rss ul li:lang(el), .widget_tag_cloud .tagcloud:lang(el), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(el), .entry .entry-content .wp-block-button .wp-block-button__link:lang(el), .entry .entry-content .wp-block-archives li > a:lang(el),
.entry .entry-content .wp-block-categories li > a:lang(el),
.entry .entry-content .wp-block-latest-posts li > a:lang(el), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(el), .entry .entry-content .wp-block-verse:lang(el), .entry .entry-content .has-drop-cap:lang(el):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(el), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(el),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(el),
.entry .entry-content .wp-block-cover-image h2:lang(el),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(el),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(el),
.entry .entry-content .wp-block-cover h2:lang(el), .entry .entry-content .wp-block-audio figcaption:lang(el),
.entry .entry-content .wp-block-video figcaption:lang(el),
.entry .entry-content .wp-block-image figcaption:lang(el),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(el),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(el), .entry .entry-content .wp-block-file:lang(el), .entry .entry-content .wp-block-file .wp-block-file__button:lang(el), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(el), .wp-caption-text:lang(el), .gallery-caption:lang(el) {
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}

body:lang(gu), button:lang(gu),
input:lang(gu),
select:lang(gu),
optgroup:lang(gu),
textarea:lang(gu), .author-description .author-link:lang(gu),
.comment-metadata:lang(gu),
.comment-reply-link:lang(gu),
.comments-title:lang(gu),
.comment-author .fn:lang(gu),
.discussion-meta-info:lang(gu),
.entry-meta:lang(gu),
.entry-footer:lang(gu),
.main-navigation:lang(gu),
.no-comments:lang(gu),
.not-found .page-title:lang(gu),
.error-404 .page-title:lang(gu),
.post-navigation .post-title:lang(gu),
.page-links:lang(gu),
.page-description:lang(gu),
.pagination .nav-links:lang(gu),
.sticky-post:lang(gu),
.site-title:lang(gu),
.site-info:lang(gu),
#cancel-comment-reply-link:lang(gu),
h1:lang(gu),
h2:lang(gu),
h3:lang(gu),
h4:lang(gu),
h5:lang(gu),
h6:lang(gu), .page-title:lang(gu), blockquote cite:lang(gu), table:lang(gu), .button:lang(gu),
input:lang(gu)[type="button"],
input:lang(gu)[type="reset"],
input:lang(gu)[type="submit"], .comment-navigation .nav-previous:lang(gu),
.comment-navigation .nav-next:lang(gu), .comment-list .pingback .comment-body:lang(gu),
.comment-list .trackback .comment-body:lang(gu), .comment-list .pingback .comment-body .comment-edit-link:lang(gu),
.comment-list .trackback .comment-body .comment-edit-link:lang(gu), .comment-form .comment-notes:lang(gu),
.comment-form label:lang(gu), .widget_archive ul li:lang(gu),
.widget_categories ul li:lang(gu),
.widget_meta ul li:lang(gu),
.widget_nav_menu ul li:lang(gu),
.widget_pages ul li:lang(gu),
.widget_recent_comments ul li:lang(gu),
.widget_recent_entries ul li:lang(gu),
.widget_rss ul li:lang(gu), .widget_tag_cloud .tagcloud:lang(gu), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(gu), .entry .entry-content .wp-block-button .wp-block-button__link:lang(gu), .entry .entry-content .wp-block-archives li > a:lang(gu),
.entry .entry-content .wp-block-categories li > a:lang(gu),
.entry .entry-content .wp-block-latest-posts li > a:lang(gu), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(gu), .entry .entry-content .wp-block-verse:lang(gu), .entry .entry-content .has-drop-cap:lang(gu):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(gu), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(gu),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(gu),
.entry .entry-content .wp-block-cover-image h2:lang(gu),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(gu),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(gu),
.entry .entry-content .wp-block-cover h2:lang(gu), .entry .entry-content .wp-block-audio figcaption:lang(gu),
.entry .entry-content .wp-block-video figcaption:lang(gu),
.entry .entry-content .wp-block-image figcaption:lang(gu),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(gu),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(gu), .entry .entry-content .wp-block-file:lang(gu), .entry .entry-content .wp-block-file .wp-block-file__button:lang(gu), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(gu), .wp-caption-text:lang(gu), .gallery-caption:lang(gu) {
  font-family: Arial, sans-serif;
}

body:lang(he-IL), button:lang(he-IL),
input:lang(he-IL),
select:lang(he-IL),
optgroup:lang(he-IL),
textarea:lang(he-IL), .author-description .author-link:lang(he-IL),
.comment-metadata:lang(he-IL),
.comment-reply-link:lang(he-IL),
.comments-title:lang(he-IL),
.comment-author .fn:lang(he-IL),
.discussion-meta-info:lang(he-IL),
.entry-meta:lang(he-IL),
.entry-footer:lang(he-IL),
.main-navigation:lang(he-IL),
.no-comments:lang(he-IL),
.not-found .page-title:lang(he-IL),
.error-404 .page-title:lang(he-IL),
.post-navigation .post-title:lang(he-IL),
.page-links:lang(he-IL),
.page-description:lang(he-IL),
.pagination .nav-links:lang(he-IL),
.sticky-post:lang(he-IL),
.site-title:lang(he-IL),
.site-info:lang(he-IL),
#cancel-comment-reply-link:lang(he-IL),
h1:lang(he-IL),
h2:lang(he-IL),
h3:lang(he-IL),
h4:lang(he-IL),
h5:lang(he-IL),
h6:lang(he-IL), .page-title:lang(he-IL), blockquote cite:lang(he-IL), table:lang(he-IL), .button:lang(he-IL),
input:lang(he-IL)[type="button"],
input:lang(he-IL)[type="reset"],
input:lang(he-IL)[type="submit"], .comment-navigation .nav-previous:lang(he-IL),
.comment-navigation .nav-next:lang(he-IL), .comment-list .pingback .comment-body:lang(he-IL),
.comment-list .trackback .comment-body:lang(he-IL), .comment-list .pingback .comment-body .comment-edit-link:lang(he-IL),
.comment-list .trackback .comment-body .comment-edit-link:lang(he-IL), .comment-form .comment-notes:lang(he-IL),
.comment-form label:lang(he-IL), .widget_archive ul li:lang(he-IL),
.widget_categories ul li:lang(he-IL),
.widget_meta ul li:lang(he-IL),
.widget_nav_menu ul li:lang(he-IL),
.widget_pages ul li:lang(he-IL),
.widget_recent_comments ul li:lang(he-IL),
.widget_recent_entries ul li:lang(he-IL),
.widget_rss ul li:lang(he-IL), .widget_tag_cloud .tagcloud:lang(he-IL), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(he-IL), .entry .entry-content .wp-block-button .wp-block-button__link:lang(he-IL), .entry .entry-content .wp-block-archives li > a:lang(he-IL),
.entry .entry-content .wp-block-categories li > a:lang(he-IL),
.entry .entry-content .wp-block-latest-posts li > a:lang(he-IL), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(he-IL), .entry .entry-content .wp-block-verse:lang(he-IL), .entry .entry-content .has-drop-cap:lang(he-IL):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(he-IL), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(he-IL),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(he-IL),
.entry .entry-content .wp-block-cover-image h2:lang(he-IL),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(he-IL),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(he-IL),
.entry .entry-content .wp-block-cover h2:lang(he-IL), .entry .entry-content .wp-block-audio figcaption:lang(he-IL),
.entry .entry-content .wp-block-video figcaption:lang(he-IL),
.entry .entry-content .wp-block-image figcaption:lang(he-IL),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(he-IL),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(he-IL), .entry .entry-content .wp-block-file:lang(he-IL), .entry .entry-content .wp-block-file .wp-block-file__button:lang(he-IL), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(he-IL), .wp-caption-text:lang(he-IL), .gallery-caption:lang(he-IL) {
  font-family: "Arial Hebrew", Arial, sans-serif;
}

body:lang(ja), button:lang(ja),
input:lang(ja),
select:lang(ja),
optgroup:lang(ja),
textarea:lang(ja), .author-description .author-link:lang(ja),
.comment-metadata:lang(ja),
.comment-reply-link:lang(ja),
.comments-title:lang(ja),
.comment-author .fn:lang(ja),
.discussion-meta-info:lang(ja),
.entry-meta:lang(ja),
.entry-footer:lang(ja),
.main-navigation:lang(ja),
.no-comments:lang(ja),
.not-found .page-title:lang(ja),
.error-404 .page-title:lang(ja),
.post-navigation .post-title:lang(ja),
.page-links:lang(ja),
.page-description:lang(ja),
.pagination .nav-links:lang(ja),
.sticky-post:lang(ja),
.site-title:lang(ja),
.site-info:lang(ja),
#cancel-comment-reply-link:lang(ja),
h1:lang(ja),
h2:lang(ja),
h3:lang(ja),
h4:lang(ja),
h5:lang(ja),
h6:lang(ja), .page-title:lang(ja), blockquote cite:lang(ja), table:lang(ja), .button:lang(ja),
input:lang(ja)[type="button"],
input:lang(ja)[type="reset"],
input:lang(ja)[type="submit"], .comment-navigation .nav-previous:lang(ja),
.comment-navigation .nav-next:lang(ja), .comment-list .pingback .comment-body:lang(ja),
.comment-list .trackback .comment-body:lang(ja), .comment-list .pingback .comment-body .comment-edit-link:lang(ja),
.comment-list .trackback .comment-body .comment-edit-link:lang(ja), .comment-form .comment-notes:lang(ja),
.comment-form label:lang(ja), .widget_archive ul li:lang(ja),
.widget_categories ul li:lang(ja),
.widget_meta ul li:lang(ja),
.widget_nav_menu ul li:lang(ja),
.widget_pages ul li:lang(ja),
.widget_recent_comments ul li:lang(ja),
.widget_recent_entries ul li:lang(ja),
.widget_rss ul li:lang(ja), .widget_tag_cloud .tagcloud:lang(ja), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ja), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ja), .entry .entry-content .wp-block-archives li > a:lang(ja),
.entry .entry-content .wp-block-categories li > a:lang(ja),
.entry .entry-content .wp-block-latest-posts li > a:lang(ja), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ja), .entry .entry-content .wp-block-verse:lang(ja), .entry .entry-content .has-drop-cap:lang(ja):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ja), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ja),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ja),
.entry .entry-content .wp-block-cover-image h2:lang(ja),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ja),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ja),
.entry .entry-content .wp-block-cover h2:lang(ja), .entry .entry-content .wp-block-audio figcaption:lang(ja),
.entry .entry-content .wp-block-video figcaption:lang(ja),
.entry .entry-content .wp-block-image figcaption:lang(ja),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ja),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ja), .entry .entry-content .wp-block-file:lang(ja), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ja), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ja), .wp-caption-text:lang(ja), .gallery-caption:lang(ja) {
  font-family: -apple-system, BlinkMacSystemFont, "Hiragino Sans", Meiryo, "Helvetica Neue", sans-serif;
}

body:lang(ko-KR), button:lang(ko-KR),
input:lang(ko-KR),
select:lang(ko-KR),
optgroup:lang(ko-KR),
textarea:lang(ko-KR), .author-description .author-link:lang(ko-KR),
.comment-metadata:lang(ko-KR),
.comment-reply-link:lang(ko-KR),
.comments-title:lang(ko-KR),
.comment-author .fn:lang(ko-KR),
.discussion-meta-info:lang(ko-KR),
.entry-meta:lang(ko-KR),
.entry-footer:lang(ko-KR),
.main-navigation:lang(ko-KR),
.no-comments:lang(ko-KR),
.not-found .page-title:lang(ko-KR),
.error-404 .page-title:lang(ko-KR),
.post-navigation .post-title:lang(ko-KR),
.page-links:lang(ko-KR),
.page-description:lang(ko-KR),
.pagination .nav-links:lang(ko-KR),
.sticky-post:lang(ko-KR),
.site-title:lang(ko-KR),
.site-info:lang(ko-KR),
#cancel-comment-reply-link:lang(ko-KR),
h1:lang(ko-KR),
h2:lang(ko-KR),
h3:lang(ko-KR),
h4:lang(ko-KR),
h5:lang(ko-KR),
h6:lang(ko-KR), .page-title:lang(ko-KR), blockquote cite:lang(ko-KR), table:lang(ko-KR), .button:lang(ko-KR),
input:lang(ko-KR)[type="button"],
input:lang(ko-KR)[type="reset"],
input:lang(ko-KR)[type="submit"], .comment-navigation .nav-previous:lang(ko-KR),
.comment-navigation .nav-next:lang(ko-KR), .comment-list .pingback .comment-body:lang(ko-KR),
.comment-list .trackback .comment-body:lang(ko-KR), .comment-list .pingback .comment-body .comment-edit-link:lang(ko-KR),
.comment-list .trackback .comment-body .comment-edit-link:lang(ko-KR), .comment-form .comment-notes:lang(ko-KR),
.comment-form label:lang(ko-KR), .widget_archive ul li:lang(ko-KR),
.widget_categories ul li:lang(ko-KR),
.widget_meta ul li:lang(ko-KR),
.widget_nav_menu ul li:lang(ko-KR),
.widget_pages ul li:lang(ko-KR),
.widget_recent_comments ul li:lang(ko-KR),
.widget_recent_entries ul li:lang(ko-KR),
.widget_rss ul li:lang(ko-KR), .widget_tag_cloud .tagcloud:lang(ko-KR), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(ko-KR), .entry .entry-content .wp-block-button .wp-block-button__link:lang(ko-KR), .entry .entry-content .wp-block-archives li > a:lang(ko-KR),
.entry .entry-content .wp-block-categories li > a:lang(ko-KR),
.entry .entry-content .wp-block-latest-posts li > a:lang(ko-KR), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(ko-KR), .entry .entry-content .wp-block-verse:lang(ko-KR), .entry .entry-content .has-drop-cap:lang(ko-KR):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(ko-KR), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(ko-KR),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(ko-KR),
.entry .entry-content .wp-block-cover-image h2:lang(ko-KR),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(ko-KR),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(ko-KR),
.entry .entry-content .wp-block-cover h2:lang(ko-KR), .entry .entry-content .wp-block-audio figcaption:lang(ko-KR),
.entry .entry-content .wp-block-video figcaption:lang(ko-KR),
.entry .entry-content .wp-block-image figcaption:lang(ko-KR),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(ko-KR),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(ko-KR), .entry .entry-content .wp-block-file:lang(ko-KR), .entry .entry-content .wp-block-file .wp-block-file__button:lang(ko-KR), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(ko-KR), .wp-caption-text:lang(ko-KR), .gallery-caption:lang(ko-KR) {
  font-family: "Apple SD Gothic Neo", "Malgun Gothic", "Nanum Gothic", Dotum, sans-serif;
}

body:lang(th), button:lang(th),
input:lang(th),
select:lang(th),
optgroup:lang(th),
textarea:lang(th), .author-description .author-link:lang(th),
.comment-metadata:lang(th),
.comment-reply-link:lang(th),
.comments-title:lang(th),
.comment-author .fn:lang(th),
.discussion-meta-info:lang(th),
.entry-meta:lang(th),
.entry-footer:lang(th),
.main-navigation:lang(th),
.no-comments:lang(th),
.not-found .page-title:lang(th),
.error-404 .page-title:lang(th),
.post-navigation .post-title:lang(th),
.page-links:lang(th),
.page-description:lang(th),
.pagination .nav-links:lang(th),
.sticky-post:lang(th),
.site-title:lang(th),
.site-info:lang(th),
#cancel-comment-reply-link:lang(th),
h1:lang(th),
h2:lang(th),
h3:lang(th),
h4:lang(th),
h5:lang(th),
h6:lang(th), .page-title:lang(th), blockquote cite:lang(th), table:lang(th), .button:lang(th),
input:lang(th)[type="button"],
input:lang(th)[type="reset"],
input:lang(th)[type="submit"], .comment-navigation .nav-previous:lang(th),
.comment-navigation .nav-next:lang(th), .comment-list .pingback .comment-body:lang(th),
.comment-list .trackback .comment-body:lang(th), .comment-list .pingback .comment-body .comment-edit-link:lang(th),
.comment-list .trackback .comment-body .comment-edit-link:lang(th), .comment-form .comment-notes:lang(th),
.comment-form label:lang(th), .widget_archive ul li:lang(th),
.widget_categories ul li:lang(th),
.widget_meta ul li:lang(th),
.widget_nav_menu ul li:lang(th),
.widget_pages ul li:lang(th),
.widget_recent_comments ul li:lang(th),
.widget_recent_entries ul li:lang(th),
.widget_rss ul li:lang(th), .widget_tag_cloud .tagcloud:lang(th), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(th), .entry .entry-content .wp-block-button .wp-block-button__link:lang(th), .entry .entry-content .wp-block-archives li > a:lang(th),
.entry .entry-content .wp-block-categories li > a:lang(th),
.entry .entry-content .wp-block-latest-posts li > a:lang(th), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(th), .entry .entry-content .wp-block-verse:lang(th), .entry .entry-content .has-drop-cap:lang(th):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(th), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(th),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(th),
.entry .entry-content .wp-block-cover-image h2:lang(th),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(th),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(th),
.entry .entry-content .wp-block-cover h2:lang(th), .entry .entry-content .wp-block-audio figcaption:lang(th),
.entry .entry-content .wp-block-video figcaption:lang(th),
.entry .entry-content .wp-block-image figcaption:lang(th),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(th),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(th), .entry .entry-content .wp-block-file:lang(th), .entry .entry-content .wp-block-file .wp-block-file__button:lang(th), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(th), .wp-caption-text:lang(th), .gallery-caption:lang(th) {
  font-family: "Sukhumvit Set", "Helvetica Neue", helvetica, arial, sans-serif;
}

body:lang(vi), button:lang(vi),
input:lang(vi),
select:lang(vi),
optgroup:lang(vi),
textarea:lang(vi), .author-description .author-link:lang(vi),
.comment-metadata:lang(vi),
.comment-reply-link:lang(vi),
.comments-title:lang(vi),
.comment-author .fn:lang(vi),
.discussion-meta-info:lang(vi),
.entry-meta:lang(vi),
.entry-footer:lang(vi),
.main-navigation:lang(vi),
.no-comments:lang(vi),
.not-found .page-title:lang(vi),
.error-404 .page-title:lang(vi),
.post-navigation .post-title:lang(vi),
.page-links:lang(vi),
.page-description:lang(vi),
.pagination .nav-links:lang(vi),
.sticky-post:lang(vi),
.site-title:lang(vi),
.site-info:lang(vi),
#cancel-comment-reply-link:lang(vi),
h1:lang(vi),
h2:lang(vi),
h3:lang(vi),
h4:lang(vi),
h5:lang(vi),
h6:lang(vi), .page-title:lang(vi), blockquote cite:lang(vi), table:lang(vi), .button:lang(vi),
input:lang(vi)[type="button"],
input:lang(vi)[type="reset"],
input:lang(vi)[type="submit"], .comment-navigation .nav-previous:lang(vi),
.comment-navigation .nav-next:lang(vi), .comment-list .pingback .comment-body:lang(vi),
.comment-list .trackback .comment-body:lang(vi), .comment-list .pingback .comment-body .comment-edit-link:lang(vi),
.comment-list .trackback .comment-body .comment-edit-link:lang(vi), .comment-form .comment-notes:lang(vi),
.comment-form label:lang(vi), .widget_archive ul li:lang(vi),
.widget_categories ul li:lang(vi),
.widget_meta ul li:lang(vi),
.widget_nav_menu ul li:lang(vi),
.widget_pages ul li:lang(vi),
.widget_recent_comments ul li:lang(vi),
.widget_recent_entries ul li:lang(vi),
.widget_rss ul li:lang(vi), .widget_tag_cloud .tagcloud:lang(vi), .widget_calendar .calendar_wrap .wp-calendar-nav:lang(vi), .entry .entry-content .wp-block-button .wp-block-button__link:lang(vi), .entry .entry-content .wp-block-archives li > a:lang(vi),
.entry .entry-content .wp-block-categories li > a:lang(vi),
.entry .entry-content .wp-block-latest-posts li > a:lang(vi), .entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date:lang(vi), .entry .entry-content .wp-block-verse:lang(vi), .entry .entry-content .has-drop-cap:lang(vi):not(:focus):first-letter, .entry .entry-content .wp-block-pullquote cite:lang(vi), .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text:lang(vi),
.entry .entry-content .wp-block-cover-image .wp-block-cover-text:lang(vi),
.entry .entry-content .wp-block-cover-image h2:lang(vi),
.entry .entry-content .wp-block-cover .wp-block-cover-image-text:lang(vi),
.entry .entry-content .wp-block-cover .wp-block-cover-text:lang(vi),
.entry .entry-content .wp-block-cover h2:lang(vi), .entry .entry-content .wp-block-audio figcaption:lang(vi),
.entry .entry-content .wp-block-video figcaption:lang(vi),
.entry .entry-content .wp-block-image figcaption:lang(vi),
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption:lang(vi),
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption:lang(vi), .entry .entry-content .wp-block-file:lang(vi), .entry .entry-content .wp-block-file .wp-block-file__button:lang(vi), .entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta:lang(vi), .wp-caption-text:lang(vi), .gallery-caption:lang(vi) {
  font-family: "Libre Franklin", sans-serif;
}

/* Normalize */
/*! normalize.css v8.0.0 | MIT License | github.com/necolas/normalize.css */
/* Document
	 ========================================================================== */
/**
 * 1. Correct the line height in all browsers.
 * 2. Prevent adjustments of font size after orientation changes in iOS.
 */
html {
  line-height: 1.15;
  /* 1 */
  -webkit-text-size-adjust: 100%;
  /* 2 */
}

/* Sections
	 ========================================================================== */
/**
 * Remove the margin in all browsers.
 */
body {
  margin: 0;
}

/**
 * Correct the font size and margin on `h1` elements within `section` and
 * `article` contexts in Chrome, Firefox, and Safari.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

/* Grouping content
	 ========================================================================== */
/**
 * 1. Add the correct box sizing in Firefox.
 * 2. Show the overflow in Edge and IE.
 */
hr {
  box-sizing: content-box;
  /* 1 */
  height: 0;
  /* 1 */
  overflow: visible;
  /* 2 */
}

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
pre {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */
}

/* Text-level semantics
	 ========================================================================== */
/**
 * Remove the gray background on active links in IE 10.
 */
a {
  background-color: transparent;
}

/**
 * 1. Remove the bottom border in Chrome 57-
 * 2. Add the correct text decoration in Chrome, Edge, IE, Opera, and Safari.
 */
abbr[title] {
  border-bottom: none;
  /* 1 */
  text-decoration: underline;
  /* 2 */
  text-decoration: underline dotted;
  /* 2 */
}

/**
 * Add the correct font weight in Chrome, Edge, and Safari.
 */
b,
strong {
  font-weight: bolder;
}

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
code,
kbd,
samp {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */
}

/**
 * Add the correct font size in all browsers.
 */
small {
  font-size: 80%;
}

/**
 * Prevent `sub` and `sup` elements from affecting the line height in
 * all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sub {
  bottom: -0.25em;
}

sup {
  top: -0.5em;
}

/* Embedded content
	 ========================================================================== */
/**
 * Remove the border on images inside links in IE 10.
 */
img {
  border-style: none;
}

/* Forms
	 ========================================================================== */
/**
 * 1. Change the font styles in all browsers.
 * 2. Remove the margin in Firefox and Safari.
 */
button,
input,
optgroup,
select,
textarea {
  font-family: inherit;
  /* 1 */
  font-size: 100%;
  /* 1 */
  line-height: 1.15;
  /* 1 */
  margin: 0;
  /* 2 */
}

/**
 * Show the overflow in IE.
 * 1. Show the overflow in Edge.
 */
button,
input {
  /* 1 */
  overflow: visible;
}

/**
 * Remove the inheritance of text transform in Edge, Firefox, and IE.
 * 1. Remove the inheritance of text transform in Firefox.
 */
button,
select {
  /* 1 */
  text-transform: none;
}

/**
 * Correct the inability to style clickable types in iOS and Safari.
 */
button,
[type="button"],
[type="reset"],
[type="submit"] {
  -webkit-appearance: button;
}

/**
 * Remove the inner border and padding in Firefox.
 */
button::-moz-focus-inner,
[type="button"]::-moz-focus-inner,
[type="reset"]::-moz-focus-inner,
[type="submit"]::-moz-focus-inner {
  border-style: none;
  padding: 0;
}

/**
 * Restore the focus styles unset by the previous rule.
 */
button:-moz-focusring,
[type="button"]:-moz-focusring,
[type="reset"]:-moz-focusring,
[type="submit"]:-moz-focusring {
  outline: 1px dotted ButtonText;
}

/**
 * Correct the padding in Firefox.
 */
fieldset {
  padding: 0.35em 0.75em 0.625em;
}

/**
 * 1. Correct the text wrapping in Edge and IE.
 * 2. Correct the color inheritance from `fieldset` elements in IE.
 * 3. Remove the padding so developers are not caught out when they zero out
 *		`fieldset` elements in all browsers.
 */
legend {
  box-sizing: border-box;
  /* 1 */
  color: inherit;
  /* 2 */
  display: table;
  /* 1 */
  max-width: 100%;
  /* 1 */
  padding: 0;
  /* 3 */
  white-space: normal;
  /* 1 */
}

/**
 * Add the correct vertical alignment in Chrome, Firefox, and Opera.
 */
progress {
  vertical-align: baseline;
}

/**
 * Remove the default vertical scrollbar in IE 10+.
 */
textarea {
  overflow: auto;
}

/**
 * 1. Add the correct box sizing in IE 10.
 * 2. Remove the padding in IE 10.
 */
[type="checkbox"],
[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */
}

/**
 * Correct the cursor style of increment and decrement buttons in Chrome.
 */
[type="number"]::-webkit-inner-spin-button,
[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

/**
 * 1. Correct the odd appearance in Chrome and Safari.
 * 2. Correct the outline style in Safari.
 */
[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  outline-offset: -2px;
  /* 2 */
}

/**
 * Remove the inner padding in Chrome and Safari on macOS.
 */
[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

/**
 * 1. Correct the inability to style clickable types in iOS and Safari.
 * 2. Change font properties to `inherit` in Safari.
 */
::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */
}

/* Interactive
	 ========================================================================== */
/*
 * Add the correct display in Edge, IE 10+, and Firefox.
 */
details {
  display: block;
}

/*
 * Add the correct display in all browsers.
 */
summary {
  display: list-item;
}

/* Misc
	 ========================================================================== */
/**
 * Add the correct display in IE 10+.
 */
template {
  display: none;
}

/**
 * Add the correct display in IE 10.
 */
[hidden] {
  display: none;
}

/* Typography */
html {
  font-size: 22px;
}

body {
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  color: #111;
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: 400;
  font-size: 1em;
  line-height: 1.8;
  margin: 0;
  text-rendering: optimizeLegibility;
}

button,
input,
select,
optgroup,
textarea {
  color: #111;
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: 400;
  line-height: 1.8;
  text-rendering: optimizeLegibility;
}

.author-description .author-link,
.comment-metadata,
.comment-reply-link,
.comments-title,
.comment-author .fn,
.discussion-meta-info,
.entry-meta,
.entry-footer,
.main-navigation,
.no-comments,
.not-found .page-title,
.error-404 .page-title,
.post-navigation .post-title,
.page-links,
.page-description,
.pagination .nav-links,
.sticky-post,
.site-title,
.site-info,
#cancel-comment-reply-link,
h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}

.main-navigation,
.page-description,
.author-description .author-link,
.not-found .page-title,
.error-404 .page-title,
.post-navigation .post-title,
.pagination .nav-links,
.comments-title,
.comment-author .fn,
.no-comments,
.site-title,
h1,
h2,
h3,
h4,
h5,
h6 {
  font-weight: 700;
  letter-spacing: -0.02em;
  line-height: 1.2;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.page-title {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
}

.site-branding,
.main-navigation ul.main-menu > li,
.social-navigation,
.author-description .author-bio,
.nav-links {
  line-height: 1.25;
}

h1 {
  font-size: 2.25em;
}

@media only screen and (min-width: 768px) {
  h1 {
    font-size: 2.8125em;
  }
}

.entry-title,
.not-found .page-title,
.error-404 .page-title,
.has-larger-font-size,
h2 {
  font-size: 1.6875em;
}

@media only screen and (min-width: 768px) {
  .entry-title,
  .not-found .page-title,
  .error-404 .page-title,
  .has-larger-font-size,
  h2 {
    font-size: 2.25em;
  }
}

.has-regular-font-size,
.has-large-font-size,
.comments-title,
h3 {
  font-size: 1.6875em;
}

.site-title,
.site-description,
.main-navigation,
.nav-links,
.page-title,
.page-description,
.comment-author .fn,
.no-comments,
h2.author-title,
p.author-bio,
h4 {
  font-size: 1.125em;
}

.pagination .nav-links,
.comment-content,
h5 {
  font-size: 0.88889em;
}

.entry-meta,
.entry-footer,
.discussion-meta-info,
.site-info,
.has-small-font-size,
.comment-reply-link,
.comment-metadata,
.comment-notes,
.sticky-post,
#cancel-comment-reply-link,
img:after,
h6 {
  font-size: 0.71111em;
}

.site-title,
.page-title {
  font-weight: normal;
}

.page-description,
.page-links a {
  font-weight: bold;
}

.site-description {
  letter-spacing: -0.01em;
}

.post-navigation .post-title,
.entry-title,
.not-found .page-title,
.error-404 .page-title,
.comments-title,
blockquote {
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
  word-break: break-word;
  word-wrap: break-word;
}

/* Do not hyphenate entry title on tablet view and bigger. */
@media only screen and (min-width: 768px) {
  .entry-title {
    -webkit-hyphens: none;
    -moz-hyphens: none;
    -ms-hyphens: none;
    hyphens: none;
  }
}

p {
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

dfn,
cite,
em,
i {
  font-style: italic;
}

blockquote cite {
  font-size: 0.71111em;
  font-style: normal;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}

pre {
  font-size: 0.88889em;
  font-family: "Courier 10 Pitch", Courier, monospace;
  line-height: 1.8;
  overflow: auto;
}

code,
kbd,
tt,
var {
  font-size: 0.88889em;
  font-family: Menlo, monaco, Consolas, Lucida Console, monospace;
}

abbr, acronym {
  border-bottom: 1px dotted #666;
  cursor: help;
}

mark,
ins {
  background: #fff9c0;
  text-decoration: none;
}

big {
  font-size: 125%;
}

a {
  text-decoration: none;
}

a:hover {
  text-decoration: none;
}

a:focus {
  text-decoration: underline;
}

/* Elements */
html {
  box-sizing: border-box;
}

::-moz-selection {
  background-color: #bfdcea;
}

::selection {
  background-color: #bfdcea;
}

*,
*:before,
*:after {
  box-sizing: inherit;
}

body {
  background-color: #fff;
}

a {
  transition: color 110ms ease-in-out;
  color: #0073aa;
}

a:hover,
a:active {
  color: #005177;
  outline: 0;
  text-decoration: none;
}

a:focus {
  outline: thin;
  outline-style: dotted;
  text-decoration: underline;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  clear: both;
  margin: 1rem 0;
}

h1:not(.site-title):before,
h2:before {
  background: #767676;
  content: "\020";
  display: block;
  height: 2px;
  margin: 1rem 0;
  width: 1em;
}

h1:not(.site-title).has-text-align-center:before,
h2.has-text-align-center:before {
  margin-right: auto;
  margin-left: auto;
}

h1:not(.site-title).has-text-align-right:before,
h2.has-text-align-right:before {
  margin-right: auto;
}

hr {
  background-color: #767676;
  border: 0;
  height: 2px;
}

ul,
ol {
  padding-right: 1rem;
}

ul {
  list-style: disc;
}

ul ul {
  list-style-type: circle;
}

ol {
  list-style: decimal;
}

li {
  line-height: 1.8;
}

li > ul,
li > ol {
  padding-right: 2rem;
}

dt {
  font-weight: bold;
}

dd {
  margin: 0 1rem 1rem;
}

img {
  height: auto;
  max-width: 100%;
  position: relative;
}

figure {
  margin: 0;
}

blockquote {
  border-right: 2px solid #0073aa;
  margin-right: 0;
  padding: 0 1rem 0 0;
}

blockquote > p {
  margin: 0 0 1rem;
}

blockquote cite {
  color: #767676;
}

table {
  margin: 0 0 1rem;
  border-collapse: collapse;
  width: 100%;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}

table td,
table th {
  padding: 0.5em;
  border: 1px solid #767676;
  word-break: break-all;
}

/* Forms */
.button,
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
  transition: background 150ms ease-in-out;
  background: #0073aa;
  border: none;
  border-radius: 5px;
  box-sizing: border-box;
  color: #fff;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 0.88889em;
  font-weight: 700;
  line-height: 1.2;
  outline: none;
  padding: 0.76rem 1rem;
  text-decoration: none;
  vertical-align: bottom;
}

.button:hover,
button:hover,
input[type="button"]:hover,
input[type="reset"]:hover,
input[type="submit"]:hover {
  background: #111;
  cursor: pointer;
}

.button:visited,
button:visited,
input[type="button"]:visited,
input[type="reset"]:visited,
input[type="submit"]:visited {
  color: #fff;
  text-decoration: none;
}

.button:focus,
button:focus,
input[type="button"]:focus,
input[type="reset"]:focus,
input[type="submit"]:focus {
  background: #111;
  outline: thin dotted;
  outline-offset: -4px;
}

input[type="text"],
input[type="email"],
input[type="url"],
input[type="password"],
input[type="search"],
input[type="number"],
input[type="tel"],
input[type="range"],
input[type="date"],
input[type="month"],
input[type="week"],
input[type="time"],
input[type="datetime"],
input[type="datetime-local"],
input[type="color"],
textarea {
  -webkit-backface-visibility: hidden;
  background: #fff;
  border: solid 1px #ccc;
  box-sizing: border-box;
  outline: none;
  padding: 0.36rem 0.66rem;
  -webkit-appearance: none;
  outline-offset: 0;
  border-radius: 0;
}

input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
input[type="number"]:focus,
input[type="tel"]:focus,
input[type="range"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="week"]:focus,
input[type="time"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="color"]:focus,
textarea:focus {
  border-color: #0073aa;
  outline: thin solid rgba(0, 115, 170, 0.15);
  outline-offset: -4px;
}

input[type="search"]::-webkit-search-decoration {
  display: none;
}

textarea {
  box-sizing: border-box;
  display: block;
  width: 100%;
  max-width: 100%;
  resize: vertical;
}

form p {
  margin: 1rem 0;
}

/* Navigation */
/*--------------------------------------------------------------
## Links
--------------------------------------------------------------*/
a {
  transition: color 110ms ease-in-out;
  color: #0073aa;
}

a:visited {
  color: #0073aa;
}

a:hover,
a:active {
  color: #005177;
  outline: 0;
  text-decoration: none;
}

a:focus {
  outline: thin dotted;
  text-decoration: underline;
}

/*--------------------------------------------------------------
## Menus
--------------------------------------------------------------*/
/** === Main menu === */
.main-navigation {
  display: block;
  margin-top: 0.25rem;
  /* Un-style buttons */
  /*
	 * Sub-menu styles
	 *
	 * :focus-within needs its own selector so other similar
	 * selectors don’t get ignored if a browser doesn’t recognize it
	 */
  /**
	 * Fade-in animation for top-level submenus
	 */
  /**
	 * Off-canvas touch device styles
	 */
}

body.page .main-navigation {
  display: block;
}

.main-navigation > div {
  display: inline;
}

.main-navigation button {
  display: inline-block;
  border: none;
  padding: 0;
  margin: 0;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-weight: 700;
  line-height: 1.2;
  text-decoration: none;
  background: transparent;
  color: inherit;
  cursor: pointer;
  transition: background 250ms ease-in-out, transform 150ms ease;
  -webkit-appearance: none;
  -moz-appearance: none;
}

.main-navigation button:hover, .main-navigation button:focus {
  background: transparent;
}

.main-navigation button:focus {
  outline: 1px solid transparent;
  outline-offset: -4px;
}

.main-navigation button:active {
  transform: scale(0.99);
}

.main-navigation .main-menu {
  display: inline-block;
  margin: 0;
  padding: 0;
}

.main-navigation .main-menu > li {
  color: #0073aa;
  display: inline;
  position: relative;
}

.main-navigation .main-menu > li > a {
  font-weight: 700;
  color: #0073aa;
  margin-left: 0.5rem;
}

.main-navigation .main-menu > li > a + svg {
  margin-left: 0.5rem;
}

.main-navigation .main-menu > li > a:hover,
.main-navigation .main-menu > li > a:hover + svg {
  color: #005177;
}

.main-navigation .main-menu > li.menu-item-has-children {
  display: inline-block;
  position: inherit;
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu > li.menu-item-has-children {
    position: relative;
  }
}

.main-navigation .main-menu > li.menu-item-has-children > a {
  margin-left: 0.125rem;
}

.main-navigation .main-menu > li.menu-item-has-children > a:after,
.main-navigation .main-menu > li.menu-item-has-children .menu-item-has-children > a:after {
  content: "";
  display: none;
}

.main-navigation .main-menu > li.menu-item-has-children .submenu-expand {
  display: inline-block;
  margin-left: 0.25rem;
  /* Priority+ Menu */
}

.main-navigation .main-menu > li.menu-item-has-children .submenu-expand.main-menu-more-toggle {
  position: relative;
  height: 24px;
  line-height: 1.2;
  width: 24px;
  padding: 0;
  margin-right: 0.5rem;
}

.main-navigation .main-menu > li.menu-item-has-children .submenu-expand.main-menu-more-toggle svg {
  height: 24px;
  width: 24px;
  top: -0.125rem;
  vertical-align: text-bottom;
}

.wp-customizer-unloading .main-navigation .main-menu > li.menu-item-has-children .submenu-expand, .main-navigation .main-menu > li.menu-item-has-children .submenu-expand.is-empty {
  display: none;
}

.main-navigation .main-menu > li.menu-item-has-children .submenu-expand svg {
  position: relative;
  top: 0.2rem;
}

.main-navigation .main-menu > li:last-child > a,
.main-navigation .main-menu > li:last-child.menu-item-has-children .submenu-expand {
  margin-left: 0;
}

.main-navigation .sub-menu {
  background-color: #0073aa;
  color: #fff;
  list-style: none;
  padding-right: 0;
  position: absolute;
  opacity: 0;
  right: -9999px;
  z-index: 99999;
}

@media only screen and (min-width: 768px) {
  .main-navigation .sub-menu {
    width: auto;
    min-width: -moz-max-content;
    min-width: -webkit-max-content;
    min-width: max-content;
  }
}

.main-navigation .sub-menu > li {
  display: block;
  float: none;
  position: relative;
}

.main-navigation .sub-menu > li.menu-item-has-children .submenu-expand {
  display: inline-block;
  position: absolute;
  width: calc( 24px + 1rem);
  left: 0;
  top: calc( .125 * 1rem);
  bottom: 0;
  color: white;
  line-height: 1;
  padding: calc( .5 * 1rem);
}

.main-navigation .sub-menu > li.menu-item-has-children .submenu-expand svg {
  top: 0;
}

.main-navigation .sub-menu > li.menu-item-has-children .submenu-expand {
  margin-left: 0;
}

@media only screen and (min-width: 768px) {
  .main-navigation .sub-menu > li.menu-item-has-children .menu-item-has-children > a:after {
    content: "\203a";
  }
}

.main-navigation .sub-menu > li > a,
.main-navigation .sub-menu > li > .menu-item-link-return {
  color: #fff;
  display: block;
  line-height: 1.2;
  text-shadow: none;
  padding: calc( .5 * 1rem) 1rem calc( .5 * 1rem) calc( 24px + 1rem);
  max-width: 20rem;
}

.main-navigation .sub-menu > li > a:hover, .main-navigation .sub-menu > li > a:focus,
.main-navigation .sub-menu > li > .menu-item-link-return:hover,
.main-navigation .sub-menu > li > .menu-item-link-return:focus {
  background: #005177;
}

.main-navigation .sub-menu > li > a:hover:after, .main-navigation .sub-menu > li > a:focus:after,
.main-navigation .sub-menu > li > .menu-item-link-return:hover:after,
.main-navigation .sub-menu > li > .menu-item-link-return:focus:after {
  background: #005177;
}

.main-navigation .sub-menu > li > .menu-item-link-return {
  width: 100%;
  font-size: 22px;
  font-weight: normal;
  text-align: right;
}

.main-navigation .sub-menu > li > a:empty {
  display: none;
}

.main-navigation .sub-menu > li.mobile-parent-nav-menu-item {
  display: none;
  font-size: 0.88889em;
  font-weight: normal;
}

.main-navigation .sub-menu > li.mobile-parent-nav-menu-item svg {
  position: relative;
  top: 0.2rem;
  margin-left: calc( .25 * 1rem);
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu {
  display: block;
  right: 0;
  margin-top: 0;
  opacity: 1;
  width: auto;
  min-width: 100%;
  /* Non-mobile position */
  /* Nested sub-menu dashes */
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu {
  display: block;
  right: 0;
  margin-top: 0;
  opacity: 1;
  width: auto;
  min-width: 100%;
  /* Non-mobile position */
  /* Nested sub-menu dashes */
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu {
    display: block;
    margin-top: 0;
    opacity: 1;
    position: absolute;
    right: 0;
    left: auto;
    top: auto;
    bottom: auto;
    height: auto;
    min-width: -moz-max-content;
    min-width: -webkit-max-content;
    min-width: max-content;
    transform: none;
  }
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu {
    display: block;
    margin-top: 0;
    opacity: 1;
    position: absolute;
    right: 0;
    left: auto;
    top: auto;
    bottom: auto;
    height: auto;
    min-width: -moz-max-content;
    min-width: -webkit-max-content;
    min-width: max-content;
    transform: none;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu.hidden-links {
  right: 0;
  width: 100%;
  display: table;
  position: absolute;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu.hidden-links {
  right: 0;
  width: 100%;
  display: table;
  position: absolute;
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu.hidden-links {
    left: 0;
    right: auto;
    display: block;
    width: max-content;
  }
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu.hidden-links {
    left: 0;
    right: auto;
    display: block;
    width: max-content;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu .submenu-expand {
  display: none;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu .submenu-expand {
  display: none;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu .sub-menu {
  display: block;
  margin-top: inherit;
  position: relative;
  width: 100%;
  right: 0;
  opacity: 1;
  /* Non-mobile position */
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu .sub-menu {
  display: block;
  margin-top: inherit;
  position: relative;
  width: 100%;
  right: 0;
  opacity: 1;
  /* Non-mobile position */
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu .sub-menu {
    float: none;
    max-width: 100%;
  }
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu .sub-menu {
    float: none;
    max-width: 100%;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu .sub-menu {
  counter-reset: submenu;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu .sub-menu {
  counter-reset: submenu;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas)[focus-within] > .sub-menu .sub-menu > li > a::before {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: normal;
  content: "– " counters(submenu, "– ", none);
  counter-increment: submenu;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus-within > .sub-menu .sub-menu > li > a::before {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: normal;
  content: "– " counters(submenu, "– ", none);
  counter-increment: submenu;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu {
  display: block;
  right: 0;
  margin-top: 0;
  opacity: 1;
  width: auto;
  min-width: 100%;
  /* Non-mobile position */
  /* Nested sub-menu dashes */
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu,
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu,
  .main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu {
    display: block;
    float: none;
    margin-top: 0;
    opacity: 1;
    position: absolute;
    right: 0;
    left: auto;
    top: auto;
    bottom: auto;
    height: auto;
    min-width: -moz-max-content;
    min-width: -webkit-max-content;
    min-width: max-content;
    transform: none;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu.hidden-links,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu.hidden-links,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu.hidden-links {
  right: 0;
  width: 100%;
  display: table;
  position: absolute;
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu.hidden-links,
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu.hidden-links,
  .main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu.hidden-links {
    left: 0;
    right: auto;
    display: table;
    width: max-content;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu .submenu-expand,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu .submenu-expand,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu .submenu-expand {
  display: none;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu .sub-menu,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu .sub-menu,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu .sub-menu {
  display: block;
  margin-top: inherit;
  position: relative;
  width: 100%;
  right: 0;
  opacity: 1;
  /* Non-mobile position */
}

@media only screen and (min-width: 768px) {
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu .sub-menu,
  .main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu .sub-menu,
  .main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu .sub-menu {
    float: none;
    max-width: 100%;
  }
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu .sub-menu,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu .sub-menu,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu .sub-menu {
  counter-reset: submenu;
}

.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):hover > .sub-menu .sub-menu > li > a::before,
.main-navigation .main-menu .menu-item-has-children:not(.off-canvas):focus > .sub-menu .sub-menu > li > a::before,
.main-navigation .main-menu .menu-item-has-children.is-focused:not(.off-canvas) > .sub-menu .sub-menu > li > a::before {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: normal;
  content: "– " counters(submenu, "– ", none);
  counter-increment: submenu;
}

.main-navigation .main-menu > .menu-item-has-children:not(.off-canvas):hover > .sub-menu {
  animation: fade_in 0.1s forwards;
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu .submenu-expand .svg-icon {
  transform: rotate(-270deg);
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu .sub-menu {
  opacity: 0;
  position: absolute;
  z-index: 0;
  transform: translateX(100%);
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu li:hover,
.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu li:focus,
.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu li > a:hover,
.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu li > a:focus {
  background-color: transparent;
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu > li > a,
.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu > li > .menu-item-link-return {
  white-space: inherit;
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true {
  display: table;
  margin-top: 0;
  opacity: 1;
  padding-right: 0;
  /* Mobile position */
  right: 0;
  top: 0;
  left: 0;
  bottom: 0;
  position: fixed;
  z-index: 100000;
  /* Make sure appears above mobile admin bar */
  width: 100vw;
  height: 100vh;
  max-width: 100vw;
  transform: translateX(-100%);
  animation: slide_in_right 0.3s forwards;
  /* Prevent menu from being blocked by admin bar */
}

.main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true > .mobile-parent-nav-menu-item {
  display: block;
}

.admin-bar .main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true {
  top: 46px;
  height: calc( 100vh - 46px);
  /* WP core breakpoint */
}

.admin-bar .main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true .sub-menu.expanded-true {
  top: 0;
}

@media only screen and (min-width: 782px) {
  .admin-bar .main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true {
    top: 32px;
    height: calc( 100vh - 32px);
  }
  .admin-bar .main-navigation .main-menu .menu-item-has-children.off-canvas .sub-menu.expanded-true .sub-menu.expanded-true {
    top: 0;
  }
}

.main-navigation .main-menu-more:nth-child(n+3) {
  display: none;
}

/* Menu animation */
@keyframes slide_in_right {
  100% {
    transform: translateX(0%);
  }
}

@keyframes fade_in {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}

/* Social menu */
.social-navigation {
  margin-top: calc(1rem / 2);
  text-align: right;
}

.social-navigation ul.social-links-menu {
  content: "";
  display: table;
  table-layout: fixed;
  display: inline-block;
  margin: 0;
  padding: 0;
}

.social-navigation ul.social-links-menu li {
  display: inline-block;
  vertical-align: bottom;
  vertical-align: -webkit-baseline-middle;
  list-style: none;
}

.social-navigation ul.social-links-menu li:nth-child(n+2) {
  margin-right: 0.1em;
}

.social-navigation ul.social-links-menu li a {
  border-bottom: 1px solid transparent;
  display: block;
  color: #111;
  margin-bottom: -1px;
  transition: opacity 110ms ease-in-out;
}

.social-navigation ul.social-links-menu li a:hover, .social-navigation ul.social-links-menu li a:active {
  color: #111;
  opacity: 0.6;
}

.social-navigation ul.social-links-menu li a:focus {
  color: #111;
  opacity: 1;
  border-bottom: 1px solid #111;
}

.social-navigation ul.social-links-menu li a svg {
  display: block;
  width: 32px;
  height: 32px;
  transform: translateZ(0);
}

.social-navigation ul.social-links-menu li a svg#ui-icon-link {
  transform: rotate(45deg);
}

@media only screen and (min-width: 768px) {
  .site-title + .social-navigation,
  .site-description + .social-navigation {
    margin-top: calc(1rem / 5);
  }
}

/** === Footer menu === */
.footer-navigation {
  display: inline;
}

.footer-navigation > div {
  display: inline;
}

.footer-navigation .footer-menu {
  display: inline;
  padding-right: 0;
}

.footer-navigation .footer-menu li {
  display: inline;
  margin-left: 1rem;
}

/*--------------------------------------------------------------
## Next / Previous
--------------------------------------------------------------*/
/* Next/Previous navigation */
.post-navigation {
  margin: calc(3 * 1rem) 0;
}

@media only screen and (min-width: 768px) {
  .post-navigation {
    margin: calc(3 * 1rem) calc(10% + 60px);
    max-width: calc(6 * (100vw / 12));
  }
}

@media only screen and (min-width: 1168px) {
  .post-navigation {
    margin: calc(3 * 1rem) 0;
    max-width: 100%;
  }
}

.post-navigation .nav-links {
  margin: 0 1rem;
  max-width: 100%;
  display: flex;
  flex-direction: column;
}

@media only screen and (min-width: 768px) {
  .post-navigation .nav-links {
    margin: 0;
  }
}

@media only screen and (min-width: 1168px) {
  .post-navigation .nav-links {
    flex-direction: row;
    margin: 0 calc(10% + 60px);
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

.post-navigation .nav-links a .meta-nav {
  color: #767676;
  user-select: none;
}

.post-navigation .nav-links a .meta-nav:before, .post-navigation .nav-links a .meta-nav:after {
  display: none;
  content: "—";
  width: 2em;
  color: #767676;
  height: 1em;
}

.post-navigation .nav-links a .post-title {
  hyphens: auto;
}

.post-navigation .nav-links a:hover {
  color: #005177;
}

@media only screen and (min-width: 1168px) {
  .post-navigation .nav-links .nav-previous,
  .post-navigation .nav-links .nav-next {
    min-width: calc(50% - 2 * 1rem);
  }
}

.post-navigation .nav-links .nav-previous {
  order: 2;
}

@media only screen and (min-width: 1168px) {
  .post-navigation .nav-links .nav-previous {
    order: 1;
  }
}

.post-navigation .nav-links .nav-previous + .nav-next {
  margin-bottom: 1rem;
}

.post-navigation .nav-links .nav-previous .meta-nav:before {
  display: inline;
}

.post-navigation .nav-links .nav-next {
  order: 1;
}

@media only screen and (min-width: 1168px) {
  .post-navigation .nav-links .nav-next {
    order: 2;
    padding-right: 1rem;
  }
}

.post-navigation .nav-links .nav-next .meta-nav:after {
  display: inline;
}

.pagination .nav-links {
  display: flex;
  flex-wrap: wrap;
  padding: 0 calc(.5 * 1rem);
}

.pagination .nav-links > * {
  padding: calc(.5 * 1rem);
}

.pagination .nav-links > *.dots, .pagination .nav-links > *.prev {
  padding-right: 0;
}

.pagination .nav-links > *.dots, .pagination .nav-links > *.next {
  padding-left: 0;
}

.pagination .nav-links a:focus {
  text-decoration: underline;
  outline-offset: -1px;
}

.pagination .nav-links a:focus.prev, .pagination .nav-links a:focus.next {
  text-decoration: none;
}

.pagination .nav-links a:focus.prev .nav-prev-text,
.pagination .nav-links a:focus.prev .nav-next-text, .pagination .nav-links a:focus.next .nav-prev-text,
.pagination .nav-links a:focus.next .nav-next-text {
  text-decoration: underline;
}

.pagination .nav-links .nav-next-text,
.pagination .nav-links .nav-prev-text {
  display: none;
}

@media only screen and (min-width: 768px) {
  .pagination .nav-links {
    margin-right: calc(10% + 60px);
    padding: 0;
  }
  .pagination .nav-links .prev > *,
  .pagination .nav-links .next > * {
    display: inline-block;
    vertical-align: text-bottom;
  }
  .pagination .nav-links > * {
    padding: 1rem;
  }
}

.comment-navigation .nav-links {
  display: flex;
  flex-direction: row;
}

.comment-navigation .nav-previous,
.comment-navigation .nav-next {
  min-width: 50%;
  width: 100%;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-weight: bold;
}

.comment-navigation .nav-previous .secondary-text,
.comment-navigation .nav-next .secondary-text {
  display: none;
}

@media only screen and (min-width: 768px) {
  .comment-navigation .nav-previous .secondary-text,
  .comment-navigation .nav-next .secondary-text {
    display: inline;
  }
}

.comment-navigation .nav-previous svg,
.comment-navigation .nav-next svg {
  vertical-align: middle;
  position: relative;
  margin: 0 -0.35em;
  top: -1px;
}

.comment-navigation .nav-next {
  text-align: left;
}

/* Accessibility */
/* Text meant only for screen readers. */
.screen-reader-text {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute !important;
  width: 1px;
  word-wrap: normal !important;
  /* Many screen reader and browser combinations announce broken words as they would appear visually. */
}

.screen-reader-text:focus {
  background-color: #f1f1f1;
  border-radius: 3px;
  box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
  clip: auto !important;
  clip-path: none;
  color: #21759b;
  display: block;
  font-size: 0.875rem;
  font-weight: bold;
  height: auto;
  right: 5px;
  line-height: normal;
  padding: 15px 23px 14px;
  text-decoration: none;
  top: 5px;
  width: auto;
  z-index: 100000;
  /* Above WP toolbar. */
}

/* Do not show the outline on the skip link target. */
#content[tabindex="-1"]:focus {
  outline: 0;
}

/* Alignments */
.alignleft {
  float: left;
  margin-right: 1rem;
}

@media only screen and (min-width: 768px) {
  .alignleft {
    margin-right: calc(2 * 1rem);
  }
}

.alignright {
  float: right;
  margin-left: 1rem;
}

@media only screen and (min-width: 768px) {
  .alignright {
    margin-left: calc(2 * 1rem);
  }
}

.aligncenter {
  clear: both;
  display: block;
  margin-right: auto;
  margin-left: auto;
}

/* Clearings */
.clear:before,
.clear:after,
.entry-content:before,
.entry-content:after,
.comment-content:before,
.comment-content:after,
.site-header:before,
.site-header:after,
.site-content:before,
.site-content:after,
.site-footer:before,
.site-footer:after {
  content: "";
  display: table;
  table-layout: fixed;
}

.clear:after,
.entry-content:after,
.comment-content:after,
.site-header:after,
.site-content:after,
.site-footer:after {
  clear: both;
}

/* Layout */
/** === Layout === */
#page {
  width: 100%;
}

.site-content {
  overflow: hidden;
}

/* Content */
/*--------------------------------------------------------------
## Header
--------------------------------------------------------------*/
.site-header {
  padding: 1em;
}

.site-header.featured-image {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  min-height: 90vh;
}

.site-header.featured-image .site-branding-container {
  margin-bottom: auto;
}

@media only screen and (min-width: 768px) {
  .site-header {
    margin: 0;
    padding: 3rem 0;
  }
  .site-header.featured-image {
    min-height: 100vh;
    margin-bottom: 3rem;
  }
}

.site-branding {
  color: #767676;
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
  position: relative;
  word-wrap: break-word;
}

@media only screen and (min-width: 768px) {
  .site-branding {
    margin: 0 calc(10% + 60px);
  }
}

.site-logo {
  position: relative;
  z-index: 999;
  margin-bottom: calc(.66 * 1rem);
}

@media only screen and (min-width: 768px) {
  .site-logo {
    margin-bottom: 0;
    position: absolute;
    left: calc(100% + (1.25 * 1rem));
    top: 4px;
    z-index: 999;
  }
}

.site-logo .custom-logo-link {
  border-radius: 100%;
  box-sizing: content-box;
  box-shadow: 0 0 0 0 rgba(0, 0, 0, 0);
  display: block;
  width: 50px;
  height: 50px;
  overflow: hidden;
  transition: box-shadow 200ms ease-in-out;
}

.site-logo .custom-logo-link .custom-logo {
  min-height: inherit;
}

.site-logo .custom-logo-link:hover, .site-logo .custom-logo-link:active, .site-logo .custom-logo-link:focus {
  box-shadow: 0 0 0 2px black;
}

@media only screen and (min-width: 768px) {
  .site-logo .custom-logo-link {
    width: 64px;
    height: 64px;
  }
}

.site-title {
  margin: auto;
  display: inline;
  color: #111;
  /* When there is no description set, make sure navigation appears below title. */
}

.site-title a {
  color: #111;
}

.site-title a:link, .site-title a:visited {
  color: #111;
}

.site-title a:hover {
  color: #4a4a4a;
}

.featured-image .site-title {
  margin: 0;
}

@media only screen and (min-width: 768px) {
  .featured-image .site-title {
    display: inline-block;
  }
}

.site-title + .main-navigation {
  display: block;
}

@media only screen and (min-width: 768px) {
  .site-title {
    display: inline;
  }
}

.site-title:not(:empty) + .site-description:not(:empty):before {
  content: "\2014";
  margin: 0 .2em;
}

.site-description {
  display: inline;
  color: #767676;
  font-weight: normal;
  margin: 0;
}

.site-header.featured-image {
  /* Hide overflow for overflowing featured image */
  overflow: hidden;
  /* Need relative positioning to properly align layers. */
  position: relative;
  /* Add text shadow to text, to increase readability. */
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.35);
  /* Set white text color when featured image is set. */
  /* add focus state to social media icons */
  /* Entry header */
  /* Custom Logo Link */
  /* Make sure important elements are above pseudo elements used for effects. */
  /* Set up image filter layer positioning */
  /* Background & Effects */
  /* Shared background settings between pseudo elements. */
  background-position: center;
  background-repeat: no-repeat;
  background-size: cover;
  /* The intensity of each blend mode is controlled via layer opacity. */
  /* Second layer: screen. */
  /* Third layer: multiply. */
  /* When image filters are inactive, a black overlay is added. */
  /* Fourth layer: overlay. */
  /* Fifth layer: readability overlay */
}

.site-header.featured-image .site-branding .site-title,
.site-header.featured-image .site-branding .site-description,
.site-header.featured-image .main-navigation a:after,
.site-header.featured-image .main-navigation .main-menu > li.menu-item-has-children:after,
.site-header.featured-image .main-navigation li,
.site-header.featured-image .social-navigation li,
.site-header.featured-image .entry-meta,
.site-header.featured-image .entry-title {
  color: #fff;
}

.site-header.featured-image .main-navigation a,
.site-header.featured-image .main-navigation a + svg,
.site-header.featured-image .social-navigation a,
.site-header.featured-image .site-title a,
.site-header.featured-image .site-featured-image a {
  color: #fff;
  transition: opacity 110ms ease-in-out;
}

.site-header.featured-image .main-navigation a:hover, .site-header.featured-image .main-navigation a:active,
.site-header.featured-image .main-navigation a:hover + svg,
.site-header.featured-image .main-navigation a:active + svg,
.site-header.featured-image .main-navigation a + svg:hover,
.site-header.featured-image .main-navigation a + svg:active,
.site-header.featured-image .main-navigation a + svg:hover + svg,
.site-header.featured-image .main-navigation a + svg:active + svg,
.site-header.featured-image .social-navigation a:hover,
.site-header.featured-image .social-navigation a:active,
.site-header.featured-image .social-navigation a:hover + svg,
.site-header.featured-image .social-navigation a:active + svg,
.site-header.featured-image .site-title a:hover,
.site-header.featured-image .site-title a:active,
.site-header.featured-image .site-title a:hover + svg,
.site-header.featured-image .site-title a:active + svg,
.site-header.featured-image .site-featured-image a:hover,
.site-header.featured-image .site-featured-image a:active,
.site-header.featured-image .site-featured-image a:hover + svg,
.site-header.featured-image .site-featured-image a:active + svg {
  color: #fff;
  opacity: 0.6;
}

.site-header.featured-image .main-navigation a:focus,
.site-header.featured-image .main-navigation a:focus + svg,
.site-header.featured-image .main-navigation a + svg:focus,
.site-header.featured-image .main-navigation a + svg:focus + svg,
.site-header.featured-image .social-navigation a:focus,
.site-header.featured-image .social-navigation a:focus + svg,
.site-header.featured-image .site-title a:focus,
.site-header.featured-image .site-title a:focus + svg,
.site-header.featured-image .site-featured-image a:focus,
.site-header.featured-image .site-featured-image a:focus + svg {
  color: #fff;
}

.site-header.featured-image .main-navigation .sub-menu a {
  opacity: inherit;
}

.site-header.featured-image .social-navigation a:focus {
  color: #fff;
  opacity: 1;
  border-bottom: 1px solid #fff;
}

.site-header.featured-image .social-navigation svg,
.site-header.featured-image .site-featured-image svg {
  /* Use -webkit- only if supporting: Chrome < 54, iOS < 9.3, Android < 4.4.4 */
  -webkit-filter: drop-shadow(0 1px 2px rgba(0, 0, 0, 0.35));
  filter: drop-shadow(0 1px 2px rgba(0, 0, 0, 0.35));
}

.site-header.featured-image .site-featured-image {
  /* First layer: grayscale. */
}

.site-header.featured-image .site-featured-image .post-thumbnail img {
  height: auto;
  right: 50%;
  max-width: 1000%;
  min-height: 100%;
  min-width: 100vw;
  position: absolute;
  top: 50%;
  transform: translateX(50%) translateY(-50%);
  width: auto;
  z-index: 1;
  /* When image filters are active, make it grayscale to colorize it blue. */
}

@supports (object-fit: cover) {
  .site-header.featured-image .site-featured-image .post-thumbnail img {
    height: 100%;
    right: 0;
    object-fit: cover;
    top: 0;
    transform: none;
    width: 100%;
  }
}

.image-filters-enabled .site-header.featured-image .site-featured-image .post-thumbnail img {
  filter: grayscale(100%);
}

.site-header.featured-image .site-featured-image .entry-header {
  margin-top: calc( 4 * 1rem);
  margin-bottom: 0;
  margin-right: 0;
  margin-left: 0;
  /* Entry meta */
}

@media only screen and (min-width: 768px) {
  .site-header.featured-image .site-featured-image .entry-header {
    margin-right: calc(10% + 60px);
    margin-left: calc(10% + 60px);
  }
}

.site-header.featured-image .site-featured-image .entry-header .entry-title:before {
  background: #fff;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta {
  font-weight: 500;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta > span {
  margin-left: 1rem;
  display: inline-block;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta > span:last-child {
  margin-left: 0;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta a {
  transition: color 110ms ease-in-out;
  color: currentColor;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta a:hover {
  text-decoration: none;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta .svg-icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin-left: 0.5em;
}

.site-header.featured-image .site-featured-image .entry-header .entry-meta .discussion-avatar-list {
  display: none;
}

@media only screen and (min-width: 768px) {
  .site-header.featured-image .site-featured-image .entry-header.has-discussion .entry-meta {
    display: flex;
    position: relative;
  }
  .site-header.featured-image .site-featured-image .entry-header.has-discussion .entry-title {
    padding-left: calc(1 * (100vw / 12) + 1rem);
  }
  .site-header.featured-image .site-featured-image .entry-header.has-discussion .entry-meta .comment-count {
    position: absolute;
    left: 0;
  }
  .site-header.featured-image .site-featured-image .entry-header.has-discussion .entry-meta .discussion-avatar-list {
    display: block;
    position: absolute;
    bottom: 100%;
  }
}

.site-header.featured-image .custom-logo-link {
  background: #fff;
  box-shadow: 0 0 0 0 rgba(255, 255, 255, 0);
}

.site-header.featured-image .custom-logo-link:hover, .site-header.featured-image .custom-logo-link:active, .site-header.featured-image .custom-logo-link:focus {
  box-shadow: 0 0 0 2px white;
}

.site-header.featured-image .site-branding {
  position: relative;
  z-index: 10;
}

.site-header.featured-image .site-featured-image .entry-header {
  position: relative;
  z-index: 9;
}

.site-header.featured-image .site-branding-container:after,
.site-header.featured-image .site-featured-image:before,
.site-header.featured-image .site-featured-image:after, .site-header.featured-image:after {
  display: block;
  position: absolute;
  top: 0;
  right: 0;
  content: "\020";
  width: 100%;
  height: 100%;
}

.image-filters-enabled .site-header.featured-image .site-featured-image:before {
  background: #0073aa;
  mix-blend-mode: screen;
  opacity: 0.1;
}

.site-header.featured-image .site-featured-image:after {
  background: #000;
  mix-blend-mode: multiply;
  opacity: .7;
  /* When image filters are active, a blue overlay is added. */
}

.image-filters-enabled .site-header.featured-image .site-featured-image:after {
  background: #0073aa;
  opacity: .8;
  z-index: 3;
  /* Browsers supporting mix-blend-mode don't need opacity < 1 */
}

@supports (mix-blend-mode: multiply) {
  .image-filters-enabled .site-header.featured-image .site-featured-image:after {
    opacity: 1;
  }
}

.image-filters-enabled .site-header.featured-image .site-branding-container:after {
  background: rgba(0, 0, 0, 0.35);
  mix-blend-mode: overlay;
  opacity: 0.5;
  z-index: 4;
  /* Browsers supporting mix-blend-mode can have a light overlay */
}

@supports (mix-blend-mode: overlay) {
  .image-filters-enabled .site-header.featured-image .site-branding-container:after {
    background: rgba(255, 255, 255, 0.35);
  }
}

.site-header.featured-image:after {
  background: #000;
  /**
		 * Add a transition to the readability overlay, to add a subtle
		 * but smooth effect when resizing the screen.
		 */
  transition: opacity 1200ms ease-in-out;
  opacity: 0.7;
  z-index: 5;
  /* When image filters are active, a blue overlay is added. */
}

.image-filters-enabled .site-header.featured-image:after {
  background: #000e14;
  opacity: 0.38;
}

@media only screen and (min-width: 768px) {
  .image-filters-enabled .site-header.featured-image:after {
    opacity: 0.18;
  }
}

.site-header.featured-image ::-moz-selection {
  background: rgba(255, 255, 255, 0.17);
}

.site-header.featured-image ::selection {
  background: rgba(255, 255, 255, 0.17);
}

/*--------------------------------------------------------------
## Posts and pages
--------------------------------------------------------------*/
.sticky {
  display: block;
}

.sticky-post {
  background: #0073aa;
  color: #fff;
  display: inline-block;
  font-weight: bold;
  line-height: 1;
  padding: .25rem;
  position: absolute;
  text-transform: uppercase;
  top: -1rem;
  z-index: 1;
}

.updated:not(.published) {
  display: none;
}

.page-links {
  clear: both;
  margin: 0 0 calc(1.5 * 1rem);
}

.entry {
  margin-top: calc(6 * 1rem);
}

.entry:first-of-type {
  margin-top: 0;
}

.entry .entry-header {
  margin: calc(3 * 1rem) 1rem 1rem;
  position: relative;
}

@media only screen and (min-width: 768px) {
  .entry .entry-header {
    margin: calc(3 * 1rem) calc(10% + 60px) 1rem;
  }
}

.entry .entry-title {
  margin: 0;
}

.entry .entry-title:before {
  background: #767676;
  content: "\020";
  display: block;
  height: 2px;
  margin: 1rem 0;
  width: 1em;
}

.entry .entry-title.has-text-align-center:before {
  margin-right: auto;
  margin-left: auto;
}

.entry .entry-title.has-text-align-right:before {
  margin-right: auto;
}

.entry .entry-title a {
  color: inherit;
}

.entry .entry-title a:hover {
  color: #4a4a4a;
}

.entry .entry-meta,
.entry .entry-footer {
  color: #767676;
  font-weight: 500;
}

.entry .entry-meta > span,
.entry .entry-footer > span {
  margin-left: 1rem;
  display: inline-block;
}

.entry .entry-meta > span:last-child,
.entry .entry-footer > span:last-child {
  margin-left: 0;
}

.entry .entry-meta a,
.entry .entry-footer a {
  transition: color 110ms ease-in-out;
  color: currentColor;
}

.entry .entry-meta a:hover,
.entry .entry-footer a:hover {
  text-decoration: none;
  color: #0073aa;
}

.entry .entry-meta .svg-icon,
.entry .entry-footer .svg-icon {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin-left: 0.5em;
}

.entry .entry-meta {
  margin: 1rem 0;
}

.entry .entry-footer {
  margin: calc(2 * 1rem) 1rem 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-footer {
    margin: 1rem calc(10% + 60px) calc(3 * 1rem);
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-footer {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

.entry .post-thumbnail {
  margin: 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .post-thumbnail {
    margin: 1rem calc(10% + 60px);
  }
}

.entry .post-thumbnail:focus {
  outline: none;
}

.entry .post-thumbnail .post-thumbnail-inner {
  display: block;
}

.entry .post-thumbnail .post-thumbnail-inner img {
  position: relative;
  display: block;
  width: 100%;
}

.image-filters-enabled .entry .post-thumbnail {
  position: relative;
  display: block;
}

.image-filters-enabled .entry .post-thumbnail .post-thumbnail-inner {
  filter: grayscale(100%);
}

.image-filters-enabled .entry .post-thumbnail .post-thumbnail-inner:after {
  background: rgba(0, 0, 0, 0.35);
  content: "";
  display: block;
  height: 100%;
  opacity: .5;
  pointer-events: none;
  position: absolute;
  top: 0;
  width: 100%;
  z-index: 4;
}

@supports (mix-blend-mode: multiply) {
  .image-filters-enabled .entry .post-thumbnail .post-thumbnail-inner:after {
    display: none;
  }
}

.image-filters-enabled .entry .post-thumbnail:before, .image-filters-enabled .entry .post-thumbnail:after {
  position: absolute;
  display: block;
  width: 100%;
  height: 100%;
  top: 0;
  right: 0;
  content: "\020";
  pointer-events: none;
}

.image-filters-enabled .entry .post-thumbnail:before {
  background: #0073aa;
  mix-blend-mode: screen;
  opacity: 0.1;
  z-index: 2;
}

.image-filters-enabled .entry .post-thumbnail:after {
  background: #0073aa;
  mix-blend-mode: multiply;
  opacity: .8;
  z-index: 3;
  /* Browsers supporting mix-blend-mode don't need opacity < 1 */
}

@supports (mix-blend-mode: multiply) {
  .image-filters-enabled .entry .post-thumbnail:after {
    opacity: 1;
  }
}

.entry .entry-content,
.entry .entry-summary {
  max-width: calc(100% - (2 * 1rem));
  margin: 0 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content,
  .entry .entry-summary {
    max-width: 80%;
    margin: 0 10%;
    padding: 0 60px;
  }
}

.entry .entry-content p {
  word-wrap: break-word;
}

.entry .entry-content .more-link {
  transition: color 110ms ease-in-out;
  display: inline;
  color: inherit;
}

.entry .entry-content .more-link:after {
  content: "\02192";
  display: inline-block;
  margin-right: 0.5em;
}

.entry .entry-content .more-link:hover {
  color: #0073aa;
  text-decoration: none;
}

.entry .entry-content a {
  text-decoration: underline;
}

.entry .entry-content a.button, .entry .entry-content a:hover {
  text-decoration: none;
}

.entry .entry-content a.button {
  display: inline-block;
}

.entry .entry-content a.button:hover {
  background: #111;
  color: #fff;
  cursor: pointer;
}

.entry .entry-content > iframe[style] {
  margin: 32px 0 !important;
  max-width: 100% !important;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > iframe[style] {
    max-width: calc(8 * (100vw / 12) - 28px) !important;
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content > iframe[style] {
    max-width: calc(6 * (100vw / 12) - 28px) !important;
  }
}

.entry .entry-content .page-links a {
  margin: calc(0.5 * 1rem);
  text-decoration: none;
}

.entry .entry-content .wp-audio-shortcode {
  max-width: calc(100vw - (2 * 1rem));
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-audio-shortcode {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-audio-shortcode {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

/* Author description */
.author-bio {
  margin: calc(2 * 1rem) 1rem 1rem;
}

@media only screen and (min-width: 768px) {
  .author-bio {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .author-bio {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .author-bio {
    margin: calc(3 * 1rem) calc(10% + 60px);
  }
}

@media only screen and (min-width: 1168px) {
  .author-bio {
    margin: calc(3 * 1rem) calc(10% + 60px);
  }
}

.author-bio .author-title {
  display: inline;
}

.author-bio .author-title:before {
  background: #767676;
  content: "\020";
  display: block;
  height: 2px;
  margin: 1rem 0;
  width: 1em;
}

.author-bio .author-title.has-text-align-center:before {
  margin-right: auto;
  margin-left: auto;
}

.author-bio .author-title.has-text-align-right:before {
  margin-right: auto;
}

.author-bio .author-description {
  display: inline;
  color: #767676;
  font-size: 1.125em;
  line-height: 1.2;
}

.author-bio .author-description .author-link {
  display: inline-block;
}

.author-bio .author-description .author-link:hover {
  color: #005177;
  text-decoration: none;
}

/*--------------------------------------------------------------
## Comments
--------------------------------------------------------------*/
.comment-content a {
  word-wrap: break-word;
}

.bypostauthor {
  display: block;
}

.comments-area {
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
  margin: calc(2 * 1rem) 1rem;
  word-wrap: break-word;
  /* Add extra margin when the comments section is located immediately after the
	 * post itself (this happens on pages).
	 */
}

@media only screen and (min-width: 768px) {
  .comments-area {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .comments-area {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .comments-area {
    margin: calc(3 * 1rem) calc(10% + 60px);
  }
}

.comments-area > * {
  margin-top: calc(2 * 1rem);
  margin-bottom: calc(2 * 1rem);
}

@media only screen and (min-width: 768px) {
  .comments-area > * {
    margin-top: calc(3 * 1rem);
    margin-bottom: calc(3 * 1rem);
  }
}

.entry + .comments-area {
  margin-top: calc(3 * 1rem);
}

@media only screen and (min-width: 768px) {
  .comments-area .comments-title-wrap {
    align-items: baseline;
    display: flex;
    justify-content: space-between;
  }
}

.comments-area .comments-title-wrap .comments-title {
  margin: 0;
}

.comments-area .comments-title-wrap .comments-title:before {
  background: #767676;
  content: "\020";
  display: block;
  height: 2px;
  margin: 1rem 0;
  width: 1em;
}

.comments-area .comments-title-wrap .comments-title.has-text-align-center:before {
  margin-right: auto;
  margin-left: auto;
}

.comments-area .comments-title-wrap .comments-title.has-text-align-right:before {
  margin-right: auto;
}

@media only screen and (min-width: 768px) {
  .comments-area .comments-title-wrap .comments-title {
    flex: 1 0 calc(3 * (100vw / 12));
  }
}

@media only screen and (min-width: 768px) {
  .comments-area .comments-title-wrap .discussion-meta {
    flex: 0 0 calc(2 * (100vw / 12));
    margin-right: 1rem;
  }
}

#comment {
  max-width: 100%;
  box-sizing: border-box;
}

#respond {
  position: relative;
}

#respond .comment-user-avatar {
  margin: 1rem 0 -1rem;
}

#respond .comment .comment-form {
  padding-right: 0;
}

#respond > small {
  display: block;
  font-size: 22px;
  position: absolute;
  right: calc(1rem + 100%);
  top: calc(-3.5 * 1rem);
  width: calc(100vw / 12);
}

#comments > .comments-title:last-child {
  display: none;
}

.comment-form-flex {
  display: flex;
  flex-direction: column;
}

.comment-form-flex .comments-title {
  display: none;
  margin: 0;
  order: 1;
}

.comment-form-flex #respond {
  order: 2;
}

.comment-form-flex #respond + .comments-title {
  display: block;
}

.comment-list {
  list-style: none;
  padding: 0;
}

.comment-list .children {
  margin: 0;
  padding: 0 1rem 0 0;
}

.comment-list > .comment:first-child {
  margin-top: 0;
}

.comment-list .pingback .comment-body,
.comment-list .trackback .comment-body {
  color: #767676;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 0.71111em;
  font-weight: 500;
  margin-top: 1rem;
  margin-bottom: 1rem;
}

.comment-list .pingback .comment-body a:not(.comment-edit-link),
.comment-list .trackback .comment-body a:not(.comment-edit-link) {
  font-weight: bold;
  font-size: 19.55556px;
  line-height: 1.5;
  padding-left: 0.5rem;
  display: block;
}

.comment-list .pingback .comment-body .comment-edit-link,
.comment-list .trackback .comment-body .comment-edit-link {
  color: #767676;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-weight: 500;
}

#respond + .comment-reply {
  display: none;
}

.comment-reply .comment-reply-link {
  display: inline-block;
}

.comment {
  list-style: none;
  position: relative;
}

@media only screen and (min-width: 768px) {
  .comment {
    padding-right: calc(.5 * (1rem + calc(100vw / 12 )));
  }
  .comment.depth-1,
  .comment .children {
    padding-right: 0;
  }
  .comment.depth-1 {
    margin-right: calc(3.25 * 1rem);
  }
}

.comment .comment-body {
  margin: calc(2 * 1rem) 0 0;
}

.comment .comment-meta {
  position: relative;
}

.comment .comment-author .avatar {
  float: right;
  margin-left: 1rem;
  position: relative;
}

@media only screen and (min-width: 768px) {
  .comment .comment-author .avatar {
    float: inherit;
    margin-left: inherit;
    position: absolute;
    top: 0;
    left: calc(100% + 1rem);
  }
}

.comment .comment-author .fn {
  position: relative;
  display: block;
}

.comment .comment-author .fn a {
  color: inherit;
}

.comment .comment-author .fn a:hover {
  color: #005177;
}

.comment .comment-author .post-author-badge {
  border-radius: 100%;
  display: block;
  height: 18px;
  position: absolute;
  background: #008fd3;
  left: calc(100% - 2.5rem);
  top: -3px;
  width: 18px;
}

@media only screen and (min-width: 768px) {
  .comment .comment-author .post-author-badge {
    left: calc(100% + 0.75rem);
  }
}

.comment .comment-author .post-author-badge svg {
  width: inherit;
  height: inherit;
  display: block;
  fill: white;
  transform: scale(0.875);
}

.comment .comment-metadata > a,
.comment .comment-metadata .comment-edit-link {
  display: inline;
  font-weight: 500;
  color: #767676;
  vertical-align: baseline;
}

.comment .comment-metadata > a time,
.comment .comment-metadata .comment-edit-link time {
  vertical-align: baseline;
}

.comment .comment-metadata > a:hover,
.comment .comment-metadata .comment-edit-link:hover {
  color: #005177;
  text-decoration: none;
}

.comment .comment-metadata > * {
  display: inline-block;
}

.comment .comment-metadata .edit-link-sep {
  color: #767676;
  margin: 0 0.2em;
  vertical-align: baseline;
}

.comment .comment-metadata .edit-link {
  color: #767676;
}

.comment .comment-metadata .edit-link svg {
  transform: scale(0.8);
  vertical-align: baseline;
  margin-left: 0.1em;
}

.comment .comment-metadata .comment-edit-link {
  position: relative;
  padding-right: 1rem;
  margin-right: -1rem;
  z-index: 1;
}

.comment .comment-metadata .comment-edit-link:hover {
  color: #0073aa;
}

.comment .comment-content {
  margin: 1rem 0;
}

@media only screen and (min-width: 1168px) {
  .comment .comment-content {
    padding-left: 1rem;
  }
}

.comment .comment-content > *:first-child {
  margin-top: 0;
}

.comment .comment-content > *:last-child {
  margin-bottom: 0;
}

.comment .comment-content blockquote {
  margin-right: 0;
}

.comment .comment-content a {
  text-decoration: underline;
}

.comment .comment-content a:hover {
  text-decoration: none;
}

.comment-reply-link,
#cancel-comment-reply-link {
  font-weight: 500;
}

.comment-reply-link:hover,
#cancel-comment-reply-link:hover {
  color: #005177;
}

.discussion-avatar-list {
  content: "";
  display: table;
  table-layout: fixed;
  margin: 0;
  padding: 0;
}

.discussion-avatar-list li {
  position: relative;
  list-style: none;
  margin: 0 0 0 -8px;
  padding: 0;
  float: right;
}

.discussion-avatar-list .comment-user-avatar img {
  height: calc(1.5 * 1rem);
  width: calc(1.5 * 1rem);
}

.discussion-meta .discussion-meta-info {
  margin: 0;
}

.discussion-meta .discussion-meta-info .svg-icon {
  vertical-align: middle;
  fill: currentColor;
  transform: scale(0.6) scaleX(-1) translateY(-0.1em);
  margin-right: -0.25rem;
}

.comment-form .comment-notes,
.comment-form label {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 0.71111em;
  color: #767676;
}

.comment-form #wp-comment-cookies-consent {
  margin: 0 0 0 10px;
}

@media only screen and (min-width: 768px) {
  .comment-form .comment-form-author,
  .comment-form .comment-form-email {
    width: calc(50% - 0.5rem);
    float: right;
  }
}

@media only screen and (min-width: 768px) {
  .comment-form .comment-form-email {
    margin-right: 1rem;
  }
}

.comment-form input[name="author"],
.comment-form input[name="email"],
.comment-form input[name="url"] {
  display: block;
  width: 100%;
}

/*--------------------------------------------------------------
## Archives
--------------------------------------------------------------*/
.archive .page-header,
.search .page-header,
.error404 .page-header {
  margin: 1rem 1rem calc(3 * 1rem);
}

@media only screen and (min-width: 768px) {
  .archive .page-header,
  .search .page-header,
  .error404 .page-header {
    margin: 0 calc(10% + 60px) calc(3 * 1rem);
  }
}

.archive .page-header .page-title,
.search .page-header .page-title,
.error404 .page-header .page-title {
  color: #767676;
  display: inline;
  letter-spacing: normal;
}

.archive .page-header .page-title:before,
.search .page-header .page-title:before,
.error404 .page-header .page-title:before {
  display: none;
}

.archive .page-header .search-term,
.archive .page-header .page-description,
.search .page-header .search-term,
.search .page-header .page-description,
.error404 .page-header .search-term,
.error404 .page-header .page-description {
  display: inherit;
  clear: both;
}

.archive .page-header .page-description,
.search .page-header .page-description {
  display: block;
  color: #111;
  font-size: 1em;
}

@media only screen and (min-width: 768px) {
  .hfeed .entry .entry-header {
    margin: calc(3 * 1rem) calc(10% + 60px) calc(1rem / 2);
  }
}

/* 404 & Not found */
.error-404.not-found .page-content,
.no-results.not-found .page-content {
  margin: calc(3 * 1rem) 1rem;
}

@media only screen and (min-width: 768px) {
  .error-404.not-found .page-content,
  .no-results.not-found .page-content {
    margin: calc(3 * 1rem) calc(10% + 60px) calc(1rem / 2);
  }
}

.error-404.not-found .search-submit,
.no-results.not-found .search-submit {
  vertical-align: middle;
  margin: 1rem 0;
}

.error-404.not-found .search-field,
.no-results.not-found .search-field {
  width: 100%;
}

/*--------------------------------------------------------------
## Footer
--------------------------------------------------------------*/
/* Site footer */
#colophon .widget-area,
#colophon .site-info {
  margin: calc(2 * 1rem) 1rem;
}

@media only screen and (min-width: 768px) {
  #colophon .widget-area,
  #colophon .site-info {
    margin: calc(3 * 1rem) calc(10% + 60px);
  }
}

#colophon .widget-column {
  display: flex;
  flex-wrap: wrap;
}

#colophon .widget-column .widget {
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
  width: 100%;
  word-wrap: break-word;
}

@media only screen and (min-width: 1168px) {
  #colophon .widget-column .widget {
    margin-left: calc(3 * 1rem);
    width: calc(50% - (3 * 1rem));
  }
}

#colophon .site-info {
  color: #767676;
  -webkit-hyphens: auto;
  -moz-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto;
  word-wrap: break-word;
}

#colophon .site-info a {
  color: inherit;
}

#colophon .site-info a:hover {
  text-decoration: none;
  color: #0073aa;
}

#colophon .site-info .imprint,
#colophon .site-info .privacy-policy-link {
  margin-left: 1rem;
}

/* Widgets */
.widget {
  margin: 0 0 1rem;
  /* Make sure select elements fit in widgets. */
}

.widget .widget-title {
  font-size: 1.6875em;
}

.widget select {
  max-width: 100%;
}

.widget a {
  color: #0073aa;
}

.widget a:hover {
  color: #005177;
}

.widget_archive ul,
.widget_categories ul,
.widget_meta ul,
.widget_nav_menu ul,
.widget_pages ul,
.widget_recent_comments ul,
.widget_recent_entries ul,
.widget_rss ul {
  padding: 0;
  list-style: none;
}

.widget_archive ul li,
.widget_categories ul li,
.widget_meta ul li,
.widget_nav_menu ul li,
.widget_pages ul li,
.widget_recent_comments ul li,
.widget_recent_entries ul li,
.widget_rss ul li {
  color: #767676;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: calc(22px * 1.125);
  font-weight: 700;
  line-height: 1.2;
  margin-top: 0.5rem;
  margin-bottom: 0.5rem;
}

.widget_archive ul ul,
.widget_categories ul ul,
.widget_meta ul ul,
.widget_nav_menu ul ul,
.widget_pages ul ul,
.widget_recent_comments ul ul,
.widget_recent_entries ul ul,
.widget_rss ul ul {
  counter-reset: submenu;
}

.widget_archive ul ul > li > a::before,
.widget_categories ul ul > li > a::before,
.widget_meta ul ul > li > a::before,
.widget_nav_menu ul ul > li > a::before,
.widget_pages ul ul > li > a::before,
.widget_recent_comments ul ul > li > a::before,
.widget_recent_entries ul ul > li > a::before,
.widget_rss ul ul > li > a::before {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: normal;
  content: "– " counters(submenu, "– ", none);
  counter-increment: submenu;
}

.widget_tag_cloud .tagcloud {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-weight: 700;
}

.widget_search .search-field {
  width: 100%;
}

@media only screen and (min-width: 600px) {
  .widget_search .search-field {
    width: auto;
  }
}

.widget_search .search-submit {
  display: block;
  margin-top: 1rem;
}

.widget_calendar .calendar_wrap {
  text-align: center;
}

.widget_calendar .calendar_wrap table td,
.widget_calendar .calendar_wrap table th {
  border: none;
}

.widget_calendar .calendar_wrap a {
  text-decoration: underline;
}

.widget_calendar .calendar_wrap .wp-calendar-table {
  margin-bottom: 0;
}

.widget_calendar .calendar_wrap .wp-calendar-nav {
  margin: 0 0 1rem;
  display: table;
  width: 100%;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}

.widget_calendar .calendar_wrap .wp-calendar-nav span {
  display: table-cell;
  padding: 0.5em;
}

.widget_calendar .calendar_wrap .wp-calendar-nav-prev,
.widget_calendar .calendar_wrap .wp-calendar-nav-next {
  width: 40%;
}

/* Blocks */
/* !Block styles */
.entry .entry-content > *,
.entry .entry-summary > *,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > * {
  margin: 32px 0;
  max-width: 100%;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *,
  .entry .entry-summary > *,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > * {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content > *,
  .entry .entry-summary > *,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > * {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *,
  .entry .entry-summary > *,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > * {
    margin: 32px 0;
  }
}

.entry .entry-content > *.alignwide,
.entry .entry-summary > *.alignwide,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignwide,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignwide {
  margin-right: auto;
  margin-left: auto;
  clear: both;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.alignwide,
  .entry .entry-summary > *.alignwide,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignwide,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignwide {
    width: 100%;
    max-width: 100%;
  }
}

.entry .entry-content > *.alignfull,
.entry .entry-summary > *.alignfull,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignfull,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignfull {
  position: relative;
  right: -1rem;
  width: calc( 100% + (2 * 1rem));
  max-width: calc( 100% + (2 * 1rem));
  clear: both;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.alignfull,
  .entry .entry-summary > *.alignfull,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignfull,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignfull {
    margin-top: calc(2 * 1rem);
    margin-bottom: calc(2 * 1rem);
    right: calc( -12.5% - 75px);
    width: calc( 125% + 150px);
    max-width: calc( 125% + 150px);
  }
}

.entry .entry-content > *.alignleft,
.entry .entry-summary > *.alignleft,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignleft,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignleft {
  float: left;
  max-width: calc(5 * (100vw / 12));
  margin-top: 0;
  margin-right: 0;
  margin-right: 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.alignleft,
  .entry .entry-summary > *.alignleft,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignleft,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignleft {
    max-width: calc(4 * (100vw / 12));
    margin-right: calc(2 * 1rem);
  }
}

.entry .entry-content > *.alignright,
.entry .entry-summary > *.alignright,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignright,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignright {
  float: right;
  max-width: calc(5 * (100vw / 12));
  margin-top: 0;
  margin-left: 0;
  margin-left: 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.alignright,
  .entry .entry-summary > *.alignright,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.alignright,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.alignright {
    max-width: calc(4 * (100vw / 12));
    margin-left: 0;
    margin-left: calc(2 * 1rem);
  }
}

.entry .entry-content > *.aligncenter,
.entry .entry-summary > *.aligncenter,
.entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.aligncenter,
.entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.aligncenter {
  margin-right: auto;
  margin-left: auto;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.aligncenter,
  .entry .entry-summary > *.aligncenter,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.aligncenter,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.aligncenter {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content > *.aligncenter,
  .entry .entry-summary > *.aligncenter,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.aligncenter,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.aligncenter {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content > *.aligncenter,
  .entry .entry-summary > *.aligncenter,
  .entry .entry-summary > .wp-block-group > .wp-block-group__inner-container > *.aligncenter,
  .entry .entry-content > .wp-block-group > .wp-block-group__inner-container > *.aligncenter {
    margin-right: 0;
    margin-left: 0;
  }
}

.entry .entry-content > * > *:first-child,
.entry .entry-summary > * > *:first-child {
  margin-top: 0;
}

.entry .entry-content > * > *:last-child,
.entry .entry-summary > * > *:last-child {
  margin-bottom: 0;
}

/*
 * Unset nested content selector styles
 * - Prevents layout styles from cascading too deeply
 * - helps with plugin compatibility
 */
.entry .entry-content .entry-content,
.entry .entry-content .entry-summary,
.entry .entry-content .entry,
.entry .entry-summary .entry-content,
.entry .entry-summary .entry-summary,
.entry .entry-summary .entry {
  margin: inherit;
  max-width: inherit;
  padding: inherit;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .entry-content,
  .entry .entry-content .entry-summary,
  .entry .entry-content .entry,
  .entry .entry-summary .entry-content,
  .entry .entry-summary .entry-summary,
  .entry .entry-summary .entry {
    margin: inherit;
    max-width: inherit;
    padding: inherit;
  }
}

.entry .entry-content p.has-background {
  padding: 20px 30px;
}

.entry .entry-content .wp-block-audio {
  width: 100%;
}

.entry .entry-content .wp-block-audio audio {
  width: 100%;
}

.entry .entry-content .wp-block-audio.alignleft audio,
.entry .entry-content .wp-block-audio.alignright audio {
  max-width: 198px;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-audio.alignleft audio,
  .entry .entry-content .wp-block-audio.alignright audio {
    max-width: 384px;
  }
}

@media only screen and (min-width: 1379px) {
  .entry .entry-content .wp-block-audio.alignleft audio,
  .entry .entry-content .wp-block-audio.alignright audio {
    max-width: 385.44px;
  }
}

.entry .entry-content .wp-block-video video {
  width: 100%;
}

.entry .entry-content .wp-block-button .wp-block-button__link {
  transition: background 150ms ease-in-out;
  border: none;
  font-size: 0.88889em;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.2;
  box-sizing: border-box;
  font-weight: bold;
  text-decoration: none;
  padding: 0.76rem 1rem;
  outline: none;
  outline: none;
}

.entry .entry-content .wp-block-button .wp-block-button__link:not(.has-background) {
  background-color: #0073aa;
}

.entry .entry-content .wp-block-button .wp-block-button__link:not(.has-text-color) {
  color: white;
}

.entry .entry-content .wp-block-button .wp-block-button__link:hover {
  color: white;
  background: #111;
  cursor: pointer;
}

.entry .entry-content .wp-block-button .wp-block-button__link:focus {
  color: white;
  background: #111;
  outline: thin dotted;
  outline-offset: -4px;
}

.entry .entry-content .wp-block-button:not(.is-style-squared) .wp-block-button__link {
  border-radius: 5px;
}

.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link,
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:focus,
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:active {
  transition: all 150ms ease-in-out;
  border-width: 2px;
  border-style: solid;
}

.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:not(.has-background),
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:focus:not(.has-background),
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:active:not(.has-background) {
  background: transparent;
}

.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:not(.has-text-color),
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:focus:not(.has-text-color),
.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:active:not(.has-text-color) {
  color: #0073aa;
  border-color: currentColor;
}

.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:hover {
  color: white;
  border-color: #111;
}

.entry .entry-content .wp-block-button.is-style-outline .wp-block-button__link:hover:not(.has-background) {
  color: #111;
}

.entry .entry-content .wp-block-archives,
.entry .entry-content .wp-block-categories,
.entry .entry-content .wp-block-latest-posts {
  padding: 0;
  list-style: none;
}

.entry .entry-content .wp-block-archives li > a,
.entry .entry-content .wp-block-categories li > a,
.entry .entry-content .wp-block-latest-posts li > a {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: calc(22px * 1.125);
  font-weight: bold;
  line-height: 1.2;
  text-decoration: none;
}

.entry .entry-content .wp-block-archives.aligncenter,
.entry .entry-content .wp-block-categories.aligncenter {
  text-align: center;
}

.entry .entry-content .wp-block-categories ul {
  padding-top: 0.75rem;
}

.entry .entry-content .wp-block-categories li ul {
  list-style: none;
  padding-right: 0;
}

.entry .entry-content .wp-block-categories ul {
  counter-reset: submenu;
}

.entry .entry-content .wp-block-categories ul > li > a::before {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-weight: normal;
  content: "– " counters(submenu, "– ", none);
  counter-increment: submenu;
}

.entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-date {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 0.71111em;
  color: #767676;
  line-height: 1.2;
}

.entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-full-content,
.entry .entry-content .wp-block-latest-posts .wp-block-latest-posts__post-excerpt {
  margin-top: 1rem;
  margin-bottom: 1rem;
}

.entry .entry-content .wp-block-latest-posts li {
  padding-bottom: 0.5rem;
}

.entry .entry-content .wp-block-latest-posts li.menu-item-has-children, .entry .entry-content .wp-block-latest-posts li:last-child {
  padding-bottom: 0;
}

.entry .entry-content .wp-block-latest-posts li :not(:last-child) .wp-block-latest-posts__post-excerpt {
  padding-bottom: 0.5rem;
}

.entry .entry-content .wp-block-latest-posts.is-grid li {
  border-top: 2px solid #ccc;
  padding-top: 1rem;
  margin-bottom: 2rem;
}

.entry .entry-content .wp-block-latest-posts.is-grid li a:after {
  content: '';
}

.entry .entry-content .wp-block-latest-posts.is-grid li:last-child {
  margin-bottom: auto;
}

.entry .entry-content .wp-block-latest-posts.is-grid li:last-child a:after {
  content: '';
}

.entry .entry-content .wp-block-preformatted {
  font-size: 0.71111em;
  line-height: 1.8;
  padding: 1rem;
}

.entry .entry-content .wp-block-verse {
  font-family: "NonBreakingSpaceOverride", "Hoefler Text", Garamond, "Times New Roman", serif;
  font-size: 22px;
  line-height: 1.8;
}

.entry .entry-content .has-drop-cap:not(:focus):first-letter {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 3.375em;
  line-height: 1;
  font-weight: bold;
  margin: 0 0 0 0.25em;
}

@-moz-document url-prefix() {
  .entry .entry-content .has-drop-cap:not(:focus):first-letter {
    margin-top: 0.2em;
  }
}

.entry .entry-content .wp-block-pullquote {
  border-color: transparent;
  border-width: 2px;
  padding: 1rem;
}

.entry .entry-content .wp-block-pullquote blockquote {
  color: #111;
  border: none;
  margin-top: calc(4 * 1rem);
  margin-bottom: calc(4.33 * 1rem);
  margin-left: 0;
  padding-right: 0;
}

.entry .entry-content .wp-block-pullquote p {
  font-size: 1.6875em;
  font-style: italic;
  line-height: 1.3;
  margin-bottom: 0.5em;
  margin-top: 0.5em;
}

.entry .entry-content .wp-block-pullquote p em {
  font-style: normal;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote p {
    font-size: 2.25em;
  }
}

.entry .entry-content .wp-block-pullquote cite {
  display: inline-block;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.6;
  text-transform: none;
  color: #767676;
  /*
			 * This requires a rem-based font size calculation instead of our normal em-based one,
			 * because the cite tag sometimes gets wrapped in a p tag. This is equivalent to $font-size_xs.
			 */
  font-size: calc(1rem / (1.25 * 1.125));
}

.entry .entry-content .wp-block-pullquote.alignleft, .entry .entry-content .wp-block-pullquote.alignright {
  width: 100%;
  padding: 0;
}

.entry .entry-content .wp-block-pullquote.alignleft blockquote, .entry .entry-content .wp-block-pullquote.alignright blockquote {
  margin: 1rem 0;
  padding: 0;
  text-align: right;
  max-width: 100%;
}

.entry .entry-content .wp-block-pullquote.alignleft blockquote p:first-child, .entry .entry-content .wp-block-pullquote.alignright blockquote p:first-child {
  margin-top: 0;
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color {
  background-color: #0073aa;
  padding-right: 0;
  padding-left: 0;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote.is-style-solid-color {
    padding-right: 10%;
    padding-left: 10%;
  }
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color p {
  font-size: 1.6875em;
  line-height: 1.3;
  margin-bottom: 0.5em;
  margin-top: 0.5em;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote.is-style-solid-color p {
    font-size: 2.25em;
  }
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color a {
  color: #fff;
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color cite {
  color: inherit;
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote {
  max-width: 100%;
  color: #fff;
  padding-right: 0;
  margin-right: 1rem;
  margin-left: 1rem;
}

.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-text-color p,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-text-color a, .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-primary-color, .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-secondary-color, .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-dark-gray-color, .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-light-gray-color, .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-white-color {
  color: inherit;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote {
    margin-right: 0;
    margin-left: 0;
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote.is-style-solid-color.alignright, .entry .entry-content .wp-block-pullquote.is-style-solid-color.alignleft {
    padding: 1rem calc(2 * 1rem);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-pullquote.is-style-solid-color.alignfull {
    padding-right: calc(10% + 58px + (2 * 1rem));
    padding-left: calc(10% + 58px + (2 * 1rem));
  }
}

.entry .entry-content .wp-block-quote:not(.is-large), .entry .entry-content .wp-block-quote:not(.is-style-large) {
  border-width: 2px;
  border-color: #0073aa;
  padding-top: 0;
  padding-bottom: 0;
}

.entry .entry-content .wp-block-quote p {
  font-size: 1em;
  font-style: normal;
  line-height: 1.8;
}

.entry .entry-content .wp-block-quote cite {
  /*
			 * This requires a rem-based font size calculation instead of our normal em-based one,
			 * because the cite tag sometimes gets wrapped in a p tag. This is equivalent to $font-size_xs.
			 */
  font-size: calc(1rem / (1.25 * 1.125));
}

.entry .entry-content .wp-block-quote.is-large, .entry .entry-content .wp-block-quote.is-style-large {
  margin: 1rem 0;
  padding: 0;
  border-right: none;
}

.entry .entry-content .wp-block-quote.is-large p, .entry .entry-content .wp-block-quote.is-style-large p {
  font-size: 1.6875em;
  line-height: 1.4;
  font-style: italic;
}

.entry .entry-content .wp-block-quote.is-large cite,
.entry .entry-content .wp-block-quote.is-large footer, .entry .entry-content .wp-block-quote.is-style-large cite,
.entry .entry-content .wp-block-quote.is-style-large footer {
  /*
				 * This requires a rem-based font size calculation instead of our normal em-based one,
				 * because the cite tag sometimes gets wrapped in a p tag. This is equivalent to $font-size_xs.
				 */
  font-size: calc(1rem / (1.25 * 1.125));
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-quote.is-large, .entry .entry-content .wp-block-quote.is-style-large {
    margin: 1rem 0;
    padding: 1rem 0;
  }
  .entry .entry-content .wp-block-quote.is-large p, .entry .entry-content .wp-block-quote.is-style-large p {
    font-size: 1.6875em;
  }
}

.entry .entry-content .wp-block-image {
  max-width: 100%;
}

.entry .entry-content .wp-block-image img {
  display: block;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-image:not(.alignwide):not(.alignfull) > img {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-image:not(.alignwide):not(.alignfull) > img {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-image .aligncenter {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-image .aligncenter {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-image .aligncenter {
    margin: 0;
    width: calc(8 * (100vw / 12) - 28px);
  }
  .entry .entry-content .wp-block-image .aligncenter img {
    margin: 0 auto;
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-image .aligncenter {
    width: calc(6 * (100vw / 12) - 28px);
  }
  .entry .entry-content .wp-block-image .aligncenter img {
    margin: 0 auto;
  }
}

.entry .entry-content .wp-block-image.alignfull img {
  width: 100vw;
  max-width: calc( 100% + (2 * 1rem));
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-image.alignfull img {
    max-width: calc( 125% + 150px);
    margin-right: auto;
    margin-left: auto;
  }
}

.entry .entry-content .wp-block-cover-image,
.entry .entry-content .wp-block-cover {
  position: relative;
  min-height: 430px;
  padding: 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-cover-image,
  .entry .entry-content .wp-block-cover {
    padding: 1rem 10%;
  }
}

.entry .entry-content .wp-block-cover-image .wp-block-cover-image-text,
.entry .entry-content .wp-block-cover-image .wp-block-cover-text,
.entry .entry-content .wp-block-cover-image h2,
.entry .entry-content .wp-block-cover .wp-block-cover-image-text,
.entry .entry-content .wp-block-cover .wp-block-cover-text,
.entry .entry-content .wp-block-cover h2 {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-size: 1.6875em;
  font-weight: bold;
  line-height: 1.25;
  padding: 0;
  color: #fff;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-cover-image .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover-image .wp-block-cover-text,
  .entry .entry-content .wp-block-cover-image h2,
  .entry .entry-content .wp-block-cover .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover .wp-block-cover-text,
  .entry .entry-content .wp-block-cover h2 {
    font-size: 2.25em;
    max-width: 100%;
  }
}

.entry .entry-content .wp-block-cover-image.alignleft, .entry .entry-content .wp-block-cover-image.alignright,
.entry .entry-content .wp-block-cover.alignleft,
.entry .entry-content .wp-block-cover.alignright {
  width: 100%;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-cover-image.alignleft, .entry .entry-content .wp-block-cover-image.alignright,
  .entry .entry-content .wp-block-cover.alignleft,
  .entry .entry-content .wp-block-cover.alignright {
    padding: 1rem calc(2 * 1rem);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover-image.alignfull h2,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover.alignfull h2 {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover-image.alignfull h2,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover.alignfull h2 {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-cover-image.alignfull,
  .entry .entry-content .wp-block-cover.alignfull {
    padding-right: calc(10% + 58px + (2 * 1rem));
    padding-left: calc(10% + 58px + (2 * 1rem));
  }
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover-image.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover-image.alignfull h2,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-image-text,
  .entry .entry-content .wp-block-cover.alignfull .wp-block-cover-text,
  .entry .entry-content .wp-block-cover.alignfull h2 {
    padding: 0;
  }
}

.entry .entry-content .wp-block-gallery {
  list-style-type: none;
  padding-right: 0;
}

.entry .entry-content .wp-block-gallery .blocks-gallery-image:last-child,
.entry .entry-content .wp-block-gallery .blocks-gallery-item:last-child {
  margin-bottom: 16px;
}

.entry .entry-content .wp-block-gallery figcaption a {
  color: #fff;
}

.entry .entry-content .wp-block-audio figcaption,
.entry .entry-content .wp-block-video figcaption,
.entry .entry-content .wp-block-image figcaption,
.entry .entry-content .wp-block-gallery .blocks-gallery-image figcaption,
.entry .entry-content .wp-block-gallery .blocks-gallery-item figcaption {
  font-size: 0.71111em;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.6;
  margin: 0;
  padding: 0.5rem;
  text-align: center;
}

.entry .entry-content .wp-block-separator,
.entry .entry-content hr {
  background-color: #767676;
  border: 0;
  height: 2px;
  margin-bottom: 2rem;
  margin-top: 2rem;
  max-width: 2.25em;
  text-align: right;
  /* Remove duplicate rule-line when a separator
		 * is followed by an H1, or H2 */
}

.entry .entry-content .wp-block-separator:not(.wp-block-separator),
.entry .entry-content hr:not(.wp-block-separator) {
  max-width: 100%;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-separator:not(.wp-block-separator),
  .entry .entry-content hr:not(.wp-block-separator) {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-separator:not(.wp-block-separator),
  .entry .entry-content hr:not(.wp-block-separator) {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

.entry .entry-content .wp-block-separator.is-style-wide,
.entry .entry-content hr.is-style-wide {
  max-width: 100%;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-separator.is-style-wide,
  .entry .entry-content hr.is-style-wide {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-separator.is-style-wide,
  .entry .entry-content hr.is-style-wide {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

.entry .entry-content .wp-block-separator.is-style-dots,
.entry .entry-content hr.is-style-dots {
  max-width: 100%;
  background-color: inherit;
  border: inherit;
  height: inherit;
  text-align: center;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-separator.is-style-dots,
  .entry .entry-content hr.is-style-dots {
    max-width: calc(8 * (100vw / 12) - 28px);
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-separator.is-style-dots,
  .entry .entry-content hr.is-style-dots {
    max-width: calc(6 * (100vw / 12) - 28px);
  }
}

.entry .entry-content .wp-block-separator.is-style-dots:not(.has-text-color):not(.has-background),
.entry .entry-content hr.is-style-dots:not(.has-text-color):not(.has-background) {
  color: #767676;
}

.entry .entry-content .wp-block-separator.is-style-dots:before,
.entry .entry-content hr.is-style-dots:before {
  font-size: 1.6875em;
  letter-spacing: 0.88889em;
  padding-right: 0.88889em;
}

.entry .entry-content .wp-block-separator + h1:before,
.entry .entry-content .wp-block-separator + h2:before,
.entry .entry-content hr + h1:before,
.entry .entry-content hr + h2:before {
  display: none;
}

.entry .entry-content .wp-block-embed-twitter {
  word-break: break-word;
}

.entry .entry-content .wp-block-table th,
.entry .entry-content .wp-block-table td {
  border-color: #767676;
}

.entry .entry-content .wp-block-file {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
}

.entry .entry-content .wp-block-file .wp-block-file__button {
  display: table;
  transition: background 150ms ease-in-out;
  border: none;
  border-radius: 5px;
  background: #0073aa;
  font-size: 22px;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.2;
  text-decoration: none;
  font-weight: bold;
  padding: 0.75rem 1rem;
  color: #fff;
  margin-right: 0;
  margin-top: calc(0.75 * 1rem);
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-file .wp-block-file__button {
    font-size: 22px;
    padding: 0.875rem 1.5rem;
  }
}

.entry .entry-content .wp-block-file .wp-block-file__button:hover {
  background: #111;
  cursor: pointer;
}

.entry .entry-content .wp-block-file .wp-block-file__button:focus {
  background: #111;
  outline: thin dotted;
  outline-offset: -4px;
}

.entry .entry-content .wp-block-code {
  border-radius: 0;
}

.entry .entry-content .wp-block-code code {
  font-size: 1.125em;
  white-space: pre-wrap;
  word-break: break-word;
}

.entry .entry-content .wp-block-columns .wp-block-column > *:first-child {
  margin-top: 0;
}

.entry .entry-content .wp-block-columns .wp-block-column > *:last-child {
  margin-bottom: 0;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-columns .wp-block-image > img:not(.alignwide):not(.alignfull),
  .entry .entry-content .wp-block-columns .wp-block-image > figure {
    max-width: 100%;
  }
}

@media only screen and (min-width: 1168px) {
  .entry .entry-content .wp-block-columns .wp-block-image > img:not(.alignwide):not(.alignfull),
  .entry .entry-content .wp-block-columns .wp-block-image > figure {
    max-width: 100%;
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-columns {
    flex-wrap: nowrap;
  }
  .entry .entry-content .wp-block-columns .wp-block-column:not(:first-child) {
    margin-right: 32px;
  }
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-group:not(.alignfull) > .wp-block-group__inner-container > .alignfull,
  .entry .entry-content .wp-block-group:not(.alignfull) > .wp-block-group__inner-container > .wp-block-image > img {
    right: 0;
    max-width: 100%;
  }
}

.entry .entry-content .wp-block-group.alignfull > .wp-block-group__inner-container {
  max-width: calc(100% - (2 * 1rem));
  margin: 0 1rem;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-group.alignfull > .wp-block-group__inner-container {
    max-width: 80%;
    margin: 0 10%;
    padding: 0 60px;
  }
}

.entry .entry-content .wp-block-group.has-background {
  padding: 1rem;
  margin-top: 0;
  margin-bottom: 0;
}

.entry .entry-content .wp-block-group.has-background .wp-block-group__inner-container > *:first-child {
  margin-top: 0;
}

.entry .entry-content .wp-block-group.has-background .wp-block-group__inner-container > *:last-child {
  margin-bottom: 0;
}

.entry .entry-content .wp-block-group.has-background.alignfull {
  padding-right: 0;
  padding-left: 0;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-group.has-background.alignfull {
    padding-top: 1rem;
    padding-bottom: 1rem;
  }
}

.entry .entry-content .wp-block-group.has-background:not(.alignfull) > .wp-block-group__inner-container > .alignfull {
  width: 100%;
  max-width: 100%;
}

@media only screen and (min-width: 768px) {
  .entry .entry-content .wp-block-group.has-background:not(.alignfull) > .wp-block-group__inner-container > .alignfull {
    width: calc( 100% + 2rem);
    max-width: calc( 100% + 2rem);
    margin-right: -1rem;
  }
}

.entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  font-weight: bold;
}

.entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-meta .wp-block-latest-comments__comment-date {
  font-weight: normal;
}

.entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment,
.entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-date,
.entry .entry-content .wp-block-latest-comments .wp-block-latest-comments__comment-excerpt p {
  font-size: inherit;
}

.entry .entry-content .wp-block-latest-comments.has-dates .wp-block-latest-comments__comment-date {
  font-size: 0.71111em;
}

.entry .entry-content .has-small-font-size {
  font-size: 0.88889em;
}

.entry .entry-content .has-normal-font-size {
  font-size: 1.125em;
}

.entry .entry-content .has-large-font-size {
  font-size: 1.6875em;
}

.entry .entry-content .has-huge-font-size {
  font-size: 2.25em;
}

.entry .entry-content .has-primary-background-color,
.entry .entry-content .has-secondary-background-color,
.entry .entry-content .has-dark-gray-background-color,
.entry .entry-content .has-light-gray-background-color {
  color: #fff;
}

.entry .entry-content .has-primary-background-color > p,
.entry .entry-content .has-primary-background-color > h1,
.entry .entry-content .has-primary-background-color > h2,
.entry .entry-content .has-primary-background-color > h3,
.entry .entry-content .has-primary-background-color > h4,
.entry .entry-content .has-primary-background-color > h5,
.entry .entry-content .has-primary-background-color > h6,
.entry .entry-content .has-primary-background-color > a,
.entry .entry-content .has-secondary-background-color > p,
.entry .entry-content .has-secondary-background-color > h1,
.entry .entry-content .has-secondary-background-color > h2,
.entry .entry-content .has-secondary-background-color > h3,
.entry .entry-content .has-secondary-background-color > h4,
.entry .entry-content .has-secondary-background-color > h5,
.entry .entry-content .has-secondary-background-color > h6,
.entry .entry-content .has-secondary-background-color > a,
.entry .entry-content .has-dark-gray-background-color > p,
.entry .entry-content .has-dark-gray-background-color > h1,
.entry .entry-content .has-dark-gray-background-color > h2,
.entry .entry-content .has-dark-gray-background-color > h3,
.entry .entry-content .has-dark-gray-background-color > h4,
.entry .entry-content .has-dark-gray-background-color > h5,
.entry .entry-content .has-dark-gray-background-color > h6,
.entry .entry-content .has-dark-gray-background-color > a,
.entry .entry-content .has-light-gray-background-color > p,
.entry .entry-content .has-light-gray-background-color > h1,
.entry .entry-content .has-light-gray-background-color > h2,
.entry .entry-content .has-light-gray-background-color > h3,
.entry .entry-content .has-light-gray-background-color > h4,
.entry .entry-content .has-light-gray-background-color > h5,
.entry .entry-content .has-light-gray-background-color > h6,
.entry .entry-content .has-light-gray-background-color > a {
  color: #fff;
}

.entry .entry-content .has-white-background-color {
  color: #111;
}

.entry .entry-content .has-white-background-color > p,
.entry .entry-content .has-white-background-color > h1,
.entry .entry-content .has-white-background-color > h2,
.entry .entry-content .has-white-background-color > h3,
.entry .entry-content .has-white-background-color > h4,
.entry .entry-content .has-white-background-color > h5,
.entry .entry-content .has-white-background-color > h6,
.entry .entry-content .has-white-background-color > a {
  color: #111;
}

.entry .entry-content .has-primary-background-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color.has-primary-background-color {
  background-color: #0073aa;
}

.entry .entry-content .has-secondary-background-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color.has-secondary-background-color {
  background-color: #005177;
}

.entry .entry-content .has-dark-gray-background-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color.has-dark-gray-background-color {
  background-color: #111;
}

.entry .entry-content .has-light-gray-background-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color.has-light-gray-background-color {
  background-color: #767676;
}

.entry .entry-content .has-white-background-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color.has-white-background-color {
  background-color: #FFF;
}

.entry .entry-content .has-primary-color,
.entry .entry-content .wp-block-pullquote blockquote.has-primary-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-primary-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-primary-color > p {
  color: #0073aa;
}

.entry .entry-content .has-secondary-color,
.entry .entry-content .wp-block-pullquote blockquote.has-secondary-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-secondary-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-secondary-color > p {
  color: #005177;
}

.entry .entry-content .has-dark-gray-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-dark-gray-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-dark-gray-color > p {
  color: #111;
}

.entry .entry-content .has-light-gray-color,
.entry .entry-content .wp-block-pullquote blockquote.has-light-gray-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-light-gray-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-light-gray-color > p {
  color: #767676;
}

.entry .entry-content .has-white-color,
.entry .entry-content .wp-block-pullquote blockquote.has-white-color,
.entry .entry-content .wp-block-pullquote.is-style-solid-color blockquote.has-white-color {
  color: #FFF;
}

/* Media */
.page-content .wp-smiley,
.entry-content .wp-smiley,
.comment-content .wp-smiley {
  border: none;
  margin-bottom: 0;
  margin-top: 0;
  padding: 0;
}

embed,
iframe,
object {
  max-width: 100%;
}

.custom-logo-link {
  display: inline-block;
}

.avatar {
  border-radius: 100%;
  display: block;
  height: calc(2.25 * 1rem);
  min-height: inherit;
  width: calc(2.25 * 1rem);
}

svg {
  transition: fill 120ms ease-in-out;
  fill: currentColor;
}

/*--------------------------------------------------------------
## Captions
--------------------------------------------------------------*/
.wp-caption {
  margin-bottom: calc(1.5 * 1rem);
}

@media only screen and (min-width: 768px) {
  .wp-caption.aligncenter {
    position: relative;
    right: calc( calc(8 * (100vw / 12) - 28px) / 2);
    transform: translateX(50%);
  }
}

@media only screen and (min-width: 1168px) {
  .wp-caption.aligncenter {
    right: calc( calc(6 * (100vw / 12) - 28px) / 2);
  }
}

.wp-caption img[class*="wp-image-"] {
  display: block;
  margin-right: auto;
  margin-left: auto;
}

.wp-caption-text {
  color: #767676;
  font-size: 0.71111em;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.6;
  margin: 0;
  padding: 0.5rem;
  text-align: center;
}

/*--------------------------------------------------------------
## Galleries
--------------------------------------------------------------*/
.gallery {
  display: flex;
  flex-flow: row wrap;
  justify-content: center;
  margin-bottom: calc(1.5 * 1rem);
}

.gallery-item {
  display: inline-block;
  margin-left: 16px;
  margin-bottom: 16px;
  text-align: center;
  vertical-align: top;
  width: 100%;
}

.gallery-columns-2 .gallery-item {
  max-width: calc((100% - 16px * 1) / 2);
}

.gallery-columns-2 .gallery-item:nth-of-type(2n+2) {
  margin-left: 0;
}

.gallery-columns-3 .gallery-item {
  max-width: calc((100% - 16px * 2) / 3);
}

.gallery-columns-3 .gallery-item:nth-of-type(3n+3) {
  margin-left: 0;
}

.gallery-columns-4 .gallery-item {
  max-width: calc((100% - 16px * 3) / 4);
}

.gallery-columns-4 .gallery-item:nth-of-type(4n+4) {
  margin-left: 0;
}

.gallery-columns-5 .gallery-item {
  max-width: calc((100% - 16px * 4) / 5);
}

.gallery-columns-5 .gallery-item:nth-of-type(5n+5) {
  margin-left: 0;
}

.gallery-columns-6 .gallery-item {
  max-width: calc((100% - 16px * 5) / 6);
}

.gallery-columns-6 .gallery-item:nth-of-type(6n+6) {
  margin-left: 0;
}

.gallery-columns-7 .gallery-item {
  max-width: calc((100% - 16px * 6) / 7);
}

.gallery-columns-7 .gallery-item:nth-of-type(7n+7) {
  margin-left: 0;
}

.gallery-columns-8 .gallery-item {
  max-width: calc((100% - 16px * 7) / 8);
}

.gallery-columns-8 .gallery-item:nth-of-type(8n+8) {
  margin-left: 0;
}

.gallery-columns-9 .gallery-item {
  max-width: calc((100% - 16px * 8) / 9);
}

.gallery-columns-9 .gallery-item:nth-of-type(9n+9) {
  margin-left: 0;
}

.gallery-item:last-of-type {
  padding-left: 0;
}

.gallery-caption {
  display: block;
  font-size: 0.71111em;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  line-height: 1.6;
  margin: 0;
  padding: 0.5rem;
}

.gallery-item > div > a {
  display: block;
  line-height: 0;
  box-shadow: 0 0 0 0 transparent;
}

.gallery-item > div > a:focus {
  box-shadow: 0 0 0 2px #0073aa;
}
